import hash from 'object-hash';
import { TranslateCacheService, TranslateCacheModule, TranslateCacheSettings } from 'ngx-translate-cache';
import { storage } from 'kv-storage-polyfill';
import { JwtHelperService as JwtHelperService$1 } from '@auth0/angular-jwt/src/jwthelper.service';
import { ToastrService } from 'ngx-toastr';
import { Router, ActivatedRoute, RouterModule } from '@angular/router';
import { JwtHelperService, JwtInterceptor, JwtModule, JWT_OPTIONS } from '@auth0/angular-jwt';
import { FormsModule } from '@angular/forms';
import { CommonModule } from '@angular/common';
import { HttpClient, HttpClientModule, HttpParams, HttpErrorResponse, HTTP_INTERCEPTORS } from '@angular/common/http';
import { createEntityAdapter } from '@ngrx/entity';
import { createFeatureSelector, Store, select, StoreModule } from '@ngrx/store';
import { __decorate, __metadata } from 'tslib';
import { Actions, Effect, ofType, EffectsModule } from '@ngrx/effects';
import { DataPersistence, NxModule } from '@nrwl/nx';
import { Injectable, NgModule, Component, Inject, Input, Pipe, Output, EventEmitter, defineInjectable, inject } from '@angular/core';
import { TranslateService, TranslateModule, TranslateLoader } from '@ngx-translate/core';
import { from, of, throwError, Subject, fromEvent, BehaviorSubject, combineLatest, merge } from 'rxjs';
import { take, toArray, switchMap, map, filter, distinctUntilChanged, catchError, tap, takeUntil, mergeMap, share, throttleTime } from 'rxjs/operators';

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class InitialPaginationMetadata {
    constructor() {
        this.actual = 0;
        this.pages = 1;
        this.itens = 0;
        this.limitByPage = 1;
        this.lastLoaded = 0;
    }
}

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/** @enum {string} */
const PaginationActionTypes = {
    PaginationLoaded: '[Pagination] Pagination Loaded',
    ResetPagination: '[Pagination] Reset Pagination',
};
class PaginationLoaded {
    /**
     * @param {?} payload
     */
    constructor(payload) {
        this.payload = payload;
        this.type = PaginationActionTypes.PaginationLoaded;
    }
}
class ResetPagination {
    /**
     * @param {?} payload
     */
    constructor(payload) {
        this.payload = payload;
        this.type = PaginationActionTypes.ResetPagination;
    }
}

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/** @type {?} */
const getFiltersHash = (filters) => {
    return hash(filters);
};
const ɵ0 = (pagination) => getFiltersHash(pagination.filters);
/** @type {?} */
const paginationAdapter = createEntityAdapter({
    selectId: ɵ0
});
/** @type {?} */
const paginationInitialState = paginationAdapter.getInitialState();
/** @type {?} */
const getLastPageLoaded = (pagination) => {
    return pagination.metadata.actual;
};
/** @type {?} */
const getNextPage = (pagination) => {
    if (pagination.metadata === null || pagination.metadata.pages === 0) {
        return 1;
    }
    if (getLastPageLoaded(pagination) === pagination.metadata.pages || pagination.metadata.pages === 0) {
        return null;
    }
    return getLastPageLoaded(pagination) + 1;
};
/** @type {?} */
const resetPagination = (pagination) => {
    const { metadata } = pagination;
    return Object.assign({}, pagination, { metadata: Object.assign({ pages: 1, limitByPage: 1, itens: 0 }, metadata, { actual: 0 }) });
};
/** @type {?} */
const nextPage = (pagination) => {
    const { metadata } = pagination;
    /** @type {?} */
    const next = getNextPage(pagination);
    if (next === null) {
        return pagination;
    }
    return Object.assign({}, pagination, { metadata: Object.assign({}, metadata, { actual: next }) });
};
/** @type {?} */
const pageLoaded = (state, loadedPagination) => {
    const { metadata } = loadedPagination;
    /** @type {?} */
    let lastLoaded = metadata.actual;
    if (state.metadata !== null && state.metadata.lastLoaded > metadata.actual) {
        lastLoaded = state.metadata.lastLoaded;
    }
    return Object.assign({}, loadedPagination, { metadata: Object.assign({}, metadata, { lastLoaded }) });
};
/** @type {?} */
const takePagination = () => (source) => source.pipe(switchMap(([list, metadata]) => {
    /** @type {?} */
    let to = metadata.actual;
    if (metadata.lastLoaded > metadata.actual) {
        to++;
    }
    /** @type {?} */
    let length = to * metadata.limitByPage;
    if (length > list.length) {
        length = list.length;
    }
    return from(list).pipe(take(length), toArray());
}));
/** @type {?} */
const isInitialPagination = () => (source) => source.pipe(filter((pagination) => {
    if (pagination.metadata === null) {
        return true;
    }
    return pagination.metadata.actual === 0;
}), map(pagination => (/** @type {?} */ (pagination.filters))));
/** @type {?} */
const filterPaginationScrollPosition = (index) => (source) => source.pipe(switchMap((pagination) => of({}).pipe(map(() => Math.ceil(index / pagination.metadata.limitByPage)), filter(page => page <= pagination.metadata.pages), filter(page => page >= pagination.metadata.actual), distinctUntilChanged(), map(() => {
    /** @type {?} */
    const div = index % pagination.metadata.limitByPage;
    return (div >= pagination.metadata.limitByPage * 0.3);
}), distinctUntilChanged(), filter(limit => limit), map(() => (/** @type {?} */ (pagination.filters))))));
/** @type {?} */
const selectPagination = (filters) => {
    /** @type {?} */
    const pageHash = getFiltersHash(filters);
    return (state) => {
        return state.entities[pageHash] || {
            filters,
            metadata: null
        };
    };
};
/**
 * @param {?=} state
 * @param {?=} action
 * @return {?}
 */
function paginationReducer(state = paginationInitialState, action = null) {
    if (action === null) {
        return state;
    }
    switch (action.type) {
        case PaginationActionTypes.PaginationLoaded:
            return paginationAdapter.upsertOne(pageLoaded(selectPagination(action.payload.filters)(state), action.payload), state);
        case PaginationActionTypes.ResetPagination:
            return paginationAdapter.upsertOne(resetPagination(selectPagination(action.payload)(state)), state);
        default:
            return state;
    }
}
/** @type {?} */
const paginationResponseFromPageResponse = (pageResponse, filters) => {
    return {
        pagination: {
            filters: filters,
            metadata: pageResponse.metadata,
        },
        data: pageResponse.data
    };
};

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class EnvService {
    /**
     * @param {?} property
     * @return {?}
     */
    get(property) {
        return this[property] || null;
    }
}
EnvService.decorators = [
    { type: Injectable, args: [{
                providedIn: 'root'
            },] }
];
/** @nocollapse */ EnvService.ngInjectableDef = defineInjectable({ factory: function EnvService_Factory() { return new EnvService(); }, token: EnvService, providedIn: "root" });

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class Host {
    /**
     * @param {?} host
     * @param {?=} protocol
     */
    constructor(host, protocol = 'https://') {
        this.host = host;
        this.protocol = protocol;
    }
    /**
     * @return {?}
     */
    get url() {
        return `${this.protocol}${this.host}`;
    }
}

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/**
 * @param {?} envService
 * @param {?} envKey
 * @return {?}
 */
function hostEnvFactory(envService, envKey) {
    /** @type {?} */
    const env = (/** @type {?} */ (envService.get(envKey)));
    if (typeof env === 'string') {
        return new Host(env);
    }
    return new Host(env.host, env.protocol);
}

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/** @type {?} */
const EnvServiceFactory = () => {
    /** @type {?} */
    const env = new EnvService();
    /** @type {?} */
    const browserWindow = window || {};
    /** @type {?} */
    const browserWindowEnv = browserWindow['__env'] || {};
    storage.set('env', browserWindowEnv);
    for (const key in browserWindowEnv) {
        if (browserWindowEnv.hasOwnProperty(key)) {
            env[key] = window['__env'][key];
        }
    }
    return env;
};
/** @type {?} */
const EnvServiceProvider = {
    provide: EnvService,
    useFactory: EnvServiceFactory,
    deps: [],
};

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/** @enum {string} */
const AlertTypes = {
    SuccessAlert: '[Alert] Success',
    ErrorAlert: '[Alert] Error',
    InfoAlert: '[Alert] Info',
    WarningAlert: '[Alert] Warning',
};
class SuccessAlert {
    /**
     * @param {?} message
     */
    constructor(message) {
        this.message = message;
        this.type = AlertTypes.SuccessAlert;
    }
}
class ErrorAlert {
    /**
     * @param {?} message
     */
    constructor(message) {
        this.message = message;
        this.type = AlertTypes.ErrorAlert;
    }
}
class InfoAlert {
    /**
     * @param {?} message
     */
    constructor(message) {
        this.message = message;
        this.type = AlertTypes.InfoAlert;
    }
}
class WarningAlert {
    /**
     * @param {?} message
     */
    constructor(message) {
        this.message = message;
        this.type = AlertTypes.WarningAlert;
    }
}

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class AlertComponent {
    constructor() { }
    /**
     * @return {?}
     */
    get class() {
        switch (this.alert.type) {
            case AlertTypes.SuccessAlert:
                return 'alert-success';
            case AlertTypes.ErrorAlert:
                return 'alert-danger';
            case AlertTypes.InfoAlert:
                return 'alert-info';
            case AlertTypes.WarningAlert:
                return 'alert-warning';
            default:
                return 'alert-dark';
        }
    }
}
AlertComponent.decorators = [
    { type: Component, args: [{
                selector: 'core-alert',
                template: "<div class=\"animated fadeIn\">\r\n    <div class=\"alert\" [ngClass]=\"class\" role=\"alert\">\r\n        {{ alert.message }}\r\n    </div>\r\n</div>"
            }] }
];
/** @nocollapse */
AlertComponent.ctorParameters = () => [];
AlertComponent.propDecorators = {
    alert: [{ type: Input }]
};

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class AlertModule {
    /**
     * @return {?}
     */
    static forRoot() {
        return {
            ngModule: AlertModule,
        };
    }
}
AlertModule.decorators = [
    { type: NgModule, args: [{
                imports: [
                    CommonModule
                ],
                declarations: [
                    AlertComponent
                ],
                exports: [
                    AlertComponent
                ]
            },] }
];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/** @enum {string} */
const LocalesTypes = {
    ptBr: 'pt-br',
    en: 'en',
    es: 'es',
    fr: 'fr',
};
/** @type {?} */
const DefaultLocale = LocalesTypes.ptBr;

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class LocalesService {
    /**
     * @param {?} translateService
     * @param {?} translateCacheService
     */
    constructor(translateService, translateCacheService) {
        this.translateService = translateService;
        this.translateCacheService = translateCacheService;
    }
    /**
     * @return {?}
     */
    init() {
        this.translateService.setDefaultLang(DefaultLocale);
        this.translateCacheService.init();
    }
    /**
     * @param {?} translateChildService
     * @return {?}
     */
    initChild(translateChildService) {
        translateChildService.setDefaultLang(DefaultLocale);
        translateChildService.use(this.translateCacheService.getCachedLanguage());
    }
}
LocalesService.decorators = [
    { type: Injectable, args: [{
                providedIn: 'root'
            },] }
];
/** @nocollapse */
LocalesService.ctorParameters = () => [
    { type: TranslateService },
    { type: TranslateCacheService }
];
/** @nocollapse */ LocalesService.ngInjectableDef = defineInjectable({ factory: function LocalesService_Factory() { return new LocalesService(inject(TranslateService), inject(TranslateCacheService)); }, token: LocalesService, providedIn: "root" });

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class LocaleLoader {
    /**
     * @param {?} translations
     */
    constructor(translations) {
        this.translations = translations;
    }
    /**
     * @param {?} lang
     * @return {?}
     */
    getTranslation(lang) {
        /** @type {?} */
        const translation = this.translations[lang] || this.translations[DefaultLocale];
        return of(translation);
    }
}
/** @nocollapse */
LocaleLoader.ctorParameters = () => [
    { type: undefined, decorators: [{ type: Inject, args: ['translations',] }] }
];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/**
 * @param {?} translateService
 * @param {?} translateCacheSettings
 * @return {?}
 */
function TranslateCacheFactory(translateService, translateCacheSettings) {
    return new TranslateCacheService(translateService, translateCacheSettings);
}
/** @type {?} */
const providers = [
    LocalesService,
    LocaleLoader
];
class LocalesModule {
    /**
     * @return {?}
     */
    static forRoot() {
        return {
            ngModule: LocalesModule,
            providers
        };
    }
}
LocalesModule.decorators = [
    { type: NgModule, args: [{
                imports: [
                    TranslateModule.forRoot(),
                    TranslateCacheModule.forRoot({
                        cacheService: {
                            provide: TranslateCacheService,
                            useFactory: TranslateCacheFactory,
                            deps: [TranslateService, TranslateCacheSettings]
                        }
                    })
                ],
                declarations: [],
                providers
            },] }
];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/** @enum {string} */
const RolesActionTypes = {
    LoadPage: '[Roles] Load Page',
    FetchPageData: '[Roles] Fetch Page Data',
    PageDataFetched: '[Roles] Page Data Fetched',
    PageDataFetchFailed: '[Roles] Page Data Fetch Failed',
    UpdateUserRoles: '[Roles] Update User Roles',
    FetchRoleGroupsBySistema: '[Roles] Fetch Roles Group by Sistema',
    FetchRoleGroupsBySistemaFail: '[Roles] Fetch Roles Group by Sistema Fail',
    RoleGroupsFetched: '[Roles] Roles Group Fetched',
};
class LoadPage {
    constructor() {
        this.type = RolesActionTypes.LoadPage;
    }
}
class PageDataFetched {
    /**
     * @param {?} payload
     */
    constructor(payload) {
        this.payload = payload;
        this.type = RolesActionTypes.PageDataFetched;
    }
}
class PageDataFetchFailed {
    /**
     * @param {?} payload
     */
    constructor(payload) {
        this.payload = payload;
        this.type = RolesActionTypes.PageDataFetchFailed;
    }
}
class UpdateUserRoles {
    /**
     * @param {?} payload
     */
    constructor(payload) {
        this.payload = payload;
        this.type = RolesActionTypes.UpdateUserRoles;
    }
}
class FetchRoleGroupsBySistema {
    /**
     * @param {?} payload
     */
    constructor(payload) {
        this.payload = payload;
        this.type = RolesActionTypes.FetchRoleGroupsBySistema;
    }
}
class RoleGroupsFetched {
    /**
     * @param {?} payload
     */
    constructor(payload) {
        this.payload = payload;
        this.type = RolesActionTypes.RoleGroupsFetched;
    }
}
class FetchRoleGroupsBySistemaFail {
    /**
     * @param {?} payload
     */
    constructor(payload) {
        this.payload = payload;
        this.type = RolesActionTypes.FetchRoleGroupsBySistemaFail;
    }
}

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
const ɵ0$1 = (role) => role.name;
/** @type {?} */
const roleAdapter = createEntityAdapter({
    selectId: ɵ0$1
});
/** @type {?} */
const roleGroupsAdapter = createEntityAdapter();
/** @type {?} */
const rolesInitialState = roleAdapter.getInitialState({
    filters: {},
    metadata: new InitialPaginationMetadata,
    groups: roleGroupsAdapter.getInitialState()
});
/**
 * @param {?=} state
 * @param {?=} action
 * @return {?}
 */
function rolesReducer(state = rolesInitialState, action) {
    switch (action.type) {
        case RolesActionTypes.PageDataFetched:
            return Object.assign({}, roleAdapter.upsertMany(action.payload.data, state), { metadata: action.payload.metadata });
        case RolesActionTypes.RoleGroupsFetched:
            return Object.assign({}, roleAdapter.upsertMany(action.payload.map((group) => group.roles).flatMap(x => x), state), { groups: roleGroupsAdapter.upsertMany(action.payload, state.groups) });
        default:
            return state;
    }
}
/** @type {?} */
const rolesSelectors = roleAdapter.getSelectors();
/** @type {?} */
const roleGroupsSelectors = roleGroupsAdapter.getSelectors();
/** @type {?} */
const selectRolesIds = rolesSelectors.selectIds;
/** @type {?} */
const selectRolesEntities = rolesSelectors.selectEntities;
/** @type {?} */
const selectAllRoles = rolesSelectors.selectAll;
/** @type {?} */
const selectRoleGroupsIds = roleGroupsSelectors.selectIds;
/** @type {?} */
const selectRoleGroupsEntities = roleGroupsSelectors.selectEntities;
/** @type {?} */
const selectAllRoleGroups = roleGroupsSelectors.selectAll;
/** @type {?} */
const selectRoleGroupsState = createFeatureSelector('groups');
/** @type {?} */
const selectRole = (name) => {
    return (state) => {
        return state.entities[name] || {
            name,
            description: name
        };
    };
};
/** @type {?} */
const selectRoleGroupsBySistema = (id) => {
    return (state) => {
        return selectAllRoleGroups(state.groups)
            .filter((group) => group.systemId === id);
    };
};
/** @type {?} */
const hasRole = (roleName, roles) => roles.some((role) => roleName.includes(role.name));
/** @type {?} */
const selectRolesState = createFeatureSelector('roles');

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/** @type {?} */
const key = 'auth';
class AuthService {
    /**
     * @param {?} http
     * @param {?} apiHost
     * @param {?} jwtHelper
     * @param {?} envService
     */
    constructor(http, apiHost, jwtHelper, envService) {
        this.http = http;
        this.apiHost = apiHost;
        this.jwtHelper = jwtHelper;
        this.accessRoles = [];
        /** @type {?} */
        const accessRoles = (/** @type {?} */ (envService.get('accessRoles')));
        if (accessRoles !== null) {
            this.accessRoles = accessRoles;
        }
    }
    /**
     * @param {?} credential
     * @return {?}
     */
    login(credential) {
        return this.http.post(`${this.apiHost.url}/Oauth/login`, credential)
            .pipe(map((response) => {
            if (!response.success) {
                throw response.message;
            }
            if (!this.hasAcessRole(response.roles)) {
                throw new Error('Acesso não permitido');
            }
            /** @type {?} */
            const user = {
                userName: response.userName,
                name: response.name,
                roles: response.roles,
                access_token: response.access_token,
                refresh_token: response.refresh_token,
                subsidiaries: response.subsidiaries,
                subsidiarySegment: response.subsidiarySegment
            };
            return user;
        }));
    }
    /**
     * @param {?} user
     * @return {?}
     */
    refreshToken(user) {
        return this.http.post(`${this.apiHost.url}/Oauth/refresh`, {
            refresh_token: user.refresh_token
        }).pipe(map((response) => {
            if (!response.success) {
                throw response.message;
            }
            if (!this.hasAcessRole(response.roles)) {
                throw new Error('Acesso não permitido');
            }
            return {
                userName: response.userName,
                name: response.name,
                roles: response.roles,
                access_token: response.access_token,
                refresh_token: response.refresh_token,
                subsidiaries: response.subsidiaries,
                subsidiarySegment: response.subsidiarySegment
            };
        }));
    }
    /**
     * @param {?} request
     * @return {?}
     */
    changePassword(request) {
        return this.http.post(`${this.apiHost.url}/Management/ChangePassword`, request).pipe(catchError(error => throwError(error.error.message)));
    }
    /**
     * @param {?} request
     * @return {?}
     */
    forgotPassword(request) {
        return this.http.post(`${this.apiHost.url}/Oauth/ForgotPassword`, request).pipe(catchError(error => throwError(error.error.message)));
    }
    /**
     * @param {?} request
     * @return {?}
     */
    resetPassword(request) {
        return this.http.post(`${this.apiHost.url}/Oauth/ResetPassword`, request).pipe(catchError(error => throwError(error.error.message)));
    }
    /**
     * @return {?}
     */
    logout() {
        return from(storage.delete(this.stateKey()).then(() => true));
    }
    /**
     * @return {?}
     */
    getState() {
        return from(storage.get(this.stateKey()).then((data) => {
            if (typeof data === 'undefined') {
                /** @type {?} */
                const loggedOutState = {
                    loggedIn: false,
                    persisted: false,
                    user: null,
                    currentSubsidiary: null,
                    currentSubsidiarySegment: null
                };
                return loggedOutState;
            }
            return data;
        }));
    }
    /**
     * @param {?} access_token
     * @return {?}
     */
    isTokenExpired(access_token) {
        return this.jwtHelper.isTokenExpired(access_token);
    }
    /**
     * @param {?} state
     * @return {?}
     */
    persistState(state) {
        return from(storage.set(this.stateKey(), state).then(() => {
            return true;
        }));
    }
    /**
     * @private
     * @param {?} roles
     * @return {?}
     */
    hasAcessRole(roles) {
        if (this.accessRoles.length === 0) {
            return true;
        }
        return this.accessRoles.some(role => hasRole(role, roles));
    }
    /**
     * @private
     * @return {?}
     */
    stateKey() {
        return `access_state_${key}`;
    }
}
AuthService.decorators = [
    { type: Injectable, args: [{
                providedIn: 'root',
            },] }
];
/** @nocollapse */
AuthService.ctorParameters = () => [
    { type: HttpClient },
    { type: Host, decorators: [{ type: Inject, args: ['apiOauthHostService',] }] },
    { type: JwtHelperService },
    { type: EnvService }
];
/** @nocollapse */ AuthService.ngInjectableDef = defineInjectable({ factory: function AuthService_Factory() { return new AuthService(inject(HttpClient), inject("apiOauthHostService"), inject(JwtHelperService$1), inject(EnvService)); }, token: AuthService, providedIn: "root" });

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/** @enum {string} */
const AuthActionTypes = {
    Login: '[Auth] Login',
    LoggedIn: '[Auth] LoggedIn',
    LoginFailed: '[Auth] Login Failed',
    Logout: '[Auth] Logout',
    ClearAuthState: '[Auth] Clear Auth State',
    Loggedout: '[Auth] Loggedout',
    LoadState: '[Auth] Load State',
    StateLoaded: '[Auth] State Loaded',
    PersistState: '[Auth] Persist State',
    StatePersisted: '[Auth] State Persisted',
    RefreshToken: '[Auth] Refresh Token',
    ChangeSubsidiary: '[Auth] Change Current Subsidiary',
    ChangeSubsidiarySegment: '[Auth] Change Current SubsidiarySegment',
    ChangePassword: '[Auth] Change Password',
    PasswordChanged: '[Auth] Password Changed',
    PasswordChangeFailed: '[Auth] Password Change Failed',
    RequestPasswordReset: '[Auth] Request Password Reset',
    PasswordResetRequested: '[Auth] Password Reset Requested',
    PasswordResetRequestFailed: '[Auth] Password Reset Request Failed',
    PasswordReset: '[Auth] Password Reset',
    PasswordReseted: '[Auth] Password Reseted',
    PasswordResetFailed: '[Auth] Password Reset Failed',
};
class Login {
    /**
     * @param {?} payload
     */
    constructor(payload) {
        this.payload = payload;
        this.type = AuthActionTypes.Login;
    }
}
class LoggedIn {
    /**
     * @param {?} payload
     */
    constructor(payload) {
        this.payload = payload;
        this.type = AuthActionTypes.LoggedIn;
    }
}
class LoginFailed {
    /**
     * @param {?} payload
     */
    constructor(payload) {
        this.payload = payload;
        this.type = AuthActionTypes.LoginFailed;
    }
}
class Logout {
    constructor() {
        this.type = AuthActionTypes.Logout;
    }
}
class ClearAuthState {
    constructor() {
        this.type = AuthActionTypes.ClearAuthState;
    }
}
class Loggedout {
    constructor() {
        this.type = AuthActionTypes.Loggedout;
    }
}
class LoadAuthState {
    constructor() {
        this.type = AuthActionTypes.LoadState;
    }
}
class AuthStateLoaded {
    /**
     * @param {?} payload
     */
    constructor(payload) {
        this.payload = payload;
        this.type = AuthActionTypes.StateLoaded;
    }
}
class PersistState {
    /**
     * @param {?} payload
     */
    constructor(payload) {
        this.payload = payload;
        this.type = AuthActionTypes.PersistState;
    }
}
class StatePersisted {
    constructor() {
        this.type = AuthActionTypes.StatePersisted;
    }
}
class RefreshToken {
    /**
     * @param {?} payload
     */
    constructor(payload) {
        this.payload = payload;
        this.type = AuthActionTypes.RefreshToken;
    }
}
class ChangeSubsidiary {
    /**
     * @param {?} payload
     */
    constructor(payload) {
        this.payload = payload;
        this.type = AuthActionTypes.ChangeSubsidiary;
    }
}
class ChangeSubsidiarySegment {
    /**
     * @param {?} payload
     */
    constructor(payload) {
        this.payload = payload;
        this.type = AuthActionTypes.ChangeSubsidiarySegment;
    }
}
class ChangePassword {
    /**
     * @param {?} payload
     */
    constructor(payload) {
        this.payload = payload;
        this.type = AuthActionTypes.ChangePassword;
    }
}
class PasswordChanged {
    /**
     * @param {?} payload
     */
    constructor(payload) {
        this.payload = payload;
        this.type = AuthActionTypes.PasswordChanged;
    }
}
class PasswordChangeFailed {
    /**
     * @param {?} payload
     */
    constructor(payload) {
        this.payload = payload;
        this.type = AuthActionTypes.PasswordChangeFailed;
    }
}
class RequestPasswordReset {
    /**
     * @param {?} payload
     */
    constructor(payload) {
        this.payload = payload;
        this.type = AuthActionTypes.RequestPasswordReset;
    }
}
class PasswordResetRequested {
    /**
     * @param {?} payload
     */
    constructor(payload) {
        this.payload = payload;
        this.type = AuthActionTypes.PasswordResetRequested;
    }
}
class PasswordResetRequestFailed {
    /**
     * @param {?} payload
     */
    constructor(payload) {
        this.payload = payload;
        this.type = AuthActionTypes.PasswordResetRequestFailed;
    }
}
class PasswordReset {
    /**
     * @param {?} payload
     */
    constructor(payload) {
        this.payload = payload;
        this.type = AuthActionTypes.PasswordReset;
    }
}
class PasswordReseted {
    /**
     * @param {?} payload
     */
    constructor(payload) {
        this.payload = payload;
        this.type = AuthActionTypes.PasswordReseted;
    }
}
class PasswordResetFailed {
    /**
     * @param {?} payload
     */
    constructor(payload) {
        this.payload = payload;
        this.type = AuthActionTypes.PasswordResetFailed;
    }
}

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/** @type {?} */
const initialState = {
    loggedIn: null,
    persisted: false,
    user: null,
    currentSubsidiary: null,
    currentSubsidiarySegment: null
};
/** @type {?} */
const selectAuthUser = (state) => {
    return state.user;
};
/** @type {?} */
const selectUserSubsidiary = (id) => {
    return (state) => {
        /** @type {?} */
        const user = selectAuthUser(state);
        /** @type {?} */
        const subsidiaries = user.subsidiaries.filter((subsidiary) => subsidiary.id === id);
        return subsidiaries.length > 0 ? subsidiaries[0] : user.subsidiaries[0];
    };
};
/** @type {?} */
const selectUserSubsidiarySegment = (requestIds) => {
    return (state) => {
        /** @type {?} */
        const user = selectAuthUser(state);
        // tslint:disable-next-line: max-line-length
        /** @type {?} */
        const subsidiariesSegments = user.subsidiarySegment.filter((subsidiarySegment) => subsidiarySegment.subsidiary.id === requestIds.subsidiaryId && subsidiarySegment.segment.id === requestIds.segmentId);
        return subsidiariesSegments.length > 0 ? subsidiariesSegments[0] : user.subsidiarySegment[0];
    };
};
/** @type {?} */
const selectPreferedSubsidiary = (user) => {
    return (state) => {
        if (state.currentSubsidiary === null) {
            return user.subsidiaries[0];
        }
        /** @type {?} */
        const subsidiaries = user.subsidiaries.filter((subsidiary) => subsidiary.id === state.currentSubsidiary.id);
        if (subsidiaries.length === 0) {
            return user.subsidiaries[0];
        }
        return state.currentSubsidiary;
    };
};
/** @type {?} */
const selectPreferedSubsidiarySegment = (user) => {
    return (state) => {
        if (state.currentSubsidiarySegment === null) {
            return user.subsidiarySegment[0];
        }
        // tslint:disable-next-line: max-line-length
        /** @type {?} */
        const subsidiarySegments = user.subsidiarySegment.filter((subsidiarySegment) => subsidiarySegment.subsidiary.id === state.currentSubsidiarySegment.subsidiary.id && subsidiarySegment.segment.id === state.currentSubsidiarySegment.segment.id);
        if (subsidiarySegments.length === 0) {
            return user.subsidiarySegment[0];
        }
        return state.currentSubsidiarySegment;
    };
};
/**
 * @param {?=} state
 * @param {?=} action
 * @return {?}
 */
function authReducer(state = initialState, action) {
    switch (action.type) {
        case AuthActionTypes.StateLoaded:
            return action.payload;
        case AuthActionTypes.Login:
        case AuthActionTypes.RefreshToken:
            return Object.assign({}, state, { persisted: false });
        case AuthActionTypes.LoggedIn:
            return Object.assign({}, state, { loggedIn: true, user: action.payload, currentSubsidiary: selectPreferedSubsidiary(action.payload)(state), currentSubsidiarySegment: selectPreferedSubsidiarySegment(action.payload)(state) });
        case AuthActionTypes.LoginFailed:
            return Object.assign({}, state, { loggedIn: false });
        case AuthActionTypes.ClearAuthState:
            return Object.assign({}, state, { loggedIn: false, persisted: false, user: null, currentSubsidiary: null, currentSubsidiarySegment: null });
        case AuthActionTypes.StatePersisted:
            return Object.assign({}, state, { persisted: true });
        case AuthActionTypes.ChangeSubsidiary:
            return Object.assign({}, state, { currentSubsidiary: selectUserSubsidiary(action.payload)(state) });
        case AuthActionTypes.ChangeSubsidiarySegment:
            return Object.assign({}, state, { currentSubsidiarySegment: selectUserSubsidiarySegment(action.payload)(state) });
        default:
            return state;
    }
}
/** @type {?} */
const selectAuthState = createFeatureSelector('auth');

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class AuthFacade {
    /**
     * @param {?} store
     * @param {?} envService
     */
    constructor(store, envService) {
        this.store = store;
        this.envService = envService;
        this.authState$ = this.selectAuthState();
        this.user$ = this.authState$.pipe(map(selectAuthUser));
        this.subsidiary$ = this.authState$.pipe(map((state) => state.currentSubsidiary));
        this.subsidiarySegment$ = this.authState$.pipe(map((state) => state.currentSubsidiarySegment));
    }
    /**
     * @return {?}
     */
    selectAuthState() {
        return this.store.pipe(select(selectAuthState), filter((state) => {
            if (state.loggedIn === null) {
                this.loadState();
                return false;
            }
            return true;
        }));
    }
    /**
     * @return {?}
     */
    isLoggedIn() {
        return this.authState$.pipe(map((state) => state.loggedIn));
    }
    /**
     * @return {?}
     */
    selectAccessToken() {
        return this.store.pipe(select(selectAuthState), map(state => {
            if (state.user === null) {
                return '';
            }
            return state.user.access_token;
        }));
    }
    /**
     * @param {?} role
     * @return {?}
     */
    hasRole(role) {
        return this.user$.pipe(map((user) => {
            if (user === null) {
                return false;
            }
            return hasRole(role, user.roles);
        }), take(1));
    }
    /**
     * @param {?} credential
     * @return {?}
     */
    login(credential) {
        this.store.dispatch(new Login(credential));
    }
    /**
     * @return {?}
     */
    logout() {
        this.store.dispatch(new Logout);
    }
    /**
     * @param {?} user
     * @return {?}
     */
    refreshToken(user) {
        this.store.dispatch(new RefreshToken(user));
    }
    /**
     * @return {?}
     */
    loadState() {
        this.store.dispatch(new LoadAuthState);
    }
    /**
     * @param {?} id
     * @return {?}
     */
    changeCurrentSubsidiary(id) {
        this.store.dispatch(new ChangeSubsidiary(id));
    }
    /**
     * @param {?} subsdiaryId
     * @param {?} segmentId
     * @return {?}
     */
    changeCurrentSubsidiarySegment(subsdiaryId, segmentId) {
        /** @type {?} */
        const changeSubsidiarySegmentRequest = {
            subsidiaryId: subsdiaryId,
            segmentId: segmentId
        };
        this.store.dispatch(new ChangeSubsidiarySegment(changeSubsidiarySegmentRequest));
    }
    /**
     * @param {?} request
     * @return {?}
     */
    changePassword(request) {
        this.store.dispatch(new ChangePassword(request));
    }
    /**
     * @param {?} userName
     * @return {?}
     */
    requestPasswordReset(userName) {
        /** @type {?} */
        const request = {
            linkRoot: this.envService.get('resetPasswordUrl'),
            userName
        };
        this.store.dispatch(new RequestPasswordReset(request));
    }
    /**
     * @param {?} request
     * @return {?}
     */
    resetPassword(request) {
        this.store.dispatch(new PasswordReset(request));
    }
}
AuthFacade.decorators = [
    { type: Injectable, args: [{
                providedIn: 'root'
            },] }
];
/** @nocollapse */
AuthFacade.ctorParameters = () => [
    { type: Store },
    { type: EnvService }
];
/** @nocollapse */ AuthFacade.ngInjectableDef = defineInjectable({ factory: function AuthFacade_Factory() { return new AuthFacade(inject(Store), inject(EnvService)); }, token: AuthFacade, providedIn: "root" });

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class AuthGuardService {
    /**
     * @param {?} auth
     * @param {?} service
     * @param {?} router
     */
    constructor(auth, service, router) {
        this.auth = auth;
        this.service = service;
        this.router = router;
    }
    /**
     * @param {?} route
     * @return {?}
     */
    canActivate(route) {
        return this.auth.authState$.pipe(filter((state) => {
            if (state.loggedIn && !state.persisted) {
                return false;
            }
            return true;
        }), filter((state) => {
            if (state.loggedIn && this.service.isTokenExpired(state.user.access_token)) {
                this.auth.refreshToken(state.user);
                return false;
            }
            return true;
        }), map((state) => {
            return state.loggedIn;
        }), tap((loggedIn) => {
            if (!loggedIn) {
                this.router.navigate(['/login']);
            }
        }), take(1));
    }
    /**
     * @param {?} route
     * @return {?}
     */
    canActivateChild(route) {
        return this.canActivate(route);
    }
}
AuthGuardService.decorators = [
    { type: Injectable, args: [{
                providedIn: 'root'
            },] }
];
/** @nocollapse */
AuthGuardService.ctorParameters = () => [
    { type: AuthFacade },
    { type: AuthService },
    { type: Router }
];
/** @nocollapse */ AuthGuardService.ngInjectableDef = defineInjectable({ factory: function AuthGuardService_Factory() { return new AuthGuardService(inject(AuthFacade), inject(AuthService), inject(Router)); }, token: AuthGuardService, providedIn: "root" });

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class GuestGuardService {
    /**
     * @param {?} auth
     * @param {?} router
     */
    constructor(auth, router) {
        this.auth = auth;
        this.router = router;
        this.loggedIn$ = auth.isLoggedIn();
    }
    /**
     * @param {?} route
     * @return {?}
     */
    canActivate(route) {
        return this.loggedIn$.pipe(map((loogedIn) => {
            if (loogedIn) {
                this.router.navigate(['/']);
            }
            return !loogedIn;
        }), take(1));
    }
    /**
     * @param {?} route
     * @return {?}
     */
    canActivateChild(route) {
        return this.canActivate(route);
    }
}
GuestGuardService.decorators = [
    { type: Injectable, args: [{
                providedIn: 'root'
            },] }
];
/** @nocollapse */
GuestGuardService.ctorParameters = () => [
    { type: AuthFacade },
    { type: Router }
];
/** @nocollapse */ GuestGuardService.ngInjectableDef = defineInjectable({ factory: function GuestGuardService_Factory() { return new GuestGuardService(inject(AuthFacade), inject(Router)); }, token: GuestGuardService, providedIn: "root" });

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class HasRoleGuardService {
    /**
     * @param {?} auth
     * @param {?} router
     */
    constructor(auth, router) {
        this.auth = auth;
        this.router = router;
    }
    /**
     * @param {?} route
     * @return {?}
     */
    canActivate(route) {
        if (!route.data.role) {
            return true;
        }
        return this.auth.hasRole(route.data.role).pipe(tap((hasRole) => {
            if (!hasRole) {
                this.router.navigate(['/']);
            }
        }), take(1));
    }
    /**
     * @param {?} route
     * @return {?}
     */
    canActivateChild(route) {
        return this.canActivate(route);
    }
    /**
     * @param {?} route
     * @return {?}
     */
    canLoad(route) {
        if (!route.data.role) {
            return true;
        }
        return this.auth.hasRole(route.data.role).pipe(tap((hasRole) => {
            if (!hasRole) {
                this.router.navigate(['/']);
            }
        }));
    }
}
HasRoleGuardService.decorators = [
    { type: Injectable, args: [{
                providedIn: 'root'
            },] }
];
/** @nocollapse */
HasRoleGuardService.ctorParameters = () => [
    { type: AuthFacade },
    { type: Router }
];
/** @nocollapse */ HasRoleGuardService.ngInjectableDef = defineInjectable({ factory: function HasRoleGuardService_Factory() { return new HasRoleGuardService(inject(AuthFacade), inject(Router)); }, token: HasRoleGuardService, providedIn: "root" });

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/**
 * @abstract
 */
class ObserverComponent {
    constructor() {
        this.destroy$ = new Subject();
    }
    /**
     * @template T
     * @param {?} observable
     * @return {?}
     */
    observe(observable) {
        return observable.pipe(takeUntil(this.destroy$));
    }
    /**
     * @return {?}
     */
    ngOnDestroy() {
        this.destroy$.next(true);
        this.destroy$.unsubscribe();
    }
}

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class AuthEffects {
    /**
     * @param {?} store
     * @param {?} actions$
     * @param {?} dataPersistence
     * @param {?} auth
     * @param {?} router
     * @param {?} toastr
     */
    constructor(store, actions$, dataPersistence, auth, router, toastr) {
        this.store = store;
        this.actions$ = actions$;
        this.dataPersistence = dataPersistence;
        this.auth = auth;
        this.router = router;
        this.toastr = toastr;
        this.login$ = this.dataPersistence.pessimisticUpdate(AuthActionTypes.Login, {
            run: (action) => {
                return this.auth.login(action.payload)
                    .pipe(map((res) => new LoggedIn(res)), take(1), catchError(error => of(new LoginFailed(error))));
            },
            onError: (action, error) => {
                console.error('Error', error);
            }
        });
        this.refreshToken$ = this.dataPersistence.pessimisticUpdate(AuthActionTypes.RefreshToken, {
            run: (action) => {
                return this.auth.refreshToken(action.payload)
                    .pipe(map((res) => new LoggedIn(res)), take(1), catchError(error => of(new LoginFailed(error))));
            },
            onError: (action, error) => {
                console.error('Error', error);
            }
        });
        this.logout$ = this.dataPersistence.pessimisticUpdate(AuthActionTypes.Logout, {
            run: (action, state) => {
                return this.auth.logout().pipe(take(1), map(() => new ClearAuthState));
            },
            onError: (action, error) => {
                console.error('Error', error);
            }
        });
        this.loggedOut$ = this.dataPersistence.pessimisticUpdate(AuthActionTypes.ClearAuthState, {
            run: (action, state) => {
                return from(this.router.navigate(['/login'])).pipe(map(() => new Loggedout));
            },
            onError: (action, error) => {
                console.error('Error', error);
            }
        });
        this.loggedIn$ = this.dataPersistence.fetch(AuthActionTypes.LoggedIn, {
            id: () => AuthActionTypes.LoggedIn,
            run: (action, state) => {
                return new PersistState(Object.assign({}, state.auth, { persisted: true }));
            },
            onError: (action, error) => {
                console.error('Error', error);
            }
        });
        this.changeCurrentSubsidiary$ = this.dataPersistence.fetch(AuthActionTypes.ChangeSubsidiary, {
            id: () => AuthActionTypes.ChangeSubsidiary,
            run: (action, state) => {
                return new PersistState(state.auth);
            },
            onError: (action, error) => {
                console.error('Error', error);
            }
        });
        this.changeCurrentSubsidiarySegment$ = this.dataPersistence.fetch(AuthActionTypes.ChangeSubsidiarySegment, {
            id: () => AuthActionTypes.ChangeSubsidiarySegment,
            run: (action, state) => {
                return new PersistState(state.auth);
            },
            onError: (action, error) => {
                console.error('Error', error);
            }
        });
        this.getState$ = this.dataPersistence.fetch(AuthActionTypes.LoadState, {
            id: () => AuthActionTypes.LoadState,
            run: (action) => {
                return this.auth.getState().pipe(map((data) => new AuthStateLoaded(data)), take(1));
            },
            onError: (action, error) => {
                console.error('Error', error);
            }
        });
        this.persistState$ = this.dataPersistence.pessimisticUpdate(AuthActionTypes.PersistState, {
            run: (action) => {
                return this.auth.persistState(action.payload).pipe(map(() => new StatePersisted), take(1));
            },
            onError: (action, error) => {
                console.error('Error', error);
            }
        });
        this.changePassword$ = this.dataPersistence.pessimisticUpdate(AuthActionTypes.ChangePassword, {
            run: (action) => {
                return this.auth.changePassword(action.payload)
                    .pipe(map((res) => new PasswordChanged(res)), take(1), catchError(error => of(new PasswordChangeFailed(error))));
            },
            onError: (action, error) => {
                console.error('Error', error);
            }
        });
        this.passwordChanged$ = this.dataPersistence.fetch(AuthActionTypes.PasswordChanged, {
            id: () => AuthActionTypes.PasswordChanged,
            run: (action) => {
                const { success, message } = action.payload;
                if (success) {
                    this.toastr.success(message);
                }
                else {
                    this.toastr.error(message);
                }
            },
            onError: (action, error) => {
                console.error('Error', error);
            }
        });
        this.passwordChangeFailed$ = this.dataPersistence.fetch(AuthActionTypes.PasswordChangeFailed, {
            run: (action) => {
                this.toastr.error(action.payload);
            },
            onError: (action, error) => {
                console.error('Error', error);
            }
        });
        this.requestPasswordReset$ = this.dataPersistence.pessimisticUpdate(AuthActionTypes.RequestPasswordReset, {
            run: (action) => {
                return this.auth.forgotPassword(action.payload)
                    .pipe(map(res => {
                    const { success, message } = res;
                    return success ? new PasswordResetRequested(res) : new PasswordResetRequestFailed(message);
                }), take(1), catchError(error => of(new PasswordResetRequestFailed(error))));
            },
            onError: (action, error) => {
                console.error('Error', error);
            }
        });
        this.passwordResetRequested$ = this.dataPersistence.fetch(AuthActionTypes.PasswordResetRequested, {
            run: (action) => {
                const { success, message } = action.payload;
                this.toastr.success(message);
            },
            onError: (action, error) => {
                console.error('Error', error);
            }
        });
        this.passwordResetRequestFailed$ = this.dataPersistence.fetch(AuthActionTypes.PasswordResetRequestFailed, {
            run: (action) => {
                this.toastr.error(action.payload);
            },
            onError: (action, error) => {
                console.error('Error', error);
            }
        });
        this.resetPassword$ = this.dataPersistence.pessimisticUpdate(AuthActionTypes.PasswordReset, {
            run: (action) => {
                return this.auth.resetPassword(action.payload)
                    .pipe(map(res => {
                    const { success, message } = res;
                    return success ? new PasswordReseted(res) : new PasswordResetFailed(message);
                }), take(1), catchError(error => of(new PasswordResetFailed(error))));
            },
            onError: (action, error) => {
                console.error('Error', error);
            }
        });
        this.passwordReseted$ = this.dataPersistence.fetch(AuthActionTypes.PasswordReseted, {
            run: (action) => {
                const { success, message } = action.payload;
                if (success) {
                    this.toastr.success(message);
                }
                else {
                    this.toastr.error(message);
                }
            },
            onError: (action, error) => {
                console.error('Error', error);
            }
        });
        this.passwordResetFailed$ = this.dataPersistence.fetch(AuthActionTypes.PasswordResetFailed, {
            run: (action) => {
                this.toastr.error(action.payload);
            },
            onError: (action, error) => {
                console.error('Error', error);
            }
        });
        if (navigator.serviceWorker) {
            fromEvent(navigator.serviceWorker, 'message').pipe(map((event) => event.data), filter(data => typeof data.type !== 'undefined' && data.type === AuthActionTypes.LoggedIn), map((data) => data.payload)).subscribe((user) => {
                this.store.dispatch(new LoggedIn(user));
            });
        }
    }
    /**
     * @param {...?} types
     * @return {?}
     */
    ofType(...types) {
        return this.actions$.pipe(ofType(...types));
    }
}
AuthEffects.decorators = [
    { type: Injectable, args: [{ providedIn: 'root' },] }
];
/** @nocollapse */
AuthEffects.ctorParameters = () => [
    { type: Store },
    { type: Actions },
    { type: DataPersistence },
    { type: AuthService },
    { type: Router },
    { type: ToastrService }
];
/** @nocollapse */ AuthEffects.ngInjectableDef = defineInjectable({ factory: function AuthEffects_Factory() { return new AuthEffects(inject(Store), inject(Actions), inject(DataPersistence), inject(AuthService), inject(Router), inject(ToastrService)); }, token: AuthEffects, providedIn: "root" });
__decorate([
    Effect(),
    __metadata("design:type", Object)
], AuthEffects.prototype, "login$", void 0);
__decorate([
    Effect(),
    __metadata("design:type", Object)
], AuthEffects.prototype, "refreshToken$", void 0);
__decorate([
    Effect(),
    __metadata("design:type", Object)
], AuthEffects.prototype, "logout$", void 0);
__decorate([
    Effect(),
    __metadata("design:type", Object)
], AuthEffects.prototype, "loggedOut$", void 0);
__decorate([
    Effect(),
    __metadata("design:type", Object)
], AuthEffects.prototype, "loggedIn$", void 0);
__decorate([
    Effect(),
    __metadata("design:type", Object)
], AuthEffects.prototype, "changeCurrentSubsidiary$", void 0);
__decorate([
    Effect(),
    __metadata("design:type", Object)
], AuthEffects.prototype, "changeCurrentSubsidiarySegment$", void 0);
__decorate([
    Effect(),
    __metadata("design:type", Object)
], AuthEffects.prototype, "getState$", void 0);
__decorate([
    Effect(),
    __metadata("design:type", Object)
], AuthEffects.prototype, "persistState$", void 0);
__decorate([
    Effect(),
    __metadata("design:type", Object)
], AuthEffects.prototype, "changePassword$", void 0);
__decorate([
    Effect(),
    __metadata("design:type", Object)
], AuthEffects.prototype, "passwordChanged$", void 0);
__decorate([
    Effect(),
    __metadata("design:type", Object)
], AuthEffects.prototype, "passwordChangeFailed$", void 0);
__decorate([
    Effect(),
    __metadata("design:type", Object)
], AuthEffects.prototype, "requestPasswordReset$", void 0);
__decorate([
    Effect(),
    __metadata("design:type", Object)
], AuthEffects.prototype, "passwordResetRequested$", void 0);
__decorate([
    Effect(),
    __metadata("design:type", Object)
], AuthEffects.prototype, "passwordResetRequestFailed$", void 0);
__decorate([
    Effect(),
    __metadata("design:type", Object)
], AuthEffects.prototype, "resetPassword$", void 0);
__decorate([
    Effect(),
    __metadata("design:type", Object)
], AuthEffects.prototype, "passwordReseted$", void 0);
__decorate([
    Effect(),
    __metadata("design:type", Object)
], AuthEffects.prototype, "passwordResetFailed$", void 0);

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class AuthFormComponent extends ObserverComponent {
    /**
     * @param {?} router
     * @param {?} facade
     * @param {?} effects
     */
    constructor(router, facade, effects) {
        super();
        this.router = router;
        this.facade = facade;
        this.effects = effects;
        this.alert = null;
        this.submiting = false;
    }
    /**
     * @return {?}
     */
    ngOnInit() {
        this.observe(this.effects.ofType(AuthActionTypes.Login)).subscribe(() => {
            this.submiting = true;
            this.alert = null;
        });
        this.observe(this.effects.ofType(AuthActionTypes.LoginFailed)).subscribe((action) => {
            this.submiting = false;
            this.alert = new ErrorAlert(action.payload);
        });
        this.observe(this.effects.ofType(AuthActionTypes.LoggedIn).pipe(switchMap(() => this.effects.ofType(AuthActionTypes.StatePersisted)))).subscribe(() => {
            this.router.navigate(['/']);
            this.submiting = false;
        });
    }
    /**
     * @param {?} credential
     * @return {?}
     */
    onSubmit(credential) {
        this.facade.login(credential);
    }
}
AuthFormComponent.decorators = [
    { type: Component, args: [{
                selector: 'core-auth-form',
                template: "<form #formRef=\"ngForm\" (ngSubmit)=\"onSubmit(formRef.value)\">\r\n    <h1>{{ 'core.auth.login.title' | translate }}</h1>\r\n    <p class=\"text-muted\">{{ 'core.auth.login.subtitle' | translate  }}</p>\r\n    <div class=\"input-group mb-3\">\r\n        <div class=\"input-group-prepend\">\r\n            <span class=\"input-group-text\"><i class=\"icon-user\"></i></span>\r\n        </div>\r\n        <input type=\"email\" [(ngModel)]=\"UserName\" name=\"UserName\" class=\"form-control\" [placeholder]=\"'core.auth.login.username' | translate  \" autocomplete=\"username\" required>\r\n    </div>\r\n    <div class=\"input-group mb-4\">\r\n        <div class=\"input-group-prepend\">\r\n            <span class=\"input-group-text\"><i class=\"icon-lock\"></i></span>\r\n        </div>\r\n        <input type=\"password\" [(ngModel)]=\"Password\" name=\"Password\" class=\"form-control\" [placeholder]=\"'core.auth.login.password' | translate \" autocomplete=\"current-password\" required>\r\n    </div>\r\n    <div class=\"row\" *ngIf=\"alert !== null\">\r\n        <div class=\"col-12\">\r\n            <core-alert [alert]=\"alert\" ></core-alert>\r\n        </div>\r\n    </div>\r\n    <div class=\"form-row\">\r\n        <div class=\"col-6\">\r\n            <button type=\"submit\" class=\"btn btn-primary px-4\" [disabled]=\"!formRef.valid || submiting\">\r\n                <span *ngIf=\"!submiting\">{{ 'core.auth.login.submit' | translate  }}</span>\r\n                <span *ngIf=\"submiting\"><i class=\"fa fa-circle-o-notch fa-spin\"></i></span>\r\n            </button>\r\n        </div>\r\n        <div class=\"col-6 d-flex justify-content-end\">\r\n            <a class=\"btn btn-link px-0\" [routerLink]=\"['forgot-password']\">{{ 'core.auth.login.forgotPassword' | translate  }}</a>\r\n        </div>\r\n    </div>\r\n</form>\r\n"
            }] }
];
/** @nocollapse */
AuthFormComponent.ctorParameters = () => [
    { type: Router },
    { type: AuthFacade },
    { type: AuthEffects }
];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class ChangePasswordComponent extends ObserverComponent {
    /**
     * @param {?} facade
     * @param {?} effects
     */
    constructor(facade, effects) {
        super();
        this.facade = facade;
        this.effects = effects;
        this.oldPassword = '';
        this.newPassword = '';
        this.confirmPassword = '';
        this.submiting = false;
    }
    /**
     * @return {?}
     */
    ngOnInit() {
        this.observe(this.effects.ofType(AuthActionTypes.ChangePassword)).subscribe(() => {
            this.submiting = true;
        });
        this.observe(this.effects.ofType(AuthActionTypes.PasswordChanged, AuthActionTypes.PasswordChangeFailed)).subscribe(() => {
            this.submiting = false;
        });
        this.observe(this.effects.ofType(AuthActionTypes.PasswordChanged)).subscribe(() => {
            this.oldPassword = '';
            this.newPassword = '';
            this.confirmPassword = '';
        });
    }
    /**
     * @param {?} data
     * @return {?}
     */
    onSubmit(data) {
        this.facade.changePassword(data);
    }
}
ChangePasswordComponent.decorators = [
    { type: Component, args: [{
                selector: 'core-change-password',
                template: "<form #formRef=\"ngForm\" (ngSubmit)=\"onSubmit(formRef.value)\">\r\n    <div class=\"row\">\r\n        <div class=\"col-12\">\r\n            <h3>{{ 'core.auth.changePassword.title' | translate }}</h3>\r\n        </div>\r\n    </div>\r\n    <div class=\"row\">\r\n        <div class=\"col-12\">\r\n            <div class=\"form-group\">\r\n                <label>{{ 'core.auth.changePassword.oldPassword' | translate }}</label>\r\n                <input type=\"password\" [(ngModel)]=\"oldPassword\" name=\"oldPassword\" class=\"form-control\" required>\r\n            </div>\r\n        </div>\r\n        <div class=\"col-12\">\r\n            <div class=\"form-group\">\r\n                <label>{{ 'core.auth.changePassword.newPassword' | translate }}</label>\r\n                <input type=\"password\" [(ngModel)]=\"newPassword\" name=\"newPassword\" class=\"form-control\" required>\r\n            </div>\r\n        </div>\r\n        <div class=\"col-12\">\r\n            <div class=\"form-group\">\r\n                <label>{{ 'core.auth.changePassword.confirmPassword' | translate }}</label>\r\n                <input type=\"password\" [(ngModel)]=\"confirmPassword\" name=\"confirmPassword\" class=\"form-control\" required>\r\n            </div>\r\n        </div>\r\n    </div>\r\n    <div class=\"row\">\r\n        <div class=\"col-12\">\r\n            <button type=\"submit\" class=\"btn btn-primary\" [disabled]=\"!formRef.valid || submiting\">\r\n                <span *ngIf=\"!submiting\">{{ 'core.auth.changePassword.submit' | translate }}</span>\r\n                <span *ngIf=\"submiting\"><i class=\"fa fa-circle-o-notch fa-spin\"></i></span>\r\n            </button>\r\n        </div>\r\n    </div>\r\n</form>"
            }] }
];
/** @nocollapse */
ChangePasswordComponent.ctorParameters = () => [
    { type: AuthFacade },
    { type: AuthEffects }
];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class HasRolePipe {
    /**
     * @param {?} authFacade
     */
    constructor(authFacade) {
        this.authFacade = authFacade;
    }
    /**
     * @param {?} role
     * @return {?}
     */
    transform(role) {
        return this.authFacade.hasRole(role);
    }
}
HasRolePipe.decorators = [
    { type: Pipe, args: [{ name: 'hasRole' },] }
];
/** @nocollapse */
HasRolePipe.ctorParameters = () => [
    { type: AuthFacade }
];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/** @type {?} */
const tranlation = {
    'core': {
        'auth': {
            'login': {
                'title': 'Login',
                'subtitle': 'Entre com a sua conta',
                'username': 'Usuário',
                'password': 'Senha',
                'forgotPassword': 'Esqueci minha senha',
                'submit': 'Entrar'
            },
            'changePassword': {
                'title': 'Alterar Senha',
                'oldPassword': 'Senha Atual',
                'newPassword': 'Nova Senha',
                'confirmPassword': 'Confirmar Senha',
                'submit': 'Alterar Senha'
            },
            'forgotPassword': {
                'title': 'Esqueci minha senha',
                'userName': 'E-mail',
                'submit': 'Recuperar senha'
            },
            'resetPassword': {
                'title': 'Redefinir Senha',
                'password': 'Nova Senha',
                'submit': 'Salvar'
            }
        }
    }
};

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/** @type {?} */
const tranlation$1 = {};

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/** @type {?} */
const translations = {
    [LocalesTypes.ptBr]: tranlation,
    [LocalesTypes.en]: tranlation$1,
};

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class ForgotPasswordComponent extends ObserverComponent {
    /**
     * @param {?} router
     * @param {?} facade
     * @param {?} effects
     */
    constructor(router, facade, effects) {
        super();
        this.router = router;
        this.facade = facade;
        this.effects = effects;
        this.userName = '';
        this.submiting = false;
    }
    /**
     * @return {?}
     */
    ngOnInit() {
        this.observe(this.effects.ofType(AuthActionTypes.RequestPasswordReset)).subscribe(() => {
            this.submiting = true;
        });
        this.observe(this.effects.ofType(AuthActionTypes.PasswordResetRequested, AuthActionTypes.PasswordResetRequestFailed)).subscribe(() => {
            this.submiting = false;
        });
        this.observe(this.effects.ofType(AuthActionTypes.PasswordResetRequested).pipe(take(1))).subscribe(() => {
            this.router.navigate(['/login']);
        });
    }
    /**
     * @param {?} userName
     * @return {?}
     */
    onSubmit(userName) {
        this.facade.requestPasswordReset(userName);
    }
}
ForgotPasswordComponent.decorators = [
    { type: Component, args: [{
                selector: 'core-forgot-password',
                template: "<form #formRef=\"ngForm\" (ngSubmit)=\"onSubmit(formRef.value.userName)\">\r\n    <div class=\"row mb-4\">\r\n        <div class=\"col-12\">\r\n            <h3>{{ 'core.auth.forgotPassword.title' | translate }}</h3>\r\n        </div>\r\n    </div>\r\n    <div class=\"row mb-3\">\r\n        <div class=\"col-12\">\r\n            <div class=\"form-group\">\r\n                <input type=\"email\" [(ngModel)]=\"userName\" name=\"userName\" class=\"form-control\" [placeholder]=\"'core.auth.forgotPassword.userName' | translate\" required>\r\n            </div>\r\n        </div>\r\n    </div>\r\n    <div class=\"row\">\r\n        <div class=\"col-12\">\r\n            <button type=\"submit\" class=\"btn btn-primary\" [disabled]=\"!formRef.valid || submiting\">\r\n                <span *ngIf=\"!submiting\">{{ 'core.auth.forgotPassword.submit' | translate }}</span>\r\n                <span *ngIf=\"submiting\"><i class=\"fa fa-circle-o-notch fa-spin\"></i></span>\r\n            </button>\r\n        </div>\r\n    </div>\r\n</form>"
            }] }
];
/** @nocollapse */
ForgotPasswordComponent.ctorParameters = () => [
    { type: Router },
    { type: AuthFacade },
    { type: AuthEffects }
];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class ResetPasswordComponent extends ObserverComponent {
    /**
     * @param {?} router
     * @param {?} activedRoute
     * @param {?} facade
     * @param {?} effects
     */
    constructor(router, activedRoute, facade, effects) {
        super();
        this.router = router;
        this.activedRoute = activedRoute;
        this.facade = facade;
        this.effects = effects;
        this.userId = '';
        this.code = '';
        this.password = '';
        this.submiting = false;
    }
    /**
     * @return {?}
     */
    ngOnInit() {
        this.observe(this.activedRoute.queryParams).subscribe((params) => {
            const { userId, code } = params;
            this.userId = userId;
            this.code = code;
        });
        this.observe(this.effects.ofType(AuthActionTypes.PasswordReset)).subscribe(() => {
            this.submiting = true;
        });
        this.observe(this.effects.ofType(AuthActionTypes.PasswordReseted, AuthActionTypes.PasswordResetFailed)).subscribe(() => {
            this.submiting = false;
        });
        this.observe(this.effects.ofType(AuthActionTypes.PasswordReseted).pipe(take(1))).subscribe(() => {
            this.router.navigate(['/login']);
        });
    }
    /**
     * @param {?} request
     * @return {?}
     */
    onSubmit(request) {
        this.facade.resetPassword(request);
    }
}
ResetPasswordComponent.decorators = [
    { type: Component, args: [{
                selector: 'core-reset-password',
                template: "<form #formRef=\"ngForm\" (ngSubmit)=\"onSubmit(formRef.value)\">\r\n    <div class=\"row\">\r\n        <div class=\"col-12\">\r\n            <h3>{{ 'core.auth.resetPassword.title' | translate }}</h3>\r\n        </div>\r\n    </div>\r\n    <div class=\"row\">\r\n        <div class=\"col-12\">\r\n            <div class=\"form-group\">\r\n                <label>{{ 'core.auth.resetPassword.password' | translate }}</label>\r\n                <input type=\"password\" [(ngModel)]=\"password\" name=\"password\" class=\"form-control\" required>\r\n                <input type=\"hidden\" [(ngModel)]=\"userId\" name=\"userId\" class=\"form-control\" required>\r\n                <input type=\"hidden\" [(ngModel)]=\"code\" name=\"code\" class=\"form-control\" required>\r\n            </div>\r\n        </div>\r\n    </div>\r\n    <div class=\"row\">\r\n        <div class=\"col-6\">\r\n            <button type=\"submit\" class=\"btn btn-primary\" [disabled]=\"!formRef.valid || submiting\">\r\n                <span *ngIf=\"!submiting\">{{ 'core.auth.resetPassword.submit' | translate }}</span>\r\n                <span *ngIf=\"submiting\"><i class=\"fa fa-circle-o-notch fa-spin\"></i></span>\r\n            </button>\r\n        </div>\r\n    </div>\r\n</form>"
            }] }
];
/** @nocollapse */
ResetPasswordComponent.ctorParameters = () => [
    { type: Router },
    { type: ActivatedRoute },
    { type: AuthFacade },
    { type: AuthEffects }
];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/** @type {?} */
const providers$1 = [
    AuthService,
    AuthGuardService,
    GuestGuardService,
    HasRoleGuardService
];
const ɵ0$2 = translations;
class AuthElisModule {
    /**
     * @param {?} translateService
     * @param {?} localesService
     */
    constructor(translateService, localesService) {
        localesService.initChild(translateService);
    }
    /**
     * @return {?}
     */
    static forRoot() {
        return {
            ngModule: AuthElisModule,
            providers: providers$1
        };
    }
}
AuthElisModule.decorators = [
    { type: NgModule, args: [{
                declarations: [
                    AuthFormComponent,
                    ChangePasswordComponent,
                    ForgotPasswordComponent,
                    ResetPasswordComponent,
                    HasRolePipe
                ],
                exports: [
                    AuthFormComponent,
                    ChangePasswordComponent,
                    ForgotPasswordComponent,
                    ResetPasswordComponent,
                    HasRolePipe
                ],
                imports: [
                    CommonModule,
                    FormsModule,
                    RouterModule,
                    HttpClientModule,
                    LocalesModule,
                    TranslateModule.forChild({
                        loader: {
                            provide: TranslateLoader,
                            useClass: LocaleLoader
                        },
                        isolate: true
                    }),
                    AlertModule
                ],
                providers: [
                    ...providers$1,
                    {
                        provide: 'translations',
                        useValue: ɵ0$2
                    }
                ]
            },] }
];
/** @nocollapse */
AuthElisModule.ctorParameters = () => [
    { type: TranslateService },
    { type: LocalesService }
];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/** @type {?} */
const authBlacklistedRoutes = [
    /\/Oauth\/login\/?$/,
    /\/Oauth\/refresh\/?$/,
    /\/Oauth\/ForgotPassword\/?$/,
    /\/Oauth\/ResetPassword\/?$/,
];
/**
 * @param {?} jwtConfig
 * @param {?} authFacade
 * @return {?}
 */
function jwtOptionsFactory(jwtConfig, authFacade) {
    return {
        tokenGetter: () => authFacade.selectAccessToken().pipe(take(1)).toPromise(),
        whitelistedDomains: jwtConfig.whitelistedDomains,
        blacklistedRoutes: jwtConfig.blacklistedRoutes
    };
}
class JwtConfig {
    /**
     * @param {?} envService
     */
    constructor(envService) {
        this.whitelistedDomains = [];
        this.blacklistedRoutes = authBlacklistedRoutes;
        /** @type {?} */
        const whitelistedDomains = (/** @type {?} */ (envService.get('jwtWhitelistedDomains')));
        if (whitelistedDomains !== null) {
            this.whitelistedDomains = whitelistedDomains;
        }
    }
}
JwtConfig.decorators = [
    { type: Injectable, args: [{
                providedIn: 'root'
            },] }
];
/** @nocollapse */
JwtConfig.ctorParameters = () => [
    { type: EnvService }
];
/** @nocollapse */ JwtConfig.ngInjectableDef = defineInjectable({ factory: function JwtConfig_Factory() { return new JwtConfig(inject(EnvService)); }, token: JwtConfig, providedIn: "root" });

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class RefreshTokenInterceptor {
    /**
     * @param {?} authFacade
     * @param {?} authService
     * @param {?} jwtInterceptor
     * @param {?} router
     */
    constructor(authFacade, authService, jwtInterceptor, router) {
        this.authFacade = authFacade;
        this.authService = authService;
        this.jwtInterceptor = jwtInterceptor;
        this.router = router;
        this.authState$ = authFacade.authState$;
    }
    /**
     * @param {?} request
     * @param {?} next
     * @return {?}
     */
    intercept(request, next) {
        if (!this.jwtInterceptor.isWhitelistedDomain(request) || this.jwtInterceptor.isBlacklistedRoute(request)) {
            return next.handle(request);
        }
        return this.authState$.pipe(filter((state) => {
            if (state.loggedIn === null) {
                this.authFacade.loadState();
                return false;
            }
            return true;
        }), filter((state) => {
            if (!state.loggedIn) {
                this.router.navigate(['/login']);
                return false;
            }
            return true;
        }), filter((state) => state.persisted), filter((state) => {
            if (this.authService.isTokenExpired(state.user.access_token)) {
                this.authFacade.refreshToken(state.user);
                return false;
            }
            return true;
        }), take(1), mergeMap(() => this.jwtInterceptor.intercept(request, next)));
    }
}
RefreshTokenInterceptor.decorators = [
    { type: Injectable }
];
/** @nocollapse */
RefreshTokenInterceptor.ctorParameters = () => [
    { type: AuthFacade },
    { type: AuthService },
    { type: JwtInterceptor },
    { type: Router }
];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class SubsidiaryInterceptor {
    /**
     * @param {?} authFacade
     * @param {?} jwtInterceptor
     */
    constructor(authFacade, jwtInterceptor) {
        this.authFacade = authFacade;
        this.jwtInterceptor = jwtInterceptor;
    }
    /**
     * @param {?} request
     * @param {?} next
     * @return {?}
     */
    intercept(request, next) {
        if (!this.jwtInterceptor.isWhitelistedDomain(request) || this.jwtInterceptor.isBlacklistedRoute(request)) {
            return next.handle(request);
        }
        return this.authFacade.authState$.pipe(switchMap((state) => {
            if (state.currentSubsidiary === null) {
                return next.handle(request);
            }
            return next.handle(request.clone({
                setHeaders: {
                    'X-Subsidiary': state.currentSubsidiary.id
                }
            }));
        }));
    }
}
SubsidiaryInterceptor.decorators = [
    { type: Injectable }
];
/** @nocollapse */
SubsidiaryInterceptor.ctorParameters = () => [
    { type: AuthFacade },
    { type: JwtInterceptor }
];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class SistemasService {
    /**
     * @param {?} http
     * @param {?} apiHost
     */
    constructor(http, apiHost) {
        this.http = http;
        this.apiHost = apiHost;
    }
    /**
     * @return {?}
     */
    fetchSistemas() {
        return this.http.get(`${this.apiHost.url}/user/GetAllSystems`)
            .pipe(map((response) => response.systems));
    }
}
SistemasService.decorators = [
    { type: Injectable, args: [{
                providedIn: 'root'
            },] }
];
/** @nocollapse */
SistemasService.ctorParameters = () => [
    { type: HttpClient },
    { type: Host, decorators: [{ type: Inject, args: ['apiHostService',] }] }
];
/** @nocollapse */ SistemasService.ngInjectableDef = defineInjectable({ factory: function SistemasService_Factory() { return new SistemasService(inject(HttpClient), inject("apiHostService")); }, token: SistemasService, providedIn: "root" });

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/** @enum {string} */
const SistemasActionTypes = {
    LoadSistemas: '[Sistemas] Load Sistemas Data',
    FetchSistemas: '[Sistemas] Fetch Sistemas Data',
    SistemasFetched: '[Sistemas] Sistemas Data Fetched',
};
class LoadSistemas {
    constructor() {
        this.type = SistemasActionTypes.LoadSistemas;
    }
}
class SistemasFetched {
    /**
     * @param {?} payload
     */
    constructor(payload) {
        this.payload = payload;
        this.type = SistemasActionTypes.SistemasFetched;
    }
}

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/** @type {?} */
const sistemaAdapter = createEntityAdapter();
/** @type {?} */
const sistemasInitialState = sistemaAdapter.getInitialState({
    loaded: false
});
/**
 * @param {?=} state
 * @param {?=} action
 * @return {?}
 */
function sistemasReducer(state = sistemasInitialState, action) {
    switch (action.type) {
        case SistemasActionTypes.SistemasFetched:
            return Object.assign({}, sistemaAdapter.upsertMany(action.payload, state), { loaded: true });
        default:
            return state;
    }
}
const { selectIds, selectEntities, selectAll } = sistemaAdapter.getSelectors();
/** @type {?} */
const selectSistemasIds = selectIds;
/** @type {?} */
const selectSistemasEntities = selectEntities;
/** @type {?} */
const selectAllSistemas = selectAll;
/** @type {?} */
const selectSistema = (id) => {
    return (state) => {
        return state.entities[id];
    };
};
/** @type {?} */
const isLoaded = (state) => {
    return state.loaded;
};
/** @type {?} */
const selectSistemasState = createFeatureSelector('sistemas');

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class SistemasEffects {
    /**
     * @param {?} actions$
     * @param {?} dataPersistence
     * @param {?} service
     */
    constructor(actions$, dataPersistence, service) {
        this.actions$ = actions$;
        this.dataPersistence = dataPersistence;
        this.service = service;
        this.loadPage$ = this.dataPersistence.fetch(SistemasActionTypes.LoadSistemas, {
            run: (action, state) => {
                /** @type {?} */
                const loaded = isLoaded(selectSistemasState(state));
                if (loaded) {
                    return;
                }
                return this.service.fetchSistemas()
                    .pipe(map((sistemas) => new SistemasFetched(sistemas)), take(1));
            },
            onError: (action, error) => {
                console.error('Error', error);
            }
        });
    }
    /**
     * @param {...?} types
     * @return {?}
     */
    ofType(...types) {
        return this.actions$.pipe(filter((action) => types.indexOf(action.type) !== -1));
    }
}
SistemasEffects.decorators = [
    { type: Injectable, args: [{ providedIn: 'root' },] }
];
/** @nocollapse */
SistemasEffects.ctorParameters = () => [
    { type: Actions },
    { type: DataPersistence },
    { type: SistemasService }
];
/** @nocollapse */ SistemasEffects.ngInjectableDef = defineInjectable({ factory: function SistemasEffects_Factory() { return new SistemasEffects(inject(Actions), inject(DataPersistence), inject(SistemasService)); }, token: SistemasEffects, providedIn: "root" });
__decorate([
    Effect(),
    __metadata("design:type", Object)
], SistemasEffects.prototype, "loadPage$", void 0);

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class SistemasFacade {
    /**
     * @param {?} store
     */
    constructor(store) {
        this.store = store;
        this.sistemas$ = this.selectSistemas();
    }
    /**
     * @return {?}
     */
    selectSistemas() {
        return this.store.pipe(select(selectSistemasState), map(selectAllSistemas), tap((sistamas) => {
            if (sistamas.length === 0) {
                this.load();
            }
        }), filter((sistamas) => sistamas.length > 0));
    }
    /**
     * @return {?}
     */
    load() {
        this.store.dispatch(new LoadSistemas);
    }
}
SistemasFacade.decorators = [
    { type: Injectable, args: [{
                providedIn: 'root'
            },] }
];
/** @nocollapse */
SistemasFacade.ctorParameters = () => [
    { type: Store }
];
/** @nocollapse */ SistemasFacade.ngInjectableDef = defineInjectable({ factory: function SistemasFacade_Factory() { return new SistemasFacade(inject(Store)); }, token: SistemasFacade, providedIn: "root" });

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/** @type {?} */
const providers$2 = [
    SistemasService,
    SistemasFacade,
    SistemasEffects
];
class SistemasModule {
    /**
     * @return {?}
     */
    static forRoot() {
        return {
            ngModule: SistemasModule,
            providers: providers$2
        };
    }
}
SistemasModule.decorators = [
    { type: NgModule, args: [{
                declarations: [],
                imports: [
                    CommonModule,
                    HttpClientModule
                ],
                providers: providers$2
            },] }
];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class UsersADService {
    /**
     * @param {?} http
     * @param {?} apiHost
     */
    constructor(http, apiHost) {
        this.http = http;
        this.apiHost = apiHost;
    }
    /**
     * @param {?} userNameAD
     * @return {?}
     */
    getUserAD(userNameAD) {
        /** @type {?} */
        const params = new HttpParams().set('UserNameAD', userNameAD);
        return this.http.get(`${this.apiHost.url}/user/getadusername`, { params }).pipe(map((res) => res.user));
    }
    /**
     * @param {?} userNameAD
     * @return {?}
     */
    getValidUserAD(userNameAD) {
        /** @type {?} */
        const params = new HttpParams().set('UserNameAD', userNameAD);
        return this.http.get(`${this.apiHost.url}/user/getadvalidusername`, { params }).pipe(catchError((error) => {
            /** @type {?} */
            const response = (error instanceof HttpErrorResponse) ? error.error : {
                success: false,
                message: 'Server Error'
            };
            return of(response);
        }));
    }
}
UsersADService.decorators = [
    { type: Injectable, args: [{
                providedIn: 'root'
            },] }
];
/** @nocollapse */
UsersADService.ctorParameters = () => [
    { type: HttpClient },
    { type: Host, decorators: [{ type: Inject, args: ['apiHostService',] }] }
];
/** @nocollapse */ UsersADService.ngInjectableDef = defineInjectable({ factory: function UsersADService_Factory() { return new UsersADService(inject(HttpClient), inject("apiHostService")); }, token: UsersADService, providedIn: "root" });

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/** @enum {string} */
const UsersADActionTypes = {
    UpdateUserADState: '[Users AD] Update Usuario State',
    FetchUserADData: '[Users AD] Fetch Usuario Data',
};
class UpdateUserADState {
    /**
     * @param {?} payload
     */
    constructor(payload) {
        this.payload = payload;
        this.type = UsersADActionTypes.UpdateUserADState;
    }
}
class FetchUserADData {
    /**
     * @param {?} payload
     */
    constructor(payload) {
        this.payload = payload;
        this.type = UsersADActionTypes.FetchUserADData;
    }
}

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
const ɵ0$3 = (usuario) => usuario.samAccountName.toLowerCase();
/** @type {?} */
const usuarioAdapter = createEntityAdapter({
    selectId: ɵ0$3
});
/** @type {?} */
const usersADInitialState = usuarioAdapter.getInitialState();
/**
 * @param {?=} state
 * @param {?=} action
 * @return {?}
 */
function usersADReducer(state = usersADInitialState, action) {
    switch (action.type) {
        case UsersADActionTypes.UpdateUserADState:
            return usuarioAdapter.upsertOne(action.payload, state);
        default:
            return state;
    }
}
const { selectIds: selectIds$1, selectEntities: selectEntities$1, selectAll: selectAll$1 } = usuarioAdapter.getSelectors();
/** @type {?} */
const selectUsersIds = selectIds$1;
/** @type {?} */
const selectUsersEntities = selectEntities$1;
/** @type {?} */
const selectAllUsers = selectAll$1;
/** @type {?} */
const selectUser = (samAccountName) => {
    return (state) => {
        return state.entities[samAccountName.toLowerCase()] || null;
    };
};
/** @type {?} */
const selectUsersADState = createFeatureSelector('usersAD');

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class UsersADFacade {
    /**
     * @param {?} store
     */
    constructor(store) {
        this.store = store;
    }
    /**
     * @param {?} userNameAD
     * @return {?}
     */
    selectUser(userNameAD) {
        return this.store.pipe(select(selectUsersADState), map(selectUser(userNameAD)), distinctUntilChanged(), tap((user) => {
            if (user === null) {
                this.fetchUser(userNameAD);
            }
        }), filter((user) => user !== null));
    }
    /**
     * @param {?} userNameAD
     * @return {?}
     */
    fetchUser(userNameAD) {
        this.store.dispatch(new FetchUserADData(userNameAD));
    }
}
UsersADFacade.decorators = [
    { type: Injectable, args: [{
                providedIn: 'root'
            },] }
];
/** @nocollapse */
UsersADFacade.ctorParameters = () => [
    { type: Store }
];
/** @nocollapse */ UsersADFacade.ngInjectableDef = defineInjectable({ factory: function UsersADFacade_Factory() { return new UsersADFacade(inject(Store)); }, token: UsersADFacade, providedIn: "root" });

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class UsersAdEffects {
    /**
     * @param {?} actions$
     * @param {?} dataPersistence
     * @param {?} service
     */
    constructor(actions$, dataPersistence, service) {
        this.actions$ = actions$;
        this.dataPersistence = dataPersistence;
        this.service = service;
        this.fetchUsers$ = this.dataPersistence.fetch(UsersADActionTypes.FetchUserADData, {
            id: (action, state) => {
                return action.payload;
            },
            run: (action, state) => {
                return this.service.getUserAD(action.payload).pipe(map((user) => new UpdateUserADState(user)), take(1));
            },
            onError: (action, error) => {
                console.error('Error', error);
            }
        });
    }
    /**
     * @param {...?} types
     * @return {?}
     */
    ofType(...types) {
        return this.actions$.pipe(filter((action) => types.indexOf(action.type) !== -1));
    }
}
UsersAdEffects.decorators = [
    { type: Injectable, args: [{ providedIn: 'root' },] }
];
/** @nocollapse */
UsersAdEffects.ctorParameters = () => [
    { type: Actions },
    { type: DataPersistence },
    { type: UsersADService }
];
/** @nocollapse */ UsersAdEffects.ngInjectableDef = defineInjectable({ factory: function UsersAdEffects_Factory() { return new UsersAdEffects(inject(Actions), inject(DataPersistence), inject(UsersADService)); }, token: UsersAdEffects, providedIn: "root" });
__decorate([
    Effect(),
    __metadata("design:type", Object)
], UsersAdEffects.prototype, "fetchUsers$", void 0);

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/** @type {?} */
const providers$3 = [
    UsersADService,
    UsersADFacade,
    UsersAdEffects
];
class UsersADModule {
    /**
     * @return {?}
     */
    static forRoot() {
        return {
            ngModule: UsersADModule,
            providers: providers$3
        };
    }
}
UsersADModule.decorators = [
    { type: NgModule, args: [{
                declarations: [],
                imports: [
                    CommonModule
                ],
                providers: providers$3
            },] }
];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class RolesService {
    /**
     * @param {?} http
     * @param {?} apiHost
     */
    constructor(http, apiHost) {
        this.http = http;
        this.apiHost = apiHost;
    }
    /**
     * @param {?} number
     * @return {?}
     */
    fetchPageData(number) {
        /** @type {?} */
        const params = new HttpParams().set('page', number.toString());
        return this.http.get(`${this.apiHost.url}/user/GetAllRolesByPagination`, { params });
    }
    /**
     * @param {?} systemName
     * @return {?}
     */
    fetchRoleGroupsBySistema(systemName) {
        /** @type {?} */
        const params = new HttpParams().set('system', systemName);
        return this.http.get(`${this.apiHost.url}/user/GetAllRolesBySystem`, { params })
            .pipe(map((response) => response.groups));
    }
    /**
     * @param {?} request
     * @return {?}
     */
    updateUserRoles(request) {
        return this.http.post(`${this.apiHost.url}/user/UpdatePermission`, request);
    }
}
RolesService.decorators = [
    { type: Injectable, args: [{
                providedIn: 'root'
            },] }
];
/** @nocollapse */
RolesService.ctorParameters = () => [
    { type: HttpClient },
    { type: Host, decorators: [{ type: Inject, args: ['apiHostService',] }] }
];
/** @nocollapse */ RolesService.ngInjectableDef = defineInjectable({ factory: function RolesService_Factory() { return new RolesService(inject(HttpClient), inject("apiHostService")); }, token: RolesService, providedIn: "root" });

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/** @enum {string} */
const UpdateUserRoleActionsTypes = {
    inserted: 'inserted',
    deleted: 'deleted',
    none: 'none',
};
class AddUserRoleRequest {
    /**
     * @param {?} email
     * @param {?} role
     */
    constructor(email, role) {
        this.email = email;
        this.role = role;
        this.insertUpdate = true;
    }
}
class RemoveUserRoleRequest {
    /**
     * @param {?} email
     * @param {?} role
     */
    constructor(email, role) {
        this.email = email;
        this.role = role;
        this.insertUpdate = false;
    }
}

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class RolesFacade {
    /**
     * @param {?} store
     */
    constructor(store) {
        this.store = store;
        this.roles$ = this.selectRoles();
        this.groups$ = this.selectRoleGroups();
    }
    /**
     * @return {?}
     */
    selectRoles() {
        return this.store.pipe(select(selectRolesState), map(selectAllRoles));
    }
    /**
     * @return {?}
     */
    selectRoleGroups() {
        return this.store.pipe(select(selectRolesState), select(selectRoleGroupsState), map(selectAllRoleGroups));
    }
    /**
     * @param {?} sistema
     * @return {?}
     */
    selectRolesBySistema(sistema) {
        return this.selectRoleGroups().pipe(map((groups) => {
            return groups.filter((group) => group.systemId === sistema.id);
        }));
    }
    /**
     * @return {?}
     */
    loadPage() {
        this.store.dispatch(new LoadPage);
    }
    /**
     * @param {?} systemName
     * @return {?}
     */
    loadRoleGroupsBySistema(systemName) {
        this.store.dispatch(new FetchRoleGroupsBySistema(systemName));
    }
    /**
     * @param {?} usuario
     * @param {?} rolesNames
     * @return {?}
     */
    insertUserRoles(usuario, rolesNames) {
        /** @type {?} */
        const requests = rolesNames.map((roleName) => new AddUserRoleRequest(usuario.userName, roleName));
        this.store.dispatch(new UpdateUserRoles(requests));
    }
    /**
     * @param {?} usuario
     * @param {?} rolesNames
     * @return {?}
     */
    removeUserRoles(usuario, rolesNames) {
        /** @type {?} */
        const requests = rolesNames.map((roleName) => new RemoveUserRoleRequest(usuario.userName, roleName));
        this.store.dispatch(new UpdateUserRoles(requests));
    }
}
RolesFacade.decorators = [
    { type: Injectable, args: [{
                providedIn: 'root'
            },] }
];
/** @nocollapse */
RolesFacade.ctorParameters = () => [
    { type: Store }
];
/** @nocollapse */ RolesFacade.ngInjectableDef = defineInjectable({ factory: function RolesFacade_Factory() { return new RolesFacade(inject(Store)); }, token: RolesFacade, providedIn: "root" });

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/** @enum {string} */
const UsuariosActionTypes = {
    LoadPage: '[Usuarios] Load Page',
    FetchPageData: '[Usuarios] Fetch Page Data',
    PageDataFetched: '[Usuarios] Page Data Fetched',
    PageDataFetchFailed: '[Usuarios] Page Data Fetch Failed',
    ResetPagination: '[Usuarios] Reset Pagination',
    SelectUsuario: '[Usuarios] Select Usuario',
    UpdateUsuarioState: '[Usuarios] Update Usuario State',
    FetchUsuarioData: '[Usuarios] Fetch Usuario Data',
    CreateUsuario: '[Usuarios] Create Usuario',
    UsuarioCreated: '[Usuarios] Usuario Created',
    UsuarioCreateFailed: '[Usuarios] Usuario Create Failed',
    ToggleAccessUsuario: '[Usuarios] Toggle Access Usuario',
    UsuarioRoleRemoved: '[Usuarios] Usuario Role removed',
    UsuarioRoleInserted: '[Usuarios] Usuario Role inserted',
    UsuarioSubsidiaryRemoved: '[Usuarios] Usuario Subsidiary removed',
    UsuarioSubsidiaryInserted: '[Usuarios] Usuario Subsidiary inserted',
    UpdateUsuarioHostFirewall: '[Usuarios] Update Usuario Host Firewall',
    UsuarioHostFirewallUpdated: '[Usuarios] Usuario Host Firewall Updated',
};
class LoadPage$1 {
    constructor() {
        this.type = UsuariosActionTypes.LoadPage;
    }
}
class PageDataFetched$1 {
    /**
     * @param {?} payload
     */
    constructor(payload) {
        this.payload = payload;
        this.type = UsuariosActionTypes.PageDataFetched;
    }
}
class PageDataFetchFailed$1 {
    /**
     * @param {?} payload
     */
    constructor(payload) {
        this.payload = payload;
        this.type = UsuariosActionTypes.PageDataFetchFailed;
    }
}
class ResetPagination$1 {
    constructor() {
        this.type = UsuariosActionTypes.ResetPagination;
    }
}
class SelectUsuario {
    /**
     * @param {?} payload
     */
    constructor(payload) {
        this.payload = payload;
        this.type = UsuariosActionTypes.SelectUsuario;
    }
}
class UpdateUsuarioState {
    /**
     * @param {?} payload
     */
    constructor(payload) {
        this.payload = payload;
        this.type = UsuariosActionTypes.UpdateUsuarioState;
    }
}
class FetchUsuarioData {
    /**
     * @param {?} payload
     */
    constructor(payload) {
        this.payload = payload;
        this.type = UsuariosActionTypes.FetchUsuarioData;
    }
}
class CreateUsuario {
    /**
     * @param {?} payload
     */
    constructor(payload) {
        this.payload = payload;
        this.type = UsuariosActionTypes.CreateUsuario;
    }
}
class UsuarioCreated {
    /**
     * @param {?} payload
     */
    constructor(payload) {
        this.payload = payload;
        this.type = UsuariosActionTypes.UsuarioCreated;
    }
}
class UsuarioCreateFailed {
    /**
     * @param {?} payload
     */
    constructor(payload) {
        this.payload = payload;
        this.type = UsuariosActionTypes.UsuarioCreateFailed;
    }
}
class ToggleUsuarioAcess {
    /**
     * @param {?} payload
     */
    constructor(payload) {
        this.payload = payload;
        this.type = UsuariosActionTypes.ToggleAccessUsuario;
    }
}
class UsuarioRoleInserted {
    /**
     * @param {?} payload
     */
    constructor(payload) {
        this.payload = payload;
        this.type = UsuariosActionTypes.UsuarioRoleInserted;
    }
}
class UsuarioRoleRemoved {
    /**
     * @param {?} payload
     */
    constructor(payload) {
        this.payload = payload;
        this.type = UsuariosActionTypes.UsuarioRoleRemoved;
    }
}
class UsuarioSubsidiaryInserted {
    /**
     * @param {?} payload
     */
    constructor(payload) {
        this.payload = payload;
        this.type = UsuariosActionTypes.UsuarioSubsidiaryInserted;
    }
}
class UsuarioSubsidiaryRemoved {
    /**
     * @param {?} payload
     */
    constructor(payload) {
        this.payload = payload;
        this.type = UsuariosActionTypes.UsuarioSubsidiaryRemoved;
    }
}
class UpdateUsuarioHostFirewall {
    /**
     * @param {?} payload
     */
    constructor(payload) {
        this.payload = payload;
        this.type = UsuariosActionTypes.UpdateUsuarioHostFirewall;
    }
}
class UsuarioHostFirewallUpdated {
    /**
     * @param {?} payload
     */
    constructor(payload) {
        this.payload = payload;
        this.type = UsuariosActionTypes.UsuarioHostFirewallUpdated;
    }
}

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class UsuarioRoleInsertData {
    /**
     * @param {?} userName
     * @param {?} role
     */
    constructor(userName, role) {
        this.userName = userName;
        this.role = role;
    }
}
class UsuarioRoleRemoveData {
    /**
     * @param {?} userName
     * @param {?} role
     */
    constructor(userName, role) {
        this.userName = userName;
        this.role = role;
    }
}
class UsuarioSubsidiaryInsertData {
    /**
     * @param {?} userName
     * @param {?} subsidiary
     */
    constructor(userName, subsidiary) {
        this.userName = userName;
        this.subsidiary = subsidiary;
    }
}
class UsuarioSubsidiaryRemoveData {
    /**
     * @param {?} userName
     * @param {?} subsidiary
     */
    constructor(userName, subsidiary) {
        this.userName = userName;
        this.subsidiary = subsidiary;
    }
}

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class RolesEffects {
    /**
     * @param {?} actions$
     * @param {?} dataPersistence
     * @param {?} service
     */
    constructor(actions$, dataPersistence, service) {
        this.actions$ = actions$;
        this.dataPersistence = dataPersistence;
        this.service = service;
        this.loadPage$ = this.dataPersistence.fetch(RolesActionTypes.LoadPage, {
            id: (action, state) => {
                return getNextPage(selectRolesState(state));
            },
            run: (action, state) => {
                /** @type {?} */
                const page = getNextPage(selectRolesState(state));
                if (page === null) {
                    return;
                }
                return this.service.fetchPageData(page)
                    .pipe(map((res) => new PageDataFetched(res)), take(1), catchError(error => of(new PageDataFetchFailed(page))));
            },
            onError: (action, error) => {
                console.error('Error', error);
            }
        });
        this.fetchRoleGroupsBySistema$ = this.dataPersistence.fetch(RolesActionTypes.FetchRoleGroupsBySistema, {
            id: (action, state) => {
                return action.payload;
            },
            run: (action, state) => {
                return this.service.fetchRoleGroupsBySistema(action.payload)
                    .pipe(map((groups) => new RoleGroupsFetched(groups)), take(1), catchError(error => of(new FetchRoleGroupsBySistemaFail(action.payload))));
            },
            onError: (action, error) => {
                console.error('Error', error);
            }
        });
        this.updateUserRoles$ = this.dataPersistence.pessimisticUpdate(RolesActionTypes.UpdateUserRoles, {
            run: (action, state) => {
                return this.service.updateUserRoles(action.payload)
                    .pipe(take(1), map((responses) => responses.filter((response) => response.action !== UpdateUserRoleActionsTypes.none)), switchMap((itens) => itens.map((response) => {
                    switch (response.action) {
                        case UpdateUserRoleActionsTypes.inserted:
                            return new UsuarioRoleInserted(new UsuarioRoleInsertData(response.email, selectRole(response.role)(selectRolesState(state))));
                        case UpdateUserRoleActionsTypes.deleted:
                            return new UsuarioRoleRemoved(new UsuarioRoleRemoveData(response.email, selectRole(response.role)(selectRolesState(state))));
                    }
                })));
            },
            onError: (action, error) => {
                console.error('Error', error);
            }
        });
    }
    /**
     * @param {...?} types
     * @return {?}
     */
    ofType(...types) {
        return this.actions$.pipe(filter((action) => types.indexOf(action.type) !== -1));
    }
}
RolesEffects.decorators = [
    { type: Injectable, args: [{ providedIn: 'root' },] }
];
/** @nocollapse */
RolesEffects.ctorParameters = () => [
    { type: Actions },
    { type: DataPersistence },
    { type: RolesService }
];
/** @nocollapse */ RolesEffects.ngInjectableDef = defineInjectable({ factory: function RolesEffects_Factory() { return new RolesEffects(inject(Actions), inject(DataPersistence), inject(RolesService)); }, token: RolesEffects, providedIn: "root" });
__decorate([
    Effect(),
    __metadata("design:type", Object)
], RolesEffects.prototype, "loadPage$", void 0);
__decorate([
    Effect(),
    __metadata("design:type", Object)
], RolesEffects.prototype, "fetchRoleGroupsBySistema$", void 0);
__decorate([
    Effect(),
    __metadata("design:type", Object)
], RolesEffects.prototype, "updateUserRoles$", void 0);

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class SelectRolesComponent extends ObserverComponent {
    /**
     * @param {?} rolesFacade
     * @param {?} sistemasFacade
     */
    constructor(rolesFacade, sistemasFacade) {
        super();
        this.rolesFacade = rolesFacade;
        this.sistemasFacade = sistemasFacade;
        this.insert = new EventEmitter();
        this.remove = new EventEmitter();
        this.selectedSistema$ = new BehaviorSubject(null);
        this.usuarioRoles$ = new BehaviorSubject([]);
        this.rolesList = [];
        this.usuarioRoleGroups = [];
        this.selectedRoles = [];
        this.selectedUsuarioRoles = [];
    }
    /**
     * @param {?} changes
     * @return {?}
     */
    ngOnChanges(changes) {
        this.usuarioRoles$.next(changes.roles.currentValue);
    }
    /**
     * @return {?}
     */
    ngOnInit() {
        this.observe(this.sistemasFacade.sistemas$).subscribe((sistemas) => {
            this.sistemas = sistemas;
        });
        this.observe(this.rolesFacade.roles$).subscribe((roles) => {
            this.rolesList = roles;
        });
        this.sistemasFacade.sistemas$.pipe(take(1)).subscribe((sistemas) => {
            this.selectSistema(sistemas[0]);
        });
        this.observe(this.selectedSistema$.pipe(filter((sistema) => sistema !== null), distinctUntilChanged())).subscribe((sistema) => {
            this.selectedRoles = [];
            this.selectedUsuarioRoles = [];
            this.rolesFacade.loadRoleGroupsBySistema(sistema.name);
        });
        this.roleGroups$ = this.selectedSistema$.pipe(filter((sistema) => sistema !== null), switchMap((sistema) => this.rolesFacade.selectRolesBySistema(sistema)));
        this.observe(combineLatest(this.roleGroups$, this.usuarioRoles$).pipe(map(([groups, roles]) => {
            /** @type {?} */
            const usuarioRolesName = roles.map((role) => role.name);
            return groups.map((group) => {
                return Object.assign({}, group, { roles: group.roles.filter((role) => usuarioRolesName.indexOf(role.name) !== -1) });
            }).filter((group) => {
                return group.roles.length > 0;
            });
        }))).subscribe((usuarioRoleGroups) => {
            this.usuarioRoleGroups = usuarioRoleGroups;
        });
    }
    /**
     * @param {?} rolesNames
     * @return {?}
     */
    insertRoles(rolesNames) {
        /** @type {?} */
        const roles = this.rolesList.filter((role) => rolesNames.indexOf(role.name) !== -1);
        this.insert.emit(roles);
        this.selectedRoles = [];
    }
    /**
     * @param {?} rolesNames
     * @return {?}
     */
    removeRoles(rolesNames) {
        /** @type {?} */
        const roles = this.rolesList.filter((role) => rolesNames.indexOf(role.name) !== -1);
        this.remove.emit(roles);
        this.selectedUsuarioRoles = [];
    }
    /**
     * @param {?} sistema
     * @return {?}
     */
    selectSistema(sistema) {
        this.selectedSistema$.next(sistema);
    }
}
SelectRolesComponent.decorators = [
    { type: Component, args: [{
                selector: 'core-select-roles',
                template: "<div class=\"card\" *ngIf=\"(selectedSistema$ | async) !== null\">\r\n        <div class=\"card-header border-bottom-0\">\r\n            <i class=\"fa fa-key\"></i> {{ 'roles.select.title' | translate }}\r\n        </div>\r\n        <div class=\"card-body bg-light p-0\">\r\n            <div class=\"tab-container\">\r\n                <ul class=\"nav nav-tabs\">\r\n                    <li class=\"nav-item\" *ngFor=\"let sistema of sistemas\" [ngClass]=\"{ active: sistema.id == (selectedSistema$ | async).id }\" >\r\n                        <a\r\n                            class=\"nav-link\"\r\n                            href=\"javascript:;\"\r\n                            [ngClass]=\"{ active: sistema.id == (selectedSistema$ | async).id }\"\r\n                            (click)=\"selectSistema(sistema)\"\r\n                        >\r\n                            {{ sistema.description }}\r\n                        </a>\r\n                    </li>\r\n                </ul>\r\n                <div class=\"tab-content border-bottom-0 border-left-0 border-right-0 px-3 py-4\">\r\n                    <div class=\"form-row\">\r\n                        <div class=\"col-12 col-md-5\">\r\n                            <select [(ngModel)]=\"selectedRoles\" class=\"form-control roles-select\" multiple>\r\n                                <optgroup\r\n                                    *ngFor=\"let group of roleGroups$ | async\"\r\n                                    [label]=\"group.description\"\r\n                                >\r\n                                    <option *ngFor=\"let role of group.roles\" [value]=\"role.name\" [disabled]=\"role | hasRoleInList:roles\" >{{ role.description }}</option>\r\n                                </optgroup>\r\n                            </select>\r\n                        </div>\r\n                        <div class=\"col-12 col-md-2 d-flex flex-column justify-content-center align-items-center my-2\">\r\n                            <div class=\"mb-3\">\r\n                                <button\r\n                                    type=\"button\"\r\n                                    class=\"btn btn-primary\"\r\n                                    [disabled]=\"selectedRoles.length === 0\"\r\n                                    (click)=\"insertRoles(selectedRoles)\"\r\n                                >\r\n                                    >>\r\n                                </button>\r\n                            </div>\r\n                            <div>\r\n                                <button\r\n                                    type=\"button\"\r\n                                    class=\"btn btn-primary\"\r\n                                    [disabled]=\"selectedUsuarioRoles.length === 0\"\r\n                                    (click)=\"removeRoles(selectedUsuarioRoles)\"\r\n                                >\r\n                                    <<\r\n                                </button>\r\n                            </div>\r\n                        </div>\r\n                        <div class=\"col-12 col-md-5\">\r\n                            <select [(ngModel)]=\"selectedUsuarioRoles\" class=\"form-control roles-select\" multiple>\r\n                                    <optgroup\r\n                                    *ngFor=\"let group of usuarioRoleGroups\"\r\n                                    [label]=\"group.description\"\r\n                                >\r\n                                    <option *ngFor=\"let role of group.roles\" [value]=\"role.name\" >{{ role.description }}</option>\r\n                                </optgroup>\r\n                            </select>\r\n                        </div>\r\n                    </div>\r\n                </div>\r\n            </div>\r\n        </div>\r\n    </div>",
                styles: [".roles-select{min-height:50vh}"]
            }] }
];
/** @nocollapse */
SelectRolesComponent.ctorParameters = () => [
    { type: RolesFacade },
    { type: SistemasFacade }
];
SelectRolesComponent.propDecorators = {
    roles: [{ type: Input }],
    insert: [{ type: Output }],
    remove: [{ type: Output }]
};

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class HasRoleInListPipe {
    /**
     * @param {?} role
     * @param {?} roles
     * @return {?}
     */
    transform(role, roles) {
        return roles.filter((userRole) => userRole.name === role.name).length > 0;
    }
}
HasRoleInListPipe.decorators = [
    { type: Pipe, args: [{ name: 'hasRoleInList' },] }
];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/** @type {?} */
const tranlation$2 = {
    'roles': {
        'select': {
            'title': 'Permissões',
        }
    }
};

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/** @type {?} */
const tranlation$3 = {};

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/** @type {?} */
const translations$1 = {
    [LocalesTypes.ptBr]: tranlation$2,
    [LocalesTypes.en]: tranlation$3,
};

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/** @type {?} */
const providers$4 = [
    RolesService,
    RolesFacade,
    RolesEffects
];
const ɵ0$4 = translations$1;
class RolesModule {
    /**
     * @param {?} translateService
     * @param {?} localesService
     */
    constructor(translateService, localesService) {
        localesService.initChild(translateService);
    }
    /**
     * @return {?}
     */
    static forRoot() {
        return {
            ngModule: RolesModule,
            providers: providers$4
        };
    }
}
RolesModule.decorators = [
    { type: NgModule, args: [{
                declarations: [
                    SelectRolesComponent,
                    HasRoleInListPipe
                ],
                exports: [
                    SelectRolesComponent,
                    HasRoleInListPipe
                ],
                imports: [
                    CommonModule,
                    FormsModule,
                    LocalesModule,
                    TranslateModule.forChild({
                        loader: {
                            provide: TranslateLoader,
                            useClass: LocaleLoader
                        },
                        isolate: true
                    }),
                ],
                providers: [
                    ...providers$4,
                    {
                        provide: 'translations',
                        useValue: ɵ0$4
                    }
                ]
            },] }
];
/** @nocollapse */
RolesModule.ctorParameters = () => [
    { type: TranslateService },
    { type: LocalesService }
];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class SubsidiariesService {
    /**
     * @param {?} http
     * @param {?} apiHost
     */
    constructor(http, apiHost) {
        this.http = http;
        this.apiHost = apiHost;
    }
    /**
     * @return {?}
     */
    fetchAll() {
        return this.http.get(`${this.apiHost.url}/Subsidiary/Segment/GetAll`);
    }
    /**
     * @param {?} request
     * @return {?}
     */
    updateUserSubsidiaries(request) {
        return this.http.post(`${this.apiHost.url}/Subsidiary/Segment/UpdateLot`, request);
    }
}
SubsidiariesService.decorators = [
    { type: Injectable, args: [{
                providedIn: 'root'
            },] }
];
/** @nocollapse */
SubsidiariesService.ctorParameters = () => [
    { type: HttpClient },
    { type: Host, decorators: [{ type: Inject, args: ['apiHostService',] }] }
];
/** @nocollapse */ SubsidiariesService.ngInjectableDef = defineInjectable({ factory: function SubsidiariesService_Factory() { return new SubsidiariesService(inject(HttpClient), inject("apiHostService")); }, token: SubsidiariesService, providedIn: "root" });

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/** @enum {string} */
const SubsidiariesActionTypes = {
    FetchAllData: '[Subsidiaries] Fetch All Data',
    DataFetched: '[Subsidiaries] Data Fetched',
    DataFetchFailed: '[Subsidiaries] Data Fetch Failed',
    UpdateUserSubsidiaries: '[Subsidiaries] Update User Subsidiaries',
};
class FetchAllData {
    constructor() {
        this.type = SubsidiariesActionTypes.FetchAllData;
    }
}
class DataFetched {
    /**
     * @param {?} payload
     */
    constructor(payload) {
        this.payload = payload;
        this.type = SubsidiariesActionTypes.DataFetched;
    }
}
class DataFetchFailed {
    constructor() {
        this.type = SubsidiariesActionTypes.DataFetchFailed;
    }
}
class UpdateUserSubsidiaries {
    /**
     * @param {?} payload
     */
    constructor(payload) {
        this.payload = payload;
        this.type = SubsidiariesActionTypes.UpdateUserSubsidiaries;
    }
}

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/** @type {?} */
const subsidiaryAdapter = createEntityAdapter({
    selectId: selectSubsidiaryId
});
/**
 * @param {?} a
 * @return {?}
 */
function selectSubsidiaryId(a) {
    //In this case this would be optional since primary key is id
    return a.segment.id;
}
/** @type {?} */
const subsidiariesInitialState = subsidiaryAdapter.getInitialState();
/**
 * @param {?=} state
 * @param {?=} action
 * @return {?}
 */
function subsidiariesReducer(state = subsidiariesInitialState, action) {
    switch (action.type) {
        case SubsidiariesActionTypes.DataFetched:
            return subsidiaryAdapter.upsertMany(action.payload.data, state);
        default:
            return state;
    }
}
/** @type {?} */
const subsidiariesSelectors = subsidiaryAdapter.getSelectors();
/** @type {?} */
const selectSubsidiariesIds = subsidiariesSelectors.selectIds;
/** @type {?} */
const selectSubsidiariesEntities = subsidiariesSelectors.selectEntities;
/** @type {?} */
const selectAllSubsidiaries = subsidiariesSelectors.selectAll;
/** @type {?} */
const selectSubsidiary = (id) => {
    return (state) => {
        return state.entities[id] || null;
    };
};
/** @type {?} */
const hasSubsidiary = (id, subsidiaries) => subsidiaries.some((subsidiary) => subsidiary.id === id);
/** @type {?} */
const filterSubsidiary = () => { };
/** @type {?} */
const selectSubsidiariesState = createFeatureSelector('subsidiaries');

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/** @enum {string} */
const UpdateUserSubsidiaryActionsTypes = {
    inserted: 'inserted',
    deleted: 'deleted',
    none: 'none',
};
class AddUserSubsidiaryRequest {
    /**
     * @param {?} username
     * @param {?} segmentId
     */
    constructor(username, segmentId) {
        this.username = username;
        this.segmentId = segmentId;
        this.insertUpdate = true;
    }
}
class RemoveUserSubsidiaryRequest {
    /**
     * @param {?} username
     * @param {?} segmentId
     */
    constructor(username, segmentId) {
        this.username = username;
        this.segmentId = segmentId;
        this.insertUpdate = false;
    }
}

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class SubsidiariesFacade {
    /**
     * @param {?} store
     */
    constructor(store) {
        this.store = store;
        this.subsidiaries$ = this.selectSubsidiaries();
    }
    /**
     * @return {?}
     */
    selectSubsidiaries() {
        return this.store.pipe(select(selectSubsidiariesState), map(selectAllSubsidiaries), tap((subsidiaries) => {
            if (subsidiaries.length === 0) {
                this.fetchAll();
            }
        }), filter((subsidiaries) => subsidiaries.length > 0), map((subsidiaries) => subsidiaries.sort((a, b) => a.companyId.toString().localeCompare(b.companyId.toString(), 'en', { numeric: true }) || a.subsidiary.toString().localeCompare(b.subsidiary.toString(), 'en', { numeric: true }))));
    }
    /**
     * @return {?}
     */
    fetchAll() {
        this.store.dispatch(new FetchAllData);
    }
    /**
     * @param {?} usuario
     * @param {?} subsidiariesIds
     * @return {?}
     */
    insertUserSubsidiaries(usuario, subsidiariesIds) {
        /** @type {?} */
        const requests = subsidiariesIds.map((id) => new AddUserSubsidiaryRequest(usuario.userName, id));
        this.store.dispatch(new UpdateUserSubsidiaries(requests));
    }
    /**
     * @param {?} usuario
     * @param {?} subsidiariesIds
     * @return {?}
     */
    removeUserSubsidiaries(usuario, subsidiariesIds) {
        /** @type {?} */
        const requests = subsidiariesIds.map((id) => new RemoveUserSubsidiaryRequest(usuario.userName, id));
        this.store.dispatch(new UpdateUserSubsidiaries(requests));
    }
}
SubsidiariesFacade.decorators = [
    { type: Injectable, args: [{
                providedIn: 'root'
            },] }
];
/** @nocollapse */
SubsidiariesFacade.ctorParameters = () => [
    { type: Store }
];
/** @nocollapse */ SubsidiariesFacade.ngInjectableDef = defineInjectable({ factory: function SubsidiariesFacade_Factory() { return new SubsidiariesFacade(inject(Store)); }, token: SubsidiariesFacade, providedIn: "root" });

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class SubsidiariesEffects {
    /**
     * @param {?} actions$
     * @param {?} dataPersistence
     * @param {?} service
     */
    constructor(actions$, dataPersistence, service) {
        this.actions$ = actions$;
        this.dataPersistence = dataPersistence;
        this.service = service;
        this.fetchAll$ = this.dataPersistence.fetch(SubsidiariesActionTypes.FetchAllData, {
            id: () => SubsidiariesActionTypes.FetchAllData,
            run: (action, state) => {
                return this.service.fetchAll()
                    .pipe(map((res) => new DataFetched(res)), take(1), catchError(error => of(new DataFetchFailed)));
            },
            onError: (action, error) => {
                console.error('Error', error);
            }
        });
        this.updateUserSubsidiaries$ = this.dataPersistence.pessimisticUpdate(SubsidiariesActionTypes.UpdateUserSubsidiaries, {
            run: (action, state) => {
                return this.service.updateUserSubsidiaries(action.payload)
                    .pipe(take(1), map((responses) => responses.filter((response) => response.action !== UpdateUserSubsidiaryActionsTypes.none)), switchMap((itens) => itens.map((response) => {
                    switch (response.action) {
                        case UpdateUserSubsidiaryActionsTypes.inserted:
                            return new UsuarioSubsidiaryInserted(new UsuarioSubsidiaryInsertData(response.email, selectSubsidiary(response.segmentId)(selectSubsidiariesState(state))));
                        case UpdateUserSubsidiaryActionsTypes.deleted:
                            return new UsuarioSubsidiaryRemoved(new UsuarioSubsidiaryRemoveData(response.email, selectSubsidiary(response.segmentId)(selectSubsidiariesState(state))));
                    }
                })));
            },
            onError: (action, error) => {
                console.error('Error', error);
            }
        });
    }
    /**
     * @param {...?} types
     * @return {?}
     */
    ofType(...types) {
        return this.actions$.pipe(filter((action) => types.indexOf(action.type) !== -1));
    }
}
SubsidiariesEffects.decorators = [
    { type: Injectable, args: [{ providedIn: 'root' },] }
];
/** @nocollapse */
SubsidiariesEffects.ctorParameters = () => [
    { type: Actions },
    { type: DataPersistence },
    { type: SubsidiariesService }
];
/** @nocollapse */ SubsidiariesEffects.ngInjectableDef = defineInjectable({ factory: function SubsidiariesEffects_Factory() { return new SubsidiariesEffects(inject(Actions), inject(DataPersistence), inject(SubsidiariesService)); }, token: SubsidiariesEffects, providedIn: "root" });
__decorate([
    Effect(),
    __metadata("design:type", Object)
], SubsidiariesEffects.prototype, "fetchAll$", void 0);
__decorate([
    Effect(),
    __metadata("design:type", Object)
], SubsidiariesEffects.prototype, "updateUserSubsidiaries$", void 0);

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class SelectSubsidiariesComponent {
    /**
     * @param {?} subsidiariesFacade
     */
    constructor(subsidiariesFacade) {
        this.subsidiariesFacade = subsidiariesFacade;
        this.insert = new EventEmitter();
        this.remove = new EventEmitter();
        this.selectedSubsidiaries = [];
        this.selectedUsuarioSubsidiaries = [];
    }
    /**
     * @return {?}
     */
    ngOnInit() {
        this.subsidiariesFacade.selectSubsidiaries().subscribe((subsidiaries) => {
            this.subsidiaryList = subsidiaries;
        });
    }
    /**
     * @param {?} segmentIds
     * @return {?}
     */
    insertSubsidiaries(segmentIds) {
        /** @type {?} */
        const subsidiaries = this.subsidiaryList.filter((subsidiary) => segmentIds.indexOf(subsidiary.segment.id) !== -1);
        this.insert.emit(subsidiaries);
        this.selectedSubsidiaries = [];
    }
    /**
     * @param {?} segmentIds
     * @return {?}
     */
    removeSubsidiaries(segmentIds) {
        /** @type {?} */
        const subsidiaries = this.subsidiaryList.filter((subsidiary) => segmentIds.indexOf(subsidiary.segment.id) !== -1);
        this.remove.emit(subsidiaries);
        this.selectedUsuarioSubsidiaries = [];
    }
    /**
     * @param {?} subsidiary
     * @return {?}
     */
    maskedValue(subsidiary) {
        return "(" + subsidiary.companyId + "/" + subsidiary.subsidiary + ") " + subsidiary.fantasyName;
    }
}
SelectSubsidiariesComponent.decorators = [
    { type: Component, args: [{
                selector: 'core-select-subsidiaries',
                template: "<div class=\"card\">\r\n    <div class=\"card-header border-bottom-0\">\r\n        <i class=\"fa fa-building\"></i> {{ 'subsidiaries.select.title' | translate }}\r\n    </div>\r\n    <div class=\"card-body\">\r\n        <th class=\"py-1 border-top-0\" [attr.colspan]=\"2\">\r\n            <input type=\"search\" class=\"form-control form-control-sm\"\r\n                [placeholder]=\"'subsidiaries.select.search' | translate\" [(ngModel)]=\"searchFilterString\">\r\n        </th>\r\n        <div class=\"form-row\">\r\n            <div class=\"col-12 col-md-5\">\r\n                <select [(ngModel)]=\"selectedSubsidiaries\" class=\"form-control subsidiaries-select\" multiple>\r\n                    <option *ngFor=\"let subsidiary of subsidiaryList | filterSubsidiary:searchFilterString\"\r\n                        [value]=\"subsidiary.segment.id\" [disabled]=\"subsidiary | hasSubsidiary:subsidiaries\">\r\n                        ({{ subsidiary.companyId }}/{{\r\n                        subsidiary.subsidiary }}) - {{ subsidiary.fantasyName }} {{ subsidiary.segment !== null\r\n                        ? \" - (\"+ subsidiary.segment.segment + \" / \" +subsidiary.segment.name + \")\" : \"\"}}</option>\r\n                </select>\r\n            </div>\r\n            <div class=\"col-12 col-md-2 d-flex flex-column justify-content-center align-items-center my-2\">\r\n                <div class=\"mb-3\">\r\n                    <button type=\"button\" class=\"btn btn-primary\" [disabled]=\"selectedSubsidiaries.length === 0\"\r\n                        (click)=\"insertSubsidiaries(selectedSubsidiaries)\">\r\n                        >>\r\n                    </button>\r\n                </div>\r\n                <div>\r\n                    <button type=\"button\" class=\"btn btn-primary\" [disabled]=\"selectedUsuarioSubsidiaries.length === 0\"\r\n                        (click)=\"removeSubsidiaries(selectedUsuarioSubsidiaries)\">\r\n                        << </button>\r\n                </div>\r\n            </div>\r\n            <div class=\"col-12 col-md-5\">\r\n                <select [(ngModel)]=\"selectedUsuarioSubsidiaries\" class=\"form-control subsidiaries-select\" multiple>\r\n                    <option *ngFor=\"let subsidiary of subsidiaries\" [value]=\"subsidiary.segment.id\">({{\r\n                        subsidiary.companyId\r\n                        }}/{{ subsidiary.subsidiary }}) - {{ subsidiary.fantasyName }} {{ subsidiary.segment !== null\r\n                        ? \" - (\"+ subsidiary.segment.segment + \" / \" +subsidiary.segment.name + \")\" : \"\"}}\r\n                    </option>\r\n                </select>\r\n            </div>\r\n        </div>\r\n    </div>\r\n</div>",
                styles: [".subsidiaries-select{min-height:35vh}"]
            }] }
];
/** @nocollapse */
SelectSubsidiariesComponent.ctorParameters = () => [
    { type: SubsidiariesFacade }
];
SelectSubsidiariesComponent.propDecorators = {
    subsidiaries: [{ type: Input }],
    insert: [{ type: Output }],
    remove: [{ type: Output }]
};

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class HasSubsidiaryPipe {
    /**
     * @param {?} subsidiary
     * @param {?} subsidiaries
     * @return {?}
     */
    transform(subsidiary, subsidiaries) {
        return subsidiaries.filter((userSubsidiary) => userSubsidiary.segment && userSubsidiary.segment.id === subsidiary.segment.id).length > 0;
    }
}
HasSubsidiaryPipe.decorators = [
    { type: Pipe, args: [{ name: 'hasSubsidiary' },] }
];
class FilterSubsidiaryPipe {
    /**
     * @param {?} subsidiaries
     * @param {?=} searchText
     * @return {?}
     */
    transform(subsidiaries, searchText = '') {
        if (!subsidiaries)
            return subsidiaries;
        if (!searchText)
            return subsidiaries;
        searchText = searchText.toLowerCase();
        return subsidiaries.filter(item => (item.companyId.toString() + item.subsidiary.toString() + item.fantasyName.toLowerCase() + item.segment.segment + item.segment.name.toLowerCase()).indexOf(searchText) !== -1);
    }
}
FilterSubsidiaryPipe.decorators = [
    { type: Pipe, args: [{ name: 'filterSubsidiary' },] }
];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/** @type {?} */
const tranlation$4 = {
    'subsidiaries': {
        'select': {
            'title': 'Filiais / Segmentos',
            'search': 'Filtrar filial/segmento'
        }
    }
};

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/** @type {?} */
const tranlation$5 = {};

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/** @type {?} */
const translations$2 = {
    [LocalesTypes.ptBr]: tranlation$4,
    [LocalesTypes.en]: tranlation$5,
};

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/** @type {?} */
const providers$5 = [
    SubsidiariesService,
    SubsidiariesFacade,
    SubsidiariesEffects
];
const ɵ0$5 = translations$2;
class SubsidiariesModule {
    /**
     * @param {?} translateService
     * @param {?} localesService
     */
    constructor(translateService, localesService) {
        localesService.initChild(translateService);
    }
    /**
     * @return {?}
     */
    static forRoot() {
        return {
            ngModule: SubsidiariesModule,
            providers: providers$5
        };
    }
}
SubsidiariesModule.decorators = [
    { type: NgModule, args: [{
                declarations: [
                    SelectSubsidiariesComponent,
                    HasSubsidiaryPipe,
                    FilterSubsidiaryPipe
                ],
                exports: [
                    SelectSubsidiariesComponent,
                    HasSubsidiaryPipe,
                    FilterSubsidiaryPipe
                ],
                imports: [
                    CommonModule,
                    FormsModule,
                    LocalesModule,
                    TranslateModule.forChild({
                        loader: {
                            provide: TranslateLoader,
                            useClass: LocaleLoader
                        },
                        isolate: true
                    }),
                ],
                providers: [
                    ...providers$5,
                    {
                        provide: 'translations',
                        useValue: ɵ0$5
                    }
                ]
            },] }
];
/** @nocollapse */
SubsidiariesModule.ctorParameters = () => [
    { type: TranslateService },
    { type: LocalesService }
];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class UsuariosService {
    /**
     * @param {?} http
     * @param {?} apiHost
     */
    constructor(http, apiHost) {
        this.http = http;
        this.apiHost = apiHost;
    }
    /**
     * @param {?} number
     * @return {?}
     */
    fetchPageData(number) {
        /** @type {?} */
        const params = new HttpParams().set('page', number.toString());
        return this.http.get(`${this.apiHost.url}/user/GetAllUsersByPagination`, { params });
    }
    /**
     * @param {?} data
     * @return {?}
     */
    createUsuario(data) {
        return this.http.post(`${this.apiHost.url}/user/create`, data).pipe(map((res) => res.data), catchError((errorResponse) => {
            throw errorResponse.error.message;
        }));
    }
    /**
     * @param {?} usuario
     * @return {?}
     */
    toggleAcessUsuario(usuario) {
        /** @type {?} */
        const LockoutEnabled = !usuario.lockoutEnabled;
        return this.http.post(`${this.apiHost.url}/user/UpdateAccessUserByEmail`, {
            email: usuario.userName,
            LockoutEnabled
        }).pipe(map((res) => {
            if (res.success) {
                return Object.assign({}, usuario, { lockoutEnabled: LockoutEnabled });
            }
            return usuario;
        }));
    }
    /**
     * @param {?} userName
     * @return {?}
     */
    getUsuario(userName) {
        /** @type {?} */
        const params = new HttpParams().set('UserName', userName);
        return this.http.get(`${this.apiHost.url}/user/getusername`, { params }).pipe(map((res) => res.data));
    }
    /**
     * @param {?} request
     * @return {?}
     */
    updateUsuarioHostFirewall(request) {
        return this.http.post(`${this.apiHost.url}/user/UpdateHostFirewallUserByEmail`, request);
    }
}
UsuariosService.decorators = [
    { type: Injectable, args: [{
                providedIn: 'root'
            },] }
];
/** @nocollapse */
UsuariosService.ctorParameters = () => [
    { type: HttpClient },
    { type: Host, decorators: [{ type: Inject, args: ['apiHostService',] }] }
];
/** @nocollapse */ UsuariosService.ngInjectableDef = defineInjectable({ factory: function UsuariosService_Factory() { return new UsuariosService(inject(HttpClient), inject("apiHostService")); }, token: UsuariosService, providedIn: "root" });

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
const ɵ0$6 = (usuario) => usuario.userName;
/** @type {?} */
const usuarioAdapter$1 = createEntityAdapter({
    selectId: ɵ0$6
});
/** @type {?} */
const usuariosInitialState = usuarioAdapter$1.getInitialState({
    currentUsuario: null,
    filters: {},
    metadata: new InitialPaginationMetadata,
});
/** @type {?} */
const insertUsarioRole = (usuario, role) => {
    return Object.assign({}, usuario, { roles: [...usuario.roles, role] });
};
/** @type {?} */
const removeUsuarioRole = (usuario, role) => {
    return Object.assign({}, usuario, { roles: usuario.roles.filter((userRole) => userRole.name !== role.name) });
};
/** @type {?} */
const insertUsarioSubsidiary = (usuario, subsidiary) => {
    return Object.assign({}, usuario, { subsidiaries: [...usuario.subsidiaries, subsidiary] });
};
/** @type {?} */
const removeUsuarioSubsidiary = (usuario, subsidiary) => {
    return Object.assign({}, usuario, { subsidiaries: usuario.subsidiaries.filter((userSubsidiary) => userSubsidiary.segment.id !== subsidiary.segment.id) });
};
/** @type {?} */
const updateHostFirewall = (usuario, ips) => {
    return Object.assign({}, usuario, { hostFirewall: ips.join(',') });
};
/** @type {?} */
const selectUsuario = (userName) => {
    return (state) => {
        return state.entities[userName] || null;
    };
};
/**
 * @param {?=} state
 * @param {?=} action
 * @return {?}
 */
function usuariosReducer(state = usuariosInitialState, action) {
    switch (action.type) {
        case UsuariosActionTypes.PageDataFetched:
            return Object.assign({}, usuarioAdapter$1.upsertMany(action.payload.data, state), { metadata: action.payload.metadata });
        case UsuariosActionTypes.ResetPagination:
            return Object.assign({}, state, resetPagination(state));
        case UsuariosActionTypes.SelectUsuario:
            return Object.assign({}, state, { currentUsuario: action.payload });
        case UsuariosActionTypes.UpdateUsuarioState:
            return usuarioAdapter$1.upsertOne(action.payload, state);
        case UsuariosActionTypes.UsuarioRoleInserted:
            return usuarioAdapter$1.upsertOne(insertUsarioRole(selectUsuario(action.payload.userName)(state), action.payload.role), state);
        case UsuariosActionTypes.UsuarioRoleRemoved:
            return usuarioAdapter$1.upsertOne(removeUsuarioRole(selectUsuario(action.payload.userName)(state), action.payload.role), state);
        case UsuariosActionTypes.UsuarioSubsidiaryInserted:
            return usuarioAdapter$1.upsertOne(insertUsarioSubsidiary(selectUsuario(action.payload.userName)(state), action.payload.subsidiary), state);
        case UsuariosActionTypes.UsuarioSubsidiaryRemoved:
            return usuarioAdapter$1.upsertOne(removeUsuarioSubsidiary(selectUsuario(action.payload.userName)(state), action.payload.subsidiary), state);
        case UsuariosActionTypes.UsuarioHostFirewallUpdated:
            return usuarioAdapter$1.upsertOne(updateHostFirewall(selectUsuario(action.payload.email)(state), action.payload.hostfirewall), state);
        default:
            return state;
    }
}
const { selectIds: selectIds$2, selectEntities: selectEntities$2, selectAll: selectAll$2 } = usuarioAdapter$1.getSelectors();
/** @type {?} */
const selectUsuariosIds = selectIds$2;
/** @type {?} */
const selectUsuariosEntities = selectEntities$2;
/** @type {?} */
const selectAllUsuarios = selectAll$2;
/** @type {?} */
const getCurrentUsuario = (state) => {
    return state.entities[state.currentUsuario] || null;
};
/** @type {?} */
const selectUsuariosState = createFeatureSelector('usuarios');

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class UsuariosFacade {
    /**
     * @param {?} store
     */
    constructor(store) {
        this.store = store;
        this.usuarios$ = this.selectUsuarios();
        this.currentUsuario$ = store.pipe(select(selectUsuariosState), select(getCurrentUsuario));
        this.pagination$ = store.pipe(select(selectUsuariosState), map((state) => state.metadata));
    }
    /**
     * @return {?}
     */
    selectUsuarios() {
        return this.store.pipe(select(selectUsuariosState), map(selectAllUsuarios), share());
    }
    /**
     * @param {?} userName
     * @return {?}
     */
    selectUser(userName) {
        return this.store.pipe(select(selectUsuariosState), map(selectUsuario(userName)), tap((usuario) => {
            if (usuario === null) {
                this.fetchUsuarioData(userName);
            }
        }), filter((usuario) => usuario !== null));
    }
    /**
     * @return {?}
     */
    loadPage() {
        this.store.dispatch(new LoadPage$1);
    }
    /**
     * @return {?}
     */
    resetPagination() {
        this.store.dispatch(new ResetPagination$1);
    }
    /**
     * @param {?} userName
     * @return {?}
     */
    selectCurrentUsuario(userName) {
        this.store.dispatch(new SelectUsuario(userName));
    }
    /**
     * @param {?} userName
     * @return {?}
     */
    fetchUsuarioData(userName) {
        this.store.dispatch(new FetchUsuarioData(userName));
    }
    /**
     * @param {?} data
     * @return {?}
     */
    createUsuario(data) {
        this.store.dispatch(new CreateUsuario(data));
    }
    /**
     * @param {?} usuario
     * @return {?}
     */
    toggleAccessUsuario(usuario) {
        this.store.dispatch(new ToggleUsuarioAcess(usuario));
    }
    /**
     * @param {?} usuario
     * @param {?} ips
     * @return {?}
     */
    updateUsuarioHostFirewall(usuario, ips) {
        /** @type {?} */
        const request = {
            email: usuario.email,
            hostfirewall: ips
        };
        this.store.dispatch(new UpdateUsuarioHostFirewall(request));
    }
}
UsuariosFacade.decorators = [
    { type: Injectable, args: [{
                providedIn: 'root'
            },] }
];
/** @nocollapse */
UsuariosFacade.ctorParameters = () => [
    { type: Store }
];
/** @nocollapse */ UsuariosFacade.ngInjectableDef = defineInjectable({ factory: function UsuariosFacade_Factory() { return new UsuariosFacade(inject(Store)); }, token: UsuariosFacade, providedIn: "root" });

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class UsuariosEffects {
    /**
     * @param {?} actions$
     * @param {?} dataPersistence
     * @param {?} service
     */
    constructor(actions$, dataPersistence, service) {
        this.actions$ = actions$;
        this.dataPersistence = dataPersistence;
        this.service = service;
        this.loadPage$ = this.dataPersistence.fetch(UsuariosActionTypes.LoadPage, {
            id: (action, state) => {
                return getNextPage(selectUsuariosState(state));
            },
            run: (action, state) => {
                /** @type {?} */
                const page = getNextPage(selectUsuariosState(state));
                if (page === null) {
                    return;
                }
                return this.service.fetchPageData(page)
                    .pipe(map((res) => new PageDataFetched$1(res)), take(1), catchError(error => of(new PageDataFetchFailed$1(page))));
            },
            onError: (action, error) => {
                console.error('Error', error);
            }
        });
        this.createUsuario$ = this.dataPersistence.pessimisticUpdate(UsuariosActionTypes.CreateUsuario, {
            run: (action) => {
                return this.service.createUsuario(action.payload)
                    .pipe(map((usuario) => new UsuarioCreated(usuario)), take(1), catchError((error) => of(new UsuarioCreateFailed(error))));
            },
            onError: (action, error) => {
                console.error('Error', error);
            }
        });
        this.usuarioCreated$ = this.dataPersistence.pessimisticUpdate(UsuariosActionTypes.UsuarioCreated, {
            run: (action) => {
                return of(new UpdateUsuarioState(action.payload));
            },
            onError: (action, error) => {
                console.error('Error', error);
            }
        });
        this.selectUsuario$ = this.dataPersistence.fetch(UsuariosActionTypes.SelectUsuario, {
            run: (action, state) => {
                /** @type {?} */
                const usuario = getCurrentUsuario(state.usuarios);
                return of(new FetchUsuarioData(action.payload));
            },
            onError: (action, error) => {
                console.error('Error', error);
            }
        });
        this.fetchUsuario$ = this.dataPersistence.fetch(UsuariosActionTypes.FetchUsuarioData, {
            id: (action, state) => {
                return action.payload;
            },
            run: (action, state) => {
                return this.service.getUsuario(action.payload).pipe(map((usuario) => new UpdateUsuarioState(usuario)), take(1));
            },
            onError: (action, error) => {
                console.error('Error', error);
            }
        });
        this.toggleAcessUsuario$ = this.dataPersistence.pessimisticUpdate(UsuariosActionTypes.ToggleAccessUsuario, {
            run: (action) => {
                return this.service.toggleAcessUsuario(action.payload)
                    .pipe(map((usuario) => new UpdateUsuarioState(usuario)), take(1));
            },
            onError: (action, error) => {
                console.error('Error', error);
            }
        });
        this.updateUsuarioHostFirewall$ = this.dataPersistence.pessimisticUpdate(UsuariosActionTypes.UpdateUsuarioHostFirewall, {
            run: (action) => {
                return this.service.updateUsuarioHostFirewall(action.payload)
                    .pipe(filter((response) => response.success), map(() => new UsuarioHostFirewallUpdated(action.payload)), take(1));
            },
            onError: (action, error) => {
                console.error('Error', error);
            }
        });
    }
    /**
     * @param {...?} types
     * @return {?}
     */
    ofType(...types) {
        return this.actions$.pipe(filter((action) => types.indexOf(action.type) !== -1));
    }
}
UsuariosEffects.decorators = [
    { type: Injectable, args: [{ providedIn: 'root' },] }
];
/** @nocollapse */
UsuariosEffects.ctorParameters = () => [
    { type: Actions },
    { type: DataPersistence },
    { type: UsuariosService }
];
/** @nocollapse */ UsuariosEffects.ngInjectableDef = defineInjectable({ factory: function UsuariosEffects_Factory() { return new UsuariosEffects(inject(Actions), inject(DataPersistence), inject(UsuariosService)); }, token: UsuariosEffects, providedIn: "root" });
__decorate([
    Effect(),
    __metadata("design:type", Object)
], UsuariosEffects.prototype, "loadPage$", void 0);
__decorate([
    Effect(),
    __metadata("design:type", Object)
], UsuariosEffects.prototype, "createUsuario$", void 0);
__decorate([
    Effect(),
    __metadata("design:type", Object)
], UsuariosEffects.prototype, "usuarioCreated$", void 0);
__decorate([
    Effect(),
    __metadata("design:type", Object)
], UsuariosEffects.prototype, "selectUsuario$", void 0);
__decorate([
    Effect(),
    __metadata("design:type", Object)
], UsuariosEffects.prototype, "fetchUsuario$", void 0);
__decorate([
    Effect(),
    __metadata("design:type", Object)
], UsuariosEffects.prototype, "toggleAcessUsuario$", void 0);
__decorate([
    Effect(),
    __metadata("design:type", Object)
], UsuariosEffects.prototype, "updateUsuarioHostFirewall$", void 0);

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class SelectUsuarioPipe {
    /**
     * @param {?} usuariosFacade
     */
    constructor(usuariosFacade) {
        this.usuariosFacade = usuariosFacade;
    }
    /**
     * @param {?} userName
     * @return {?}
     */
    transform(userName) {
        if (userName === null) {
            return null;
        }
        return this.usuariosFacade.selectUser(userName);
    }
}
SelectUsuarioPipe.decorators = [
    { type: Pipe, args: [{ name: 'selectUsuario' },] }
];
/** @nocollapse */
SelectUsuarioPipe.ctorParameters = () => [
    { type: UsuariosFacade }
];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/** @type {?} */
const providers$6 = [
    UsuariosService,
    UsuariosFacade,
    UsuariosEffects
];
class UsuariosModule {
    /**
     * @return {?}
     */
    static forRoot() {
        return {
            ngModule: UsuariosModule,
            providers: providers$6
        };
    }
}
UsuariosModule.decorators = [
    { type: NgModule, args: [{
                declarations: [
                    SelectUsuarioPipe
                ],
                exports: [
                    SelectUsuarioPipe
                ],
                imports: [
                    CommonModule
                ],
                providers: providers$6
            },] }
];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class LocaleInterceptor {
    /**
     * @param {?} translateService
     */
    constructor(translateService) {
        this.translateService = translateService;
    }
    /**
     * @param {?} request
     * @param {?} next
     * @return {?}
     */
    intercept(request, next) {
        return next.handle(request.clone({
            setHeaders: {
                'X-Language': this.translateService.currentLang
            }
        }));
    }
}
LocaleInterceptor.decorators = [
    { type: Injectable }
];
/** @nocollapse */
LocaleInterceptor.ctorParameters = () => [
    { type: TranslateService }
];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
const ɵ0$7 = hostEnvFactory, ɵ1$1 = hostEnvFactory;
/** @type {?} */
const providers$7 = [
    EnvServiceProvider,
    JwtConfig,
    RefreshTokenInterceptor,
    JwtInterceptor,
    LocaleInterceptor,
    SubsidiaryInterceptor,
    {
        provide: 'apiHost',
        useValue: 'apiHost'
    },
    {
        provide: 'apiOauthHost',
        useValue: 'apiOauthHost'
    },
    {
        provide: 'apiHostService',
        useFactory: ɵ0$7,
        deps: [EnvService, [new Inject('apiHost')]]
    },
    {
        provide: 'apiOauthHostService',
        useFactory: ɵ1$1,
        deps: [EnvService, [new Inject('apiOauthHost')]]
    },
];
const ɵ2$1 = jwtOptionsFactory;
class ElisCoreModule {
    /**
     * @return {?}
     */
    static forRoot() {
        return {
            ngModule: ElisCoreModule,
            providers: providers$7
        };
    }
}
ElisCoreModule.decorators = [
    { type: NgModule, args: [{
                declarations: [],
                imports: [
                    NxModule,
                    StoreModule,
                    EffectsModule,
                    AlertModule.forRoot(),
                    LocalesModule.forRoot(),
                    AuthElisModule.forRoot(),
                    SistemasModule.forRoot(),
                    UsersADModule.forRoot(),
                    RolesModule.forRoot(),
                    SubsidiariesModule.forRoot(),
                    UsuariosModule.forRoot(),
                    JwtModule.forRoot({
                        jwtOptionsProvider: {
                            provide: JWT_OPTIONS,
                            useFactory: ɵ2$1,
                            deps: [JwtConfig, AuthFacade]
                        }
                    })
                ],
                exports: [],
                providers: [
                    ...providers$7,
                    {
                        provide: HTTP_INTERCEPTORS,
                        useClass: RefreshTokenInterceptor,
                        multi: true
                    },
                    {
                        provide: HTTP_INTERCEPTORS,
                        useExisting: JwtInterceptor,
                        multi: true
                    },
                    {
                        provide: HTTP_INTERCEPTORS,
                        useExisting: LocaleInterceptor,
                        multi: true
                    }
                ]
            },] }
];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/**
 * @abstract
 */
class ScrollPagination extends ObserverComponent {
    constructor() {
        super(...arguments);
        this.scrollIndex$ = new BehaviorSubject(0);
    }
    /**
     * @param {?} index
     * @return {?}
     */
    changeIndex(index) {
        this.scrollIndex$.next(index);
    }
    /**
     * @template T
     * @param {?} pagination$
     * @return {?}
     */
    selectToLoadPage(pagination$) {
        return merge(pagination$.pipe(isInitialPagination()), this.scrollIndex$.pipe(distinctUntilChanged(), switchMap(index => pagination$.pipe(filterPaginationScrollPosition(index))))).pipe(throttleTime(200));
    }
    /**
     * @return {?}
     */
    ngOnDestroy() {
        super.ngOnDestroy();
        this.scrollIndex$.unsubscribe();
    }
}

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */

export { ObserverComponent, ScrollPagination, EnvService, EnvServiceProvider, hostEnvFactory, Host, AlertModule, AlertComponent, SistemasModule, SistemasService, SistemasFacade, SistemasEffects, SistemasActionTypes, UsersADModule, UsersADService, UsersADFacade, UsersAdEffects, UsersADActionTypes, RolesModule, RolesService, RolesFacade, RolesEffects, RolesActionTypes, SelectRolesComponent, HasRoleInListPipe, translations$1 as RolesTranslations, SubsidiariesModule, SubsidiariesService, SubsidiariesFacade, SubsidiariesEffects, SubsidiariesActionTypes, SelectSubsidiariesComponent, HasSubsidiaryPipe, FilterSubsidiaryPipe, translations$2 as SubsidiariesTranslations, UsuariosModule, UsuariosService, UsuariosFacade, UsuariosEffects, UsuariosActionTypes, SelectUsuarioPipe, AuthElisModule, AuthService, AuthGuardService, GuestGuardService, HasRoleGuardService, AuthFacade, AuthEffects, AuthActionTypes, JwtConfig, jwtOptionsFactory, translations as AuthModuleTranslations, AuthFormComponent, ChangePasswordComponent, HasRolePipe, LocalesModule, LocalesService, LocaleLoader, InitialPaginationMetadata, PaginationActionTypes, PaginationLoaded, ResetPagination, paginationReducer, getFiltersHash, getLastPageLoaded, getNextPage, resetPagination, nextPage, pageLoaded, takePagination, isInitialPagination, filterPaginationScrollPosition, selectPagination, paginationResponseFromPageResponse, ElisCoreModule, AlertTypes, SuccessAlert, ErrorAlert, InfoAlert, WarningAlert, sistemasReducer, selectSistemasIds, selectSistemasEntities, selectAllSistemas, selectSistema, isLoaded, selectSistemasState, usersADReducer, selectUsersIds, selectUsersEntities, selectAllUsers, selectUser, selectUsersADState, UpdateUserRoleActionsTypes, AddUserRoleRequest, RemoveUserRoleRequest, rolesReducer, selectRolesIds, selectRolesEntities, selectAllRoles, selectRoleGroupsIds, selectRoleGroupsEntities, selectAllRoleGroups, selectRoleGroupsState, selectRole, selectRoleGroupsBySistema, hasRole, selectRolesState, UpdateUserSubsidiaryActionsTypes, AddUserSubsidiaryRequest, RemoveUserSubsidiaryRequest, selectSubsidiaryId, subsidiariesReducer, selectSubsidiariesIds, selectSubsidiariesEntities, selectAllSubsidiaries, selectSubsidiary, hasSubsidiary, filterSubsidiary, selectSubsidiariesState, UsuarioRoleInsertData, UsuarioRoleRemoveData, UsuarioSubsidiaryInsertData, UsuarioSubsidiaryRemoveData, usuariosReducer, selectUsuario, selectUsuariosIds, selectUsuariosEntities, selectAllUsuarios, getCurrentUsuario, selectUsuariosState, authReducer, initialState, selectAuthUser, selectUserSubsidiary, selectUserSubsidiarySegment, selectPreferedSubsidiary, selectPreferedSubsidiarySegment, selectAuthState, LocalesTypes, DefaultLocale, ForgotPasswordComponent as ɵc, ResetPasswordComponent as ɵd, RefreshTokenInterceptor as ɵe, SubsidiaryInterceptor as ɵg, EnvServiceFactory as ɵa, LocaleInterceptor as ɵf, TranslateCacheFactory as ɵb };

//# sourceMappingURL=elisconnect-core.js.map