import hash from 'object-hash';
import { TranslateCacheService, TranslateCacheModule, TranslateCacheSettings } from 'ngx-translate-cache';
import { storage } from 'kv-storage-polyfill';
import { JwtHelperService as JwtHelperService$1 } from '@auth0/angular-jwt/src/jwthelper.service';
import { ToastrService } from 'ngx-toastr';
import { Router, ActivatedRoute, RouterModule } from '@angular/router';
import { JwtHelperService, JwtInterceptor, JwtModule, JWT_OPTIONS } from '@auth0/angular-jwt';
import { FormsModule } from '@angular/forms';
import { CommonModule } from '@angular/common';
import { HttpClient, HttpClientModule, HttpParams, HttpErrorResponse, HTTP_INTERCEPTORS } from '@angular/common/http';
import { createEntityAdapter } from '@ngrx/entity';
import { createFeatureSelector, Store, select, StoreModule } from '@ngrx/store';
import { Actions, Effect, ofType, EffectsModule } from '@ngrx/effects';
import { DataPersistence, NxModule } from '@nrwl/nx';
import { Injectable, NgModule, Inject, Component, Input, Pipe, Output, EventEmitter, defineInjectable, inject } from '@angular/core';
import { TranslateService, TranslateModule, TranslateLoader } from '@ngx-translate/core';
import { __extends, __decorate, __metadata, __assign, __spread, __read } from 'tslib';
import { from, of, throwError, Subject, fromEvent, BehaviorSubject, combineLatest, merge } from 'rxjs';
import { take, toArray, switchMap, map, filter, distinctUntilChanged, catchError, tap, takeUntil, mergeMap, share, throttleTime } from 'rxjs/operators';

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
var InitialPaginationMetadata = /** @class */ (function () {
    function InitialPaginationMetadata() {
        this.actual = 0;
        this.pages = 1;
        this.itens = 0;
        this.limitByPage = 1;
        this.lastLoaded = 0;
    }
    return InitialPaginationMetadata;
}());

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/** @enum {string} */
var PaginationActionTypes = {
    PaginationLoaded: '[Pagination] Pagination Loaded',
    ResetPagination: '[Pagination] Reset Pagination',
};
var PaginationLoaded = /** @class */ (function () {
    function PaginationLoaded(payload) {
        this.payload = payload;
        this.type = PaginationActionTypes.PaginationLoaded;
    }
    return PaginationLoaded;
}());
var ResetPagination = /** @class */ (function () {
    function ResetPagination(payload) {
        this.payload = payload;
        this.type = PaginationActionTypes.ResetPagination;
    }
    return ResetPagination;
}());

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/** @type {?} */
var getFiltersHash = function (filters) {
    return hash(filters);
};
var ɵ0 = function (pagination) { return getFiltersHash(pagination.filters); };
/** @type {?} */
var paginationAdapter = createEntityAdapter({
    selectId: ɵ0
});
/** @type {?} */
var paginationInitialState = paginationAdapter.getInitialState();
/** @type {?} */
var getLastPageLoaded = function (pagination) {
    return pagination.metadata.actual;
};
/** @type {?} */
var getNextPage = function (pagination) {
    if (pagination.metadata === null || pagination.metadata.pages === 0) {
        return 1;
    }
    if (getLastPageLoaded(pagination) === pagination.metadata.pages || pagination.metadata.pages === 0) {
        return null;
    }
    return getLastPageLoaded(pagination) + 1;
};
/** @type {?} */
var resetPagination = function (pagination) {
    var metadata = pagination.metadata;
    return __assign({}, pagination, { metadata: __assign({ pages: 1, limitByPage: 1, itens: 0 }, metadata, { actual: 0 }) });
};
/** @type {?} */
var nextPage = function (pagination) {
    var metadata = pagination.metadata;
    /** @type {?} */
    var next = getNextPage(pagination);
    if (next === null) {
        return pagination;
    }
    return __assign({}, pagination, { metadata: __assign({}, metadata, { actual: next }) });
};
/** @type {?} */
var pageLoaded = function (state, loadedPagination) {
    var metadata = loadedPagination.metadata;
    /** @type {?} */
    var lastLoaded = metadata.actual;
    if (state.metadata !== null && state.metadata.lastLoaded > metadata.actual) {
        lastLoaded = state.metadata.lastLoaded;
    }
    return __assign({}, loadedPagination, { metadata: __assign({}, metadata, { lastLoaded: lastLoaded }) });
};
/** @type {?} */
var takePagination = function () { return function (source) { return source.pipe(switchMap(function (_a) {
    var _b = __read(_a, 2), list = _b[0], metadata = _b[1];
    /** @type {?} */
    var to = metadata.actual;
    if (metadata.lastLoaded > metadata.actual) {
        to++;
    }
    /** @type {?} */
    var length = to * metadata.limitByPage;
    if (length > list.length) {
        length = list.length;
    }
    return from(list).pipe(take(length), toArray());
})); }; };
/** @type {?} */
var isInitialPagination = function () { return function (source) { return source.pipe(filter(function (pagination) {
    if (pagination.metadata === null) {
        return true;
    }
    return pagination.metadata.actual === 0;
}), map(function (pagination) { return (/** @type {?} */ (pagination.filters)); })); }; };
/** @type {?} */
var filterPaginationScrollPosition = function (index) { return function (source) { return source.pipe(switchMap(function (pagination) { return of({}).pipe(map(function () { return Math.ceil(index / pagination.metadata.limitByPage); }), filter(function (page) { return page <= pagination.metadata.pages; }), filter(function (page) { return page >= pagination.metadata.actual; }), distinctUntilChanged(), map(function () {
    /** @type {?} */
    var div = index % pagination.metadata.limitByPage;
    return (div >= pagination.metadata.limitByPage * 0.3);
}), distinctUntilChanged(), filter(function (limit) { return limit; }), map(function () { return (/** @type {?} */ (pagination.filters)); })); })); }; };
/** @type {?} */
var selectPagination = function (filters) {
    /** @type {?} */
    var pageHash = getFiltersHash(filters);
    return function (state) {
        return state.entities[pageHash] || {
            filters: filters,
            metadata: null
        };
    };
};
/**
 * @param {?=} state
 * @param {?=} action
 * @return {?}
 */
function paginationReducer(state, action) {
    if (state === void 0) { state = paginationInitialState; }
    if (action === void 0) { action = null; }
    if (action === null) {
        return state;
    }
    switch (action.type) {
        case PaginationActionTypes.PaginationLoaded:
            return paginationAdapter.upsertOne(pageLoaded(selectPagination(action.payload.filters)(state), action.payload), state);
        case PaginationActionTypes.ResetPagination:
            return paginationAdapter.upsertOne(resetPagination(selectPagination(action.payload)(state)), state);
        default:
            return state;
    }
}
/** @type {?} */
var paginationResponseFromPageResponse = function (pageResponse, filters) {
    return {
        pagination: {
            filters: filters,
            metadata: pageResponse.metadata,
        },
        data: pageResponse.data
    };
};

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
var EnvService = /** @class */ (function () {
    function EnvService() {
    }
    /**
     * @param {?} property
     * @return {?}
     */
    EnvService.prototype.get = /**
     * @param {?} property
     * @return {?}
     */
    function (property) {
        return this[property] || null;
    };
    EnvService.decorators = [
        { type: Injectable, args: [{
                    providedIn: 'root'
                },] }
    ];
    /** @nocollapse */ EnvService.ngInjectableDef = defineInjectable({ factory: function EnvService_Factory() { return new EnvService(); }, token: EnvService, providedIn: "root" });
    return EnvService;
}());

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
var Host = /** @class */ (function () {
    function Host(host, protocol) {
        if (protocol === void 0) { protocol = 'https://'; }
        this.host = host;
        this.protocol = protocol;
    }
    Object.defineProperty(Host.prototype, "url", {
        get: /**
         * @return {?}
         */
        function () {
            return "" + this.protocol + this.host;
        },
        enumerable: true,
        configurable: true
    });
    return Host;
}());

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/**
 * @param {?} envService
 * @param {?} envKey
 * @return {?}
 */
function hostEnvFactory(envService, envKey) {
    /** @type {?} */
    var env = (/** @type {?} */ (envService.get(envKey)));
    if (typeof env === 'string') {
        return new Host(env);
    }
    return new Host(env.host, env.protocol);
}

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/** @type {?} */
var EnvServiceFactory = function () {
    /** @type {?} */
    var env = new EnvService();
    /** @type {?} */
    var browserWindow = window || {};
    /** @type {?} */
    var browserWindowEnv = browserWindow['__env'] || {};
    storage.set('env', browserWindowEnv);
    for (var key in browserWindowEnv) {
        if (browserWindowEnv.hasOwnProperty(key)) {
            env[key] = window['__env'][key];
        }
    }
    return env;
};
/** @type {?} */
var EnvServiceProvider = {
    provide: EnvService,
    useFactory: EnvServiceFactory,
    deps: [],
};

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/** @enum {string} */
var AlertTypes = {
    SuccessAlert: '[Alert] Success',
    ErrorAlert: '[Alert] Error',
    InfoAlert: '[Alert] Info',
    WarningAlert: '[Alert] Warning',
};
var SuccessAlert = /** @class */ (function () {
    function SuccessAlert(message) {
        this.message = message;
        this.type = AlertTypes.SuccessAlert;
    }
    return SuccessAlert;
}());
var ErrorAlert = /** @class */ (function () {
    function ErrorAlert(message) {
        this.message = message;
        this.type = AlertTypes.ErrorAlert;
    }
    return ErrorAlert;
}());
var InfoAlert = /** @class */ (function () {
    function InfoAlert(message) {
        this.message = message;
        this.type = AlertTypes.InfoAlert;
    }
    return InfoAlert;
}());
var WarningAlert = /** @class */ (function () {
    function WarningAlert(message) {
        this.message = message;
        this.type = AlertTypes.WarningAlert;
    }
    return WarningAlert;
}());

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
var AlertComponent = /** @class */ (function () {
    function AlertComponent() {
    }
    Object.defineProperty(AlertComponent.prototype, "class", {
        get: /**
         * @return {?}
         */
        function () {
            switch (this.alert.type) {
                case AlertTypes.SuccessAlert:
                    return 'alert-success';
                case AlertTypes.ErrorAlert:
                    return 'alert-danger';
                case AlertTypes.InfoAlert:
                    return 'alert-info';
                case AlertTypes.WarningAlert:
                    return 'alert-warning';
                default:
                    return 'alert-dark';
            }
        },
        enumerable: true,
        configurable: true
    });
    AlertComponent.decorators = [
        { type: Component, args: [{
                    selector: 'core-alert',
                    template: "<div class=\"animated fadeIn\">\r\n    <div class=\"alert\" [ngClass]=\"class\" role=\"alert\">\r\n        {{ alert.message }}\r\n    </div>\r\n</div>"
                }] }
    ];
    /** @nocollapse */
    AlertComponent.ctorParameters = function () { return []; };
    AlertComponent.propDecorators = {
        alert: [{ type: Input }]
    };
    return AlertComponent;
}());

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
var AlertModule = /** @class */ (function () {
    function AlertModule() {
    }
    /**
     * @return {?}
     */
    AlertModule.forRoot = /**
     * @return {?}
     */
    function () {
        return {
            ngModule: AlertModule,
        };
    };
    AlertModule.decorators = [
        { type: NgModule, args: [{
                    imports: [
                        CommonModule
                    ],
                    declarations: [
                        AlertComponent
                    ],
                    exports: [
                        AlertComponent
                    ]
                },] }
    ];
    return AlertModule;
}());

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/** @enum {string} */
var LocalesTypes = {
    ptBr: 'pt-br',
    en: 'en',
    es: 'es',
    fr: 'fr',
};
/** @type {?} */
var DefaultLocale = LocalesTypes.ptBr;

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
var LocalesService = /** @class */ (function () {
    function LocalesService(translateService, translateCacheService) {
        this.translateService = translateService;
        this.translateCacheService = translateCacheService;
    }
    /**
     * @return {?}
     */
    LocalesService.prototype.init = /**
     * @return {?}
     */
    function () {
        this.translateService.setDefaultLang(DefaultLocale);
        this.translateCacheService.init();
    };
    /**
     * @param {?} translateChildService
     * @return {?}
     */
    LocalesService.prototype.initChild = /**
     * @param {?} translateChildService
     * @return {?}
     */
    function (translateChildService) {
        translateChildService.setDefaultLang(DefaultLocale);
        translateChildService.use(this.translateCacheService.getCachedLanguage());
    };
    LocalesService.decorators = [
        { type: Injectable, args: [{
                    providedIn: 'root'
                },] }
    ];
    /** @nocollapse */
    LocalesService.ctorParameters = function () { return [
        { type: TranslateService },
        { type: TranslateCacheService }
    ]; };
    /** @nocollapse */ LocalesService.ngInjectableDef = defineInjectable({ factory: function LocalesService_Factory() { return new LocalesService(inject(TranslateService), inject(TranslateCacheService)); }, token: LocalesService, providedIn: "root" });
    return LocalesService;
}());

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
var LocaleLoader = /** @class */ (function () {
    function LocaleLoader(translations) {
        this.translations = translations;
    }
    /**
     * @param {?} lang
     * @return {?}
     */
    LocaleLoader.prototype.getTranslation = /**
     * @param {?} lang
     * @return {?}
     */
    function (lang) {
        /** @type {?} */
        var translation = this.translations[lang] || this.translations[DefaultLocale];
        return of(translation);
    };
    /** @nocollapse */
    LocaleLoader.ctorParameters = function () { return [
        { type: undefined, decorators: [{ type: Inject, args: ['translations',] }] }
    ]; };
    return LocaleLoader;
}());

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/**
 * @param {?} translateService
 * @param {?} translateCacheSettings
 * @return {?}
 */
function TranslateCacheFactory(translateService, translateCacheSettings) {
    return new TranslateCacheService(translateService, translateCacheSettings);
}
/** @type {?} */
var providers = [
    LocalesService,
    LocaleLoader
];
var LocalesModule = /** @class */ (function () {
    function LocalesModule() {
    }
    /**
     * @return {?}
     */
    LocalesModule.forRoot = /**
     * @return {?}
     */
    function () {
        return {
            ngModule: LocalesModule,
            providers: providers
        };
    };
    LocalesModule.decorators = [
        { type: NgModule, args: [{
                    imports: [
                        TranslateModule.forRoot(),
                        TranslateCacheModule.forRoot({
                            cacheService: {
                                provide: TranslateCacheService,
                                useFactory: TranslateCacheFactory,
                                deps: [TranslateService, TranslateCacheSettings]
                            }
                        })
                    ],
                    declarations: [],
                    providers: providers
                },] }
    ];
    return LocalesModule;
}());

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/** @enum {string} */
var RolesActionTypes = {
    LoadPage: '[Roles] Load Page',
    FetchPageData: '[Roles] Fetch Page Data',
    PageDataFetched: '[Roles] Page Data Fetched',
    PageDataFetchFailed: '[Roles] Page Data Fetch Failed',
    UpdateUserRoles: '[Roles] Update User Roles',
    FetchRoleGroupsBySistema: '[Roles] Fetch Roles Group by Sistema',
    FetchRoleGroupsBySistemaFail: '[Roles] Fetch Roles Group by Sistema Fail',
    RoleGroupsFetched: '[Roles] Roles Group Fetched',
};
var LoadPage = /** @class */ (function () {
    function LoadPage() {
        this.type = RolesActionTypes.LoadPage;
    }
    return LoadPage;
}());
var PageDataFetched = /** @class */ (function () {
    function PageDataFetched(payload) {
        this.payload = payload;
        this.type = RolesActionTypes.PageDataFetched;
    }
    return PageDataFetched;
}());
var PageDataFetchFailed = /** @class */ (function () {
    function PageDataFetchFailed(payload) {
        this.payload = payload;
        this.type = RolesActionTypes.PageDataFetchFailed;
    }
    return PageDataFetchFailed;
}());
var UpdateUserRoles = /** @class */ (function () {
    function UpdateUserRoles(payload) {
        this.payload = payload;
        this.type = RolesActionTypes.UpdateUserRoles;
    }
    return UpdateUserRoles;
}());
var FetchRoleGroupsBySistema = /** @class */ (function () {
    function FetchRoleGroupsBySistema(payload) {
        this.payload = payload;
        this.type = RolesActionTypes.FetchRoleGroupsBySistema;
    }
    return FetchRoleGroupsBySistema;
}());
var RoleGroupsFetched = /** @class */ (function () {
    function RoleGroupsFetched(payload) {
        this.payload = payload;
        this.type = RolesActionTypes.RoleGroupsFetched;
    }
    return RoleGroupsFetched;
}());
var FetchRoleGroupsBySistemaFail = /** @class */ (function () {
    function FetchRoleGroupsBySistemaFail(payload) {
        this.payload = payload;
        this.type = RolesActionTypes.FetchRoleGroupsBySistemaFail;
    }
    return FetchRoleGroupsBySistemaFail;
}());

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
var ɵ0$1 = function (role) { return role.name; };
/** @type {?} */
var roleAdapter = createEntityAdapter({
    selectId: ɵ0$1
});
/** @type {?} */
var roleGroupsAdapter = createEntityAdapter();
/** @type {?} */
var rolesInitialState = roleAdapter.getInitialState({
    filters: {},
    metadata: new InitialPaginationMetadata,
    groups: roleGroupsAdapter.getInitialState()
});
/**
 * @param {?=} state
 * @param {?=} action
 * @return {?}
 */
function rolesReducer(state, action) {
    if (state === void 0) { state = rolesInitialState; }
    switch (action.type) {
        case RolesActionTypes.PageDataFetched:
            return __assign({}, roleAdapter.upsertMany(action.payload.data, state), { metadata: action.payload.metadata });
        case RolesActionTypes.RoleGroupsFetched:
            return __assign({}, roleAdapter.upsertMany(action.payload.map(function (group) { return group.roles; }).flatMap(function (x) { return x; }), state), { groups: roleGroupsAdapter.upsertMany(action.payload, state.groups) });
        default:
            return state;
    }
}
/** @type {?} */
var rolesSelectors = roleAdapter.getSelectors();
/** @type {?} */
var roleGroupsSelectors = roleGroupsAdapter.getSelectors();
/** @type {?} */
var selectRolesIds = rolesSelectors.selectIds;
/** @type {?} */
var selectRolesEntities = rolesSelectors.selectEntities;
/** @type {?} */
var selectAllRoles = rolesSelectors.selectAll;
/** @type {?} */
var selectRoleGroupsIds = roleGroupsSelectors.selectIds;
/** @type {?} */
var selectRoleGroupsEntities = roleGroupsSelectors.selectEntities;
/** @type {?} */
var selectAllRoleGroups = roleGroupsSelectors.selectAll;
/** @type {?} */
var selectRoleGroupsState = createFeatureSelector('groups');
/** @type {?} */
var selectRole = function (name) {
    return function (state) {
        return state.entities[name] || {
            name: name,
            description: name
        };
    };
};
/** @type {?} */
var selectRoleGroupsBySistema = function (id) {
    return function (state) {
        return selectAllRoleGroups(state.groups)
            .filter(function (group) { return group.systemId === id; });
    };
};
/** @type {?} */
var hasRole = function (roleName, roles) { return roles.some(function (role) { return roleName.includes(role.name); }); };
/** @type {?} */
var selectRolesState = createFeatureSelector('roles');

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/** @type {?} */
var key = 'auth';
var AuthService = /** @class */ (function () {
    function AuthService(http, apiHost, jwtHelper, envService) {
        this.http = http;
        this.apiHost = apiHost;
        this.jwtHelper = jwtHelper;
        this.accessRoles = [];
        /** @type {?} */
        var accessRoles = (/** @type {?} */ (envService.get('accessRoles')));
        if (accessRoles !== null) {
            this.accessRoles = accessRoles;
        }
    }
    /**
     * @param {?} credential
     * @return {?}
     */
    AuthService.prototype.login = /**
     * @param {?} credential
     * @return {?}
     */
    function (credential) {
        var _this = this;
        return this.http.post(this.apiHost.url + "/Oauth/login", credential)
            .pipe(map(function (response) {
            if (!response.success) {
                throw response.message;
            }
            if (!_this.hasAcessRole(response.roles)) {
                throw new Error('Acesso não permitido');
            }
            /** @type {?} */
            var user = {
                userName: response.userName,
                name: response.name,
                roles: response.roles,
                access_token: response.access_token,
                refresh_token: response.refresh_token,
                subsidiaries: response.subsidiaries,
                subsidiarySegment: response.subsidiarySegment
            };
            return user;
        }));
    };
    /**
     * @param {?} user
     * @return {?}
     */
    AuthService.prototype.refreshToken = /**
     * @param {?} user
     * @return {?}
     */
    function (user) {
        var _this = this;
        return this.http.post(this.apiHost.url + "/Oauth/refresh", {
            refresh_token: user.refresh_token
        }).pipe(map(function (response) {
            if (!response.success) {
                throw response.message;
            }
            if (!_this.hasAcessRole(response.roles)) {
                throw new Error('Acesso não permitido');
            }
            return {
                userName: response.userName,
                name: response.name,
                roles: response.roles,
                access_token: response.access_token,
                refresh_token: response.refresh_token,
                subsidiaries: response.subsidiaries,
                subsidiarySegment: response.subsidiarySegment
            };
        }));
    };
    /**
     * @param {?} request
     * @return {?}
     */
    AuthService.prototype.changePassword = /**
     * @param {?} request
     * @return {?}
     */
    function (request) {
        return this.http.post(this.apiHost.url + "/Management/ChangePassword", request).pipe(catchError(function (error) { return throwError(error.error.message); }));
    };
    /**
     * @param {?} request
     * @return {?}
     */
    AuthService.prototype.forgotPassword = /**
     * @param {?} request
     * @return {?}
     */
    function (request) {
        return this.http.post(this.apiHost.url + "/Oauth/ForgotPassword", request).pipe(catchError(function (error) { return throwError(error.error.message); }));
    };
    /**
     * @param {?} request
     * @return {?}
     */
    AuthService.prototype.resetPassword = /**
     * @param {?} request
     * @return {?}
     */
    function (request) {
        return this.http.post(this.apiHost.url + "/Oauth/ResetPassword", request).pipe(catchError(function (error) { return throwError(error.error.message); }));
    };
    /**
     * @return {?}
     */
    AuthService.prototype.logout = /**
     * @return {?}
     */
    function () {
        return from(storage.delete(this.stateKey()).then(function () { return true; }));
    };
    /**
     * @return {?}
     */
    AuthService.prototype.getState = /**
     * @return {?}
     */
    function () {
        return from(storage.get(this.stateKey()).then(function (data) {
            if (typeof data === 'undefined') {
                /** @type {?} */
                var loggedOutState = {
                    loggedIn: false,
                    persisted: false,
                    user: null,
                    currentSubsidiary: null,
                    currentSubsidiarySegment: null
                };
                return loggedOutState;
            }
            return data;
        }));
    };
    /**
     * @param {?} access_token
     * @return {?}
     */
    AuthService.prototype.isTokenExpired = /**
     * @param {?} access_token
     * @return {?}
     */
    function (access_token) {
        return this.jwtHelper.isTokenExpired(access_token);
    };
    /**
     * @param {?} state
     * @return {?}
     */
    AuthService.prototype.persistState = /**
     * @param {?} state
     * @return {?}
     */
    function (state) {
        return from(storage.set(this.stateKey(), state).then(function () {
            return true;
        }));
    };
    /**
     * @private
     * @param {?} roles
     * @return {?}
     */
    AuthService.prototype.hasAcessRole = /**
     * @private
     * @param {?} roles
     * @return {?}
     */
    function (roles) {
        if (this.accessRoles.length === 0) {
            return true;
        }
        return this.accessRoles.some(function (role) { return hasRole(role, roles); });
    };
    /**
     * @private
     * @return {?}
     */
    AuthService.prototype.stateKey = /**
     * @private
     * @return {?}
     */
    function () {
        return "access_state_" + key;
    };
    AuthService.decorators = [
        { type: Injectable, args: [{
                    providedIn: 'root',
                },] }
    ];
    /** @nocollapse */
    AuthService.ctorParameters = function () { return [
        { type: HttpClient },
        { type: Host, decorators: [{ type: Inject, args: ['apiOauthHostService',] }] },
        { type: JwtHelperService },
        { type: EnvService }
    ]; };
    /** @nocollapse */ AuthService.ngInjectableDef = defineInjectable({ factory: function AuthService_Factory() { return new AuthService(inject(HttpClient), inject("apiOauthHostService"), inject(JwtHelperService$1), inject(EnvService)); }, token: AuthService, providedIn: "root" });
    return AuthService;
}());

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/** @enum {string} */
var AuthActionTypes = {
    Login: '[Auth] Login',
    LoggedIn: '[Auth] LoggedIn',
    LoginFailed: '[Auth] Login Failed',
    Logout: '[Auth] Logout',
    ClearAuthState: '[Auth] Clear Auth State',
    Loggedout: '[Auth] Loggedout',
    LoadState: '[Auth] Load State',
    StateLoaded: '[Auth] State Loaded',
    PersistState: '[Auth] Persist State',
    StatePersisted: '[Auth] State Persisted',
    RefreshToken: '[Auth] Refresh Token',
    ChangeSubsidiary: '[Auth] Change Current Subsidiary',
    ChangeSubsidiarySegment: '[Auth] Change Current SubsidiarySegment',
    ChangePassword: '[Auth] Change Password',
    PasswordChanged: '[Auth] Password Changed',
    PasswordChangeFailed: '[Auth] Password Change Failed',
    RequestPasswordReset: '[Auth] Request Password Reset',
    PasswordResetRequested: '[Auth] Password Reset Requested',
    PasswordResetRequestFailed: '[Auth] Password Reset Request Failed',
    PasswordReset: '[Auth] Password Reset',
    PasswordReseted: '[Auth] Password Reseted',
    PasswordResetFailed: '[Auth] Password Reset Failed',
};
var Login = /** @class */ (function () {
    function Login(payload) {
        this.payload = payload;
        this.type = AuthActionTypes.Login;
    }
    return Login;
}());
var LoggedIn = /** @class */ (function () {
    function LoggedIn(payload) {
        this.payload = payload;
        this.type = AuthActionTypes.LoggedIn;
    }
    return LoggedIn;
}());
var LoginFailed = /** @class */ (function () {
    function LoginFailed(payload) {
        this.payload = payload;
        this.type = AuthActionTypes.LoginFailed;
    }
    return LoginFailed;
}());
var Logout = /** @class */ (function () {
    function Logout() {
        this.type = AuthActionTypes.Logout;
    }
    return Logout;
}());
var ClearAuthState = /** @class */ (function () {
    function ClearAuthState() {
        this.type = AuthActionTypes.ClearAuthState;
    }
    return ClearAuthState;
}());
var Loggedout = /** @class */ (function () {
    function Loggedout() {
        this.type = AuthActionTypes.Loggedout;
    }
    return Loggedout;
}());
var LoadAuthState = /** @class */ (function () {
    function LoadAuthState() {
        this.type = AuthActionTypes.LoadState;
    }
    return LoadAuthState;
}());
var AuthStateLoaded = /** @class */ (function () {
    function AuthStateLoaded(payload) {
        this.payload = payload;
        this.type = AuthActionTypes.StateLoaded;
    }
    return AuthStateLoaded;
}());
var PersistState = /** @class */ (function () {
    function PersistState(payload) {
        this.payload = payload;
        this.type = AuthActionTypes.PersistState;
    }
    return PersistState;
}());
var StatePersisted = /** @class */ (function () {
    function StatePersisted() {
        this.type = AuthActionTypes.StatePersisted;
    }
    return StatePersisted;
}());
var RefreshToken = /** @class */ (function () {
    function RefreshToken(payload) {
        this.payload = payload;
        this.type = AuthActionTypes.RefreshToken;
    }
    return RefreshToken;
}());
var ChangeSubsidiary = /** @class */ (function () {
    function ChangeSubsidiary(payload) {
        this.payload = payload;
        this.type = AuthActionTypes.ChangeSubsidiary;
    }
    return ChangeSubsidiary;
}());
var ChangeSubsidiarySegment = /** @class */ (function () {
    function ChangeSubsidiarySegment(payload) {
        this.payload = payload;
        this.type = AuthActionTypes.ChangeSubsidiarySegment;
    }
    return ChangeSubsidiarySegment;
}());
var ChangePassword = /** @class */ (function () {
    function ChangePassword(payload) {
        this.payload = payload;
        this.type = AuthActionTypes.ChangePassword;
    }
    return ChangePassword;
}());
var PasswordChanged = /** @class */ (function () {
    function PasswordChanged(payload) {
        this.payload = payload;
        this.type = AuthActionTypes.PasswordChanged;
    }
    return PasswordChanged;
}());
var PasswordChangeFailed = /** @class */ (function () {
    function PasswordChangeFailed(payload) {
        this.payload = payload;
        this.type = AuthActionTypes.PasswordChangeFailed;
    }
    return PasswordChangeFailed;
}());
var RequestPasswordReset = /** @class */ (function () {
    function RequestPasswordReset(payload) {
        this.payload = payload;
        this.type = AuthActionTypes.RequestPasswordReset;
    }
    return RequestPasswordReset;
}());
var PasswordResetRequested = /** @class */ (function () {
    function PasswordResetRequested(payload) {
        this.payload = payload;
        this.type = AuthActionTypes.PasswordResetRequested;
    }
    return PasswordResetRequested;
}());
var PasswordResetRequestFailed = /** @class */ (function () {
    function PasswordResetRequestFailed(payload) {
        this.payload = payload;
        this.type = AuthActionTypes.PasswordResetRequestFailed;
    }
    return PasswordResetRequestFailed;
}());
var PasswordReset = /** @class */ (function () {
    function PasswordReset(payload) {
        this.payload = payload;
        this.type = AuthActionTypes.PasswordReset;
    }
    return PasswordReset;
}());
var PasswordReseted = /** @class */ (function () {
    function PasswordReseted(payload) {
        this.payload = payload;
        this.type = AuthActionTypes.PasswordReseted;
    }
    return PasswordReseted;
}());
var PasswordResetFailed = /** @class */ (function () {
    function PasswordResetFailed(payload) {
        this.payload = payload;
        this.type = AuthActionTypes.PasswordResetFailed;
    }
    return PasswordResetFailed;
}());

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/** @type {?} */
var initialState = {
    loggedIn: null,
    persisted: false,
    user: null,
    currentSubsidiary: null,
    currentSubsidiarySegment: null
};
/** @type {?} */
var selectAuthUser = function (state) {
    return state.user;
};
/** @type {?} */
var selectUserSubsidiary = function (id) {
    return function (state) {
        /** @type {?} */
        var user = selectAuthUser(state);
        /** @type {?} */
        var subsidiaries = user.subsidiaries.filter(function (subsidiary) { return subsidiary.id === id; });
        return subsidiaries.length > 0 ? subsidiaries[0] : user.subsidiaries[0];
    };
};
/** @type {?} */
var selectUserSubsidiarySegment = function (requestIds) {
    return function (state) {
        /** @type {?} */
        var user = selectAuthUser(state);
        // tslint:disable-next-line: max-line-length
        /** @type {?} */
        var subsidiariesSegments = user.subsidiarySegment.filter(function (subsidiarySegment) { return subsidiarySegment.subsidiary.id === requestIds.subsidiaryId && subsidiarySegment.segment.id === requestIds.segmentId; });
        return subsidiariesSegments.length > 0 ? subsidiariesSegments[0] : user.subsidiarySegment[0];
    };
};
/** @type {?} */
var selectPreferedSubsidiary = function (user) {
    return function (state) {
        if (state.currentSubsidiary === null) {
            return user.subsidiaries[0];
        }
        /** @type {?} */
        var subsidiaries = user.subsidiaries.filter(function (subsidiary) { return subsidiary.id === state.currentSubsidiary.id; });
        if (subsidiaries.length === 0) {
            return user.subsidiaries[0];
        }
        return state.currentSubsidiary;
    };
};
/** @type {?} */
var selectPreferedSubsidiarySegment = function (user) {
    return function (state) {
        if (state.currentSubsidiarySegment === null) {
            return user.subsidiarySegment[0];
        }
        // tslint:disable-next-line: max-line-length
        /** @type {?} */
        var subsidiarySegments = user.subsidiarySegment.filter(function (subsidiarySegment) { return subsidiarySegment.subsidiary.id === state.currentSubsidiarySegment.subsidiary.id && subsidiarySegment.segment.id === state.currentSubsidiarySegment.segment.id; });
        if (subsidiarySegments.length === 0) {
            return user.subsidiarySegment[0];
        }
        return state.currentSubsidiarySegment;
    };
};
/**
 * @param {?=} state
 * @param {?=} action
 * @return {?}
 */
function authReducer(state, action) {
    if (state === void 0) { state = initialState; }
    switch (action.type) {
        case AuthActionTypes.StateLoaded:
            return action.payload;
        case AuthActionTypes.Login:
        case AuthActionTypes.RefreshToken:
            return __assign({}, state, { persisted: false });
        case AuthActionTypes.LoggedIn:
            return __assign({}, state, { loggedIn: true, user: action.payload, currentSubsidiary: selectPreferedSubsidiary(action.payload)(state), currentSubsidiarySegment: selectPreferedSubsidiarySegment(action.payload)(state) });
        case AuthActionTypes.LoginFailed:
            return __assign({}, state, { loggedIn: false });
        case AuthActionTypes.ClearAuthState:
            return __assign({}, state, { loggedIn: false, persisted: false, user: null, currentSubsidiary: null, currentSubsidiarySegment: null });
        case AuthActionTypes.StatePersisted:
            return __assign({}, state, { persisted: true });
        case AuthActionTypes.ChangeSubsidiary:
            return __assign({}, state, { currentSubsidiary: selectUserSubsidiary(action.payload)(state) });
        case AuthActionTypes.ChangeSubsidiarySegment:
            return __assign({}, state, { currentSubsidiarySegment: selectUserSubsidiarySegment(action.payload)(state) });
        default:
            return state;
    }
}
/** @type {?} */
var selectAuthState = createFeatureSelector('auth');

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
var AuthFacade = /** @class */ (function () {
    function AuthFacade(store, envService) {
        this.store = store;
        this.envService = envService;
        this.authState$ = this.selectAuthState();
        this.user$ = this.authState$.pipe(map(selectAuthUser));
        this.subsidiary$ = this.authState$.pipe(map(function (state) { return state.currentSubsidiary; }));
        this.subsidiarySegment$ = this.authState$.pipe(map(function (state) { return state.currentSubsidiarySegment; }));
    }
    /**
     * @return {?}
     */
    AuthFacade.prototype.selectAuthState = /**
     * @return {?}
     */
    function () {
        var _this = this;
        return this.store.pipe(select(selectAuthState), filter(function (state) {
            if (state.loggedIn === null) {
                _this.loadState();
                return false;
            }
            return true;
        }));
    };
    /**
     * @return {?}
     */
    AuthFacade.prototype.isLoggedIn = /**
     * @return {?}
     */
    function () {
        return this.authState$.pipe(map(function (state) { return state.loggedIn; }));
    };
    /**
     * @return {?}
     */
    AuthFacade.prototype.selectAccessToken = /**
     * @return {?}
     */
    function () {
        return this.store.pipe(select(selectAuthState), map(function (state) {
            if (state.user === null) {
                return '';
            }
            return state.user.access_token;
        }));
    };
    /**
     * @param {?} role
     * @return {?}
     */
    AuthFacade.prototype.hasRole = /**
     * @param {?} role
     * @return {?}
     */
    function (role) {
        return this.user$.pipe(map(function (user) {
            if (user === null) {
                return false;
            }
            return hasRole(role, user.roles);
        }), take(1));
    };
    /**
     * @param {?} credential
     * @return {?}
     */
    AuthFacade.prototype.login = /**
     * @param {?} credential
     * @return {?}
     */
    function (credential) {
        this.store.dispatch(new Login(credential));
    };
    /**
     * @return {?}
     */
    AuthFacade.prototype.logout = /**
     * @return {?}
     */
    function () {
        this.store.dispatch(new Logout);
    };
    /**
     * @param {?} user
     * @return {?}
     */
    AuthFacade.prototype.refreshToken = /**
     * @param {?} user
     * @return {?}
     */
    function (user) {
        this.store.dispatch(new RefreshToken(user));
    };
    /**
     * @return {?}
     */
    AuthFacade.prototype.loadState = /**
     * @return {?}
     */
    function () {
        this.store.dispatch(new LoadAuthState);
    };
    /**
     * @param {?} id
     * @return {?}
     */
    AuthFacade.prototype.changeCurrentSubsidiary = /**
     * @param {?} id
     * @return {?}
     */
    function (id) {
        this.store.dispatch(new ChangeSubsidiary(id));
    };
    /**
     * @param {?} subsdiaryId
     * @param {?} segmentId
     * @return {?}
     */
    AuthFacade.prototype.changeCurrentSubsidiarySegment = /**
     * @param {?} subsdiaryId
     * @param {?} segmentId
     * @return {?}
     */
    function (subsdiaryId, segmentId) {
        /** @type {?} */
        var changeSubsidiarySegmentRequest = {
            subsidiaryId: subsdiaryId,
            segmentId: segmentId
        };
        this.store.dispatch(new ChangeSubsidiarySegment(changeSubsidiarySegmentRequest));
    };
    /**
     * @param {?} request
     * @return {?}
     */
    AuthFacade.prototype.changePassword = /**
     * @param {?} request
     * @return {?}
     */
    function (request) {
        this.store.dispatch(new ChangePassword(request));
    };
    /**
     * @param {?} userName
     * @return {?}
     */
    AuthFacade.prototype.requestPasswordReset = /**
     * @param {?} userName
     * @return {?}
     */
    function (userName) {
        /** @type {?} */
        var request = {
            linkRoot: this.envService.get('resetPasswordUrl'),
            userName: userName
        };
        this.store.dispatch(new RequestPasswordReset(request));
    };
    /**
     * @param {?} request
     * @return {?}
     */
    AuthFacade.prototype.resetPassword = /**
     * @param {?} request
     * @return {?}
     */
    function (request) {
        this.store.dispatch(new PasswordReset(request));
    };
    AuthFacade.decorators = [
        { type: Injectable, args: [{
                    providedIn: 'root'
                },] }
    ];
    /** @nocollapse */
    AuthFacade.ctorParameters = function () { return [
        { type: Store },
        { type: EnvService }
    ]; };
    /** @nocollapse */ AuthFacade.ngInjectableDef = defineInjectable({ factory: function AuthFacade_Factory() { return new AuthFacade(inject(Store), inject(EnvService)); }, token: AuthFacade, providedIn: "root" });
    return AuthFacade;
}());

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
var AuthGuardService = /** @class */ (function () {
    function AuthGuardService(auth, service, router) {
        this.auth = auth;
        this.service = service;
        this.router = router;
    }
    /**
     * @param {?} route
     * @return {?}
     */
    AuthGuardService.prototype.canActivate = /**
     * @param {?} route
     * @return {?}
     */
    function (route) {
        var _this = this;
        return this.auth.authState$.pipe(filter(function (state) {
            if (state.loggedIn && !state.persisted) {
                return false;
            }
            return true;
        }), filter(function (state) {
            if (state.loggedIn && _this.service.isTokenExpired(state.user.access_token)) {
                _this.auth.refreshToken(state.user);
                return false;
            }
            return true;
        }), map(function (state) {
            return state.loggedIn;
        }), tap(function (loggedIn) {
            if (!loggedIn) {
                _this.router.navigate(['/login']);
            }
        }), take(1));
    };
    /**
     * @param {?} route
     * @return {?}
     */
    AuthGuardService.prototype.canActivateChild = /**
     * @param {?} route
     * @return {?}
     */
    function (route) {
        return this.canActivate(route);
    };
    AuthGuardService.decorators = [
        { type: Injectable, args: [{
                    providedIn: 'root'
                },] }
    ];
    /** @nocollapse */
    AuthGuardService.ctorParameters = function () { return [
        { type: AuthFacade },
        { type: AuthService },
        { type: Router }
    ]; };
    /** @nocollapse */ AuthGuardService.ngInjectableDef = defineInjectable({ factory: function AuthGuardService_Factory() { return new AuthGuardService(inject(AuthFacade), inject(AuthService), inject(Router)); }, token: AuthGuardService, providedIn: "root" });
    return AuthGuardService;
}());

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
var GuestGuardService = /** @class */ (function () {
    function GuestGuardService(auth, router) {
        this.auth = auth;
        this.router = router;
        this.loggedIn$ = auth.isLoggedIn();
    }
    /**
     * @param {?} route
     * @return {?}
     */
    GuestGuardService.prototype.canActivate = /**
     * @param {?} route
     * @return {?}
     */
    function (route) {
        var _this = this;
        return this.loggedIn$.pipe(map(function (loogedIn) {
            if (loogedIn) {
                _this.router.navigate(['/']);
            }
            return !loogedIn;
        }), take(1));
    };
    /**
     * @param {?} route
     * @return {?}
     */
    GuestGuardService.prototype.canActivateChild = /**
     * @param {?} route
     * @return {?}
     */
    function (route) {
        return this.canActivate(route);
    };
    GuestGuardService.decorators = [
        { type: Injectable, args: [{
                    providedIn: 'root'
                },] }
    ];
    /** @nocollapse */
    GuestGuardService.ctorParameters = function () { return [
        { type: AuthFacade },
        { type: Router }
    ]; };
    /** @nocollapse */ GuestGuardService.ngInjectableDef = defineInjectable({ factory: function GuestGuardService_Factory() { return new GuestGuardService(inject(AuthFacade), inject(Router)); }, token: GuestGuardService, providedIn: "root" });
    return GuestGuardService;
}());

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
var HasRoleGuardService = /** @class */ (function () {
    function HasRoleGuardService(auth, router) {
        this.auth = auth;
        this.router = router;
    }
    /**
     * @param {?} route
     * @return {?}
     */
    HasRoleGuardService.prototype.canActivate = /**
     * @param {?} route
     * @return {?}
     */
    function (route) {
        var _this = this;
        if (!route.data.role) {
            return true;
        }
        return this.auth.hasRole(route.data.role).pipe(tap(function (hasRole) {
            if (!hasRole) {
                _this.router.navigate(['/']);
            }
        }), take(1));
    };
    /**
     * @param {?} route
     * @return {?}
     */
    HasRoleGuardService.prototype.canActivateChild = /**
     * @param {?} route
     * @return {?}
     */
    function (route) {
        return this.canActivate(route);
    };
    /**
     * @param {?} route
     * @return {?}
     */
    HasRoleGuardService.prototype.canLoad = /**
     * @param {?} route
     * @return {?}
     */
    function (route) {
        var _this = this;
        if (!route.data.role) {
            return true;
        }
        return this.auth.hasRole(route.data.role).pipe(tap(function (hasRole) {
            if (!hasRole) {
                _this.router.navigate(['/']);
            }
        }));
    };
    HasRoleGuardService.decorators = [
        { type: Injectable, args: [{
                    providedIn: 'root'
                },] }
    ];
    /** @nocollapse */
    HasRoleGuardService.ctorParameters = function () { return [
        { type: AuthFacade },
        { type: Router }
    ]; };
    /** @nocollapse */ HasRoleGuardService.ngInjectableDef = defineInjectable({ factory: function HasRoleGuardService_Factory() { return new HasRoleGuardService(inject(AuthFacade), inject(Router)); }, token: HasRoleGuardService, providedIn: "root" });
    return HasRoleGuardService;
}());

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/**
 * @abstract
 */
var  /**
 * @abstract
 */
ObserverComponent = /** @class */ (function () {
    function ObserverComponent() {
        this.destroy$ = new Subject();
    }
    /**
     * @template T
     * @param {?} observable
     * @return {?}
     */
    ObserverComponent.prototype.observe = /**
     * @template T
     * @param {?} observable
     * @return {?}
     */
    function (observable) {
        return observable.pipe(takeUntil(this.destroy$));
    };
    /**
     * @return {?}
     */
    ObserverComponent.prototype.ngOnDestroy = /**
     * @return {?}
     */
    function () {
        this.destroy$.next(true);
        this.destroy$.unsubscribe();
    };
    return ObserverComponent;
}());

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
var AuthEffects = /** @class */ (function () {
    function AuthEffects(store, actions$, dataPersistence, auth, router, toastr) {
        var _this = this;
        this.store = store;
        this.actions$ = actions$;
        this.dataPersistence = dataPersistence;
        this.auth = auth;
        this.router = router;
        this.toastr = toastr;
        this.login$ = this.dataPersistence.pessimisticUpdate(AuthActionTypes.Login, {
            run: function (action) {
                return _this.auth.login(action.payload)
                    .pipe(map(function (res) { return new LoggedIn(res); }), take(1), catchError(function (error) { return of(new LoginFailed(error)); }));
            },
            onError: function (action, error) {
                console.error('Error', error);
            }
        });
        this.refreshToken$ = this.dataPersistence.pessimisticUpdate(AuthActionTypes.RefreshToken, {
            run: function (action) {
                return _this.auth.refreshToken(action.payload)
                    .pipe(map(function (res) { return new LoggedIn(res); }), take(1), catchError(function (error) { return of(new LoginFailed(error)); }));
            },
            onError: function (action, error) {
                console.error('Error', error);
            }
        });
        this.logout$ = this.dataPersistence.pessimisticUpdate(AuthActionTypes.Logout, {
            run: function (action, state) {
                return _this.auth.logout().pipe(take(1), map(function () { return new ClearAuthState; }));
            },
            onError: function (action, error) {
                console.error('Error', error);
            }
        });
        this.loggedOut$ = this.dataPersistence.pessimisticUpdate(AuthActionTypes.ClearAuthState, {
            run: function (action, state) {
                return from(_this.router.navigate(['/login'])).pipe(map(function () { return new Loggedout; }));
            },
            onError: function (action, error) {
                console.error('Error', error);
            }
        });
        this.loggedIn$ = this.dataPersistence.fetch(AuthActionTypes.LoggedIn, {
            id: function () { return AuthActionTypes.LoggedIn; },
            run: function (action, state) {
                return new PersistState(__assign({}, state.auth, { persisted: true }));
            },
            onError: function (action, error) {
                console.error('Error', error);
            }
        });
        this.changeCurrentSubsidiary$ = this.dataPersistence.fetch(AuthActionTypes.ChangeSubsidiary, {
            id: function () { return AuthActionTypes.ChangeSubsidiary; },
            run: function (action, state) {
                return new PersistState(state.auth);
            },
            onError: function (action, error) {
                console.error('Error', error);
            }
        });
        this.changeCurrentSubsidiarySegment$ = this.dataPersistence.fetch(AuthActionTypes.ChangeSubsidiarySegment, {
            id: function () { return AuthActionTypes.ChangeSubsidiarySegment; },
            run: function (action, state) {
                return new PersistState(state.auth);
            },
            onError: function (action, error) {
                console.error('Error', error);
            }
        });
        this.getState$ = this.dataPersistence.fetch(AuthActionTypes.LoadState, {
            id: function () { return AuthActionTypes.LoadState; },
            run: function (action) {
                return _this.auth.getState().pipe(map(function (data) { return new AuthStateLoaded(data); }), take(1));
            },
            onError: function (action, error) {
                console.error('Error', error);
            }
        });
        this.persistState$ = this.dataPersistence.pessimisticUpdate(AuthActionTypes.PersistState, {
            run: function (action) {
                return _this.auth.persistState(action.payload).pipe(map(function () { return new StatePersisted; }), take(1));
            },
            onError: function (action, error) {
                console.error('Error', error);
            }
        });
        this.changePassword$ = this.dataPersistence.pessimisticUpdate(AuthActionTypes.ChangePassword, {
            run: function (action) {
                return _this.auth.changePassword(action.payload)
                    .pipe(map(function (res) { return new PasswordChanged(res); }), take(1), catchError(function (error) { return of(new PasswordChangeFailed(error)); }));
            },
            onError: function (action, error) {
                console.error('Error', error);
            }
        });
        this.passwordChanged$ = this.dataPersistence.fetch(AuthActionTypes.PasswordChanged, {
            id: function () { return AuthActionTypes.PasswordChanged; },
            run: function (action) {
                var _a = action.payload, success = _a.success, message = _a.message;
                if (success) {
                    _this.toastr.success(message);
                }
                else {
                    _this.toastr.error(message);
                }
            },
            onError: function (action, error) {
                console.error('Error', error);
            }
        });
        this.passwordChangeFailed$ = this.dataPersistence.fetch(AuthActionTypes.PasswordChangeFailed, {
            run: function (action) {
                _this.toastr.error(action.payload);
            },
            onError: function (action, error) {
                console.error('Error', error);
            }
        });
        this.requestPasswordReset$ = this.dataPersistence.pessimisticUpdate(AuthActionTypes.RequestPasswordReset, {
            run: function (action) {
                return _this.auth.forgotPassword(action.payload)
                    .pipe(map(function (res) {
                    var success = res.success, message = res.message;
                    return success ? new PasswordResetRequested(res) : new PasswordResetRequestFailed(message);
                }), take(1), catchError(function (error) { return of(new PasswordResetRequestFailed(error)); }));
            },
            onError: function (action, error) {
                console.error('Error', error);
            }
        });
        this.passwordResetRequested$ = this.dataPersistence.fetch(AuthActionTypes.PasswordResetRequested, {
            run: function (action) {
                var _a = action.payload, success = _a.success, message = _a.message;
                _this.toastr.success(message);
            },
            onError: function (action, error) {
                console.error('Error', error);
            }
        });
        this.passwordResetRequestFailed$ = this.dataPersistence.fetch(AuthActionTypes.PasswordResetRequestFailed, {
            run: function (action) {
                _this.toastr.error(action.payload);
            },
            onError: function (action, error) {
                console.error('Error', error);
            }
        });
        this.resetPassword$ = this.dataPersistence.pessimisticUpdate(AuthActionTypes.PasswordReset, {
            run: function (action) {
                return _this.auth.resetPassword(action.payload)
                    .pipe(map(function (res) {
                    var success = res.success, message = res.message;
                    return success ? new PasswordReseted(res) : new PasswordResetFailed(message);
                }), take(1), catchError(function (error) { return of(new PasswordResetFailed(error)); }));
            },
            onError: function (action, error) {
                console.error('Error', error);
            }
        });
        this.passwordReseted$ = this.dataPersistence.fetch(AuthActionTypes.PasswordReseted, {
            run: function (action) {
                var _a = action.payload, success = _a.success, message = _a.message;
                if (success) {
                    _this.toastr.success(message);
                }
                else {
                    _this.toastr.error(message);
                }
            },
            onError: function (action, error) {
                console.error('Error', error);
            }
        });
        this.passwordResetFailed$ = this.dataPersistence.fetch(AuthActionTypes.PasswordResetFailed, {
            run: function (action) {
                _this.toastr.error(action.payload);
            },
            onError: function (action, error) {
                console.error('Error', error);
            }
        });
        if (navigator.serviceWorker) {
            fromEvent(navigator.serviceWorker, 'message').pipe(map(function (event) { return event.data; }), filter(function (data) { return typeof data.type !== 'undefined' && data.type === AuthActionTypes.LoggedIn; }), map(function (data) { return data.payload; })).subscribe(function (user) {
                _this.store.dispatch(new LoggedIn(user));
            });
        }
    }
    /**
     * @param {...?} types
     * @return {?}
     */
    AuthEffects.prototype.ofType = /**
     * @param {...?} types
     * @return {?}
     */
    function () {
        var types = [];
        for (var _i = 0; _i < arguments.length; _i++) {
            types[_i] = arguments[_i];
        }
        return this.actions$.pipe(ofType.apply(void 0, __spread(types)));
    };
    AuthEffects.decorators = [
        { type: Injectable, args: [{ providedIn: 'root' },] }
    ];
    /** @nocollapse */
    AuthEffects.ctorParameters = function () { return [
        { type: Store },
        { type: Actions },
        { type: DataPersistence },
        { type: AuthService },
        { type: Router },
        { type: ToastrService }
    ]; };
    /** @nocollapse */ AuthEffects.ngInjectableDef = defineInjectable({ factory: function AuthEffects_Factory() { return new AuthEffects(inject(Store), inject(Actions), inject(DataPersistence), inject(AuthService), inject(Router), inject(ToastrService)); }, token: AuthEffects, providedIn: "root" });
    __decorate([
        Effect(),
        __metadata("design:type", Object)
    ], AuthEffects.prototype, "login$", void 0);
    __decorate([
        Effect(),
        __metadata("design:type", Object)
    ], AuthEffects.prototype, "refreshToken$", void 0);
    __decorate([
        Effect(),
        __metadata("design:type", Object)
    ], AuthEffects.prototype, "logout$", void 0);
    __decorate([
        Effect(),
        __metadata("design:type", Object)
    ], AuthEffects.prototype, "loggedOut$", void 0);
    __decorate([
        Effect(),
        __metadata("design:type", Object)
    ], AuthEffects.prototype, "loggedIn$", void 0);
    __decorate([
        Effect(),
        __metadata("design:type", Object)
    ], AuthEffects.prototype, "changeCurrentSubsidiary$", void 0);
    __decorate([
        Effect(),
        __metadata("design:type", Object)
    ], AuthEffects.prototype, "changeCurrentSubsidiarySegment$", void 0);
    __decorate([
        Effect(),
        __metadata("design:type", Object)
    ], AuthEffects.prototype, "getState$", void 0);
    __decorate([
        Effect(),
        __metadata("design:type", Object)
    ], AuthEffects.prototype, "persistState$", void 0);
    __decorate([
        Effect(),
        __metadata("design:type", Object)
    ], AuthEffects.prototype, "changePassword$", void 0);
    __decorate([
        Effect(),
        __metadata("design:type", Object)
    ], AuthEffects.prototype, "passwordChanged$", void 0);
    __decorate([
        Effect(),
        __metadata("design:type", Object)
    ], AuthEffects.prototype, "passwordChangeFailed$", void 0);
    __decorate([
        Effect(),
        __metadata("design:type", Object)
    ], AuthEffects.prototype, "requestPasswordReset$", void 0);
    __decorate([
        Effect(),
        __metadata("design:type", Object)
    ], AuthEffects.prototype, "passwordResetRequested$", void 0);
    __decorate([
        Effect(),
        __metadata("design:type", Object)
    ], AuthEffects.prototype, "passwordResetRequestFailed$", void 0);
    __decorate([
        Effect(),
        __metadata("design:type", Object)
    ], AuthEffects.prototype, "resetPassword$", void 0);
    __decorate([
        Effect(),
        __metadata("design:type", Object)
    ], AuthEffects.prototype, "passwordReseted$", void 0);
    __decorate([
        Effect(),
        __metadata("design:type", Object)
    ], AuthEffects.prototype, "passwordResetFailed$", void 0);
    return AuthEffects;
}());

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
var AuthFormComponent = /** @class */ (function (_super) {
    __extends(AuthFormComponent, _super);
    function AuthFormComponent(router, facade, effects) {
        var _this = _super.call(this) || this;
        _this.router = router;
        _this.facade = facade;
        _this.effects = effects;
        _this.alert = null;
        _this.submiting = false;
        return _this;
    }
    /**
     * @return {?}
     */
    AuthFormComponent.prototype.ngOnInit = /**
     * @return {?}
     */
    function () {
        var _this = this;
        this.observe(this.effects.ofType(AuthActionTypes.Login)).subscribe(function () {
            _this.submiting = true;
            _this.alert = null;
        });
        this.observe(this.effects.ofType(AuthActionTypes.LoginFailed)).subscribe(function (action) {
            _this.submiting = false;
            _this.alert = new ErrorAlert(action.payload);
        });
        this.observe(this.effects.ofType(AuthActionTypes.LoggedIn).pipe(switchMap(function () { return _this.effects.ofType(AuthActionTypes.StatePersisted); }))).subscribe(function () {
            _this.router.navigate(['/']);
            _this.submiting = false;
        });
    };
    /**
     * @param {?} credential
     * @return {?}
     */
    AuthFormComponent.prototype.onSubmit = /**
     * @param {?} credential
     * @return {?}
     */
    function (credential) {
        this.facade.login(credential);
    };
    AuthFormComponent.decorators = [
        { type: Component, args: [{
                    selector: 'core-auth-form',
                    template: "<form #formRef=\"ngForm\" (ngSubmit)=\"onSubmit(formRef.value)\">\r\n    <h1>{{ 'core.auth.login.title' | translate }}</h1>\r\n    <p class=\"text-muted\">{{ 'core.auth.login.subtitle' | translate  }}</p>\r\n    <div class=\"input-group mb-3\">\r\n        <div class=\"input-group-prepend\">\r\n            <span class=\"input-group-text\"><i class=\"icon-user\"></i></span>\r\n        </div>\r\n        <input type=\"email\" [(ngModel)]=\"UserName\" name=\"UserName\" class=\"form-control\" [placeholder]=\"'core.auth.login.username' | translate  \" autocomplete=\"username\" required>\r\n    </div>\r\n    <div class=\"input-group mb-4\">\r\n        <div class=\"input-group-prepend\">\r\n            <span class=\"input-group-text\"><i class=\"icon-lock\"></i></span>\r\n        </div>\r\n        <input type=\"password\" [(ngModel)]=\"Password\" name=\"Password\" class=\"form-control\" [placeholder]=\"'core.auth.login.password' | translate \" autocomplete=\"current-password\" required>\r\n    </div>\r\n    <div class=\"row\" *ngIf=\"alert !== null\">\r\n        <div class=\"col-12\">\r\n            <core-alert [alert]=\"alert\" ></core-alert>\r\n        </div>\r\n    </div>\r\n    <div class=\"form-row\">\r\n        <div class=\"col-6\">\r\n            <button type=\"submit\" class=\"btn btn-primary px-4\" [disabled]=\"!formRef.valid || submiting\">\r\n                <span *ngIf=\"!submiting\">{{ 'core.auth.login.submit' | translate  }}</span>\r\n                <span *ngIf=\"submiting\"><i class=\"fa fa-circle-o-notch fa-spin\"></i></span>\r\n            </button>\r\n        </div>\r\n        <div class=\"col-6 d-flex justify-content-end\">\r\n            <a class=\"btn btn-link px-0\" [routerLink]=\"['forgot-password']\">{{ 'core.auth.login.forgotPassword' | translate  }}</a>\r\n        </div>\r\n    </div>\r\n</form>\r\n"
                }] }
    ];
    /** @nocollapse */
    AuthFormComponent.ctorParameters = function () { return [
        { type: Router },
        { type: AuthFacade },
        { type: AuthEffects }
    ]; };
    return AuthFormComponent;
}(ObserverComponent));

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
var ChangePasswordComponent = /** @class */ (function (_super) {
    __extends(ChangePasswordComponent, _super);
    function ChangePasswordComponent(facade, effects) {
        var _this = _super.call(this) || this;
        _this.facade = facade;
        _this.effects = effects;
        _this.oldPassword = '';
        _this.newPassword = '';
        _this.confirmPassword = '';
        _this.submiting = false;
        return _this;
    }
    /**
     * @return {?}
     */
    ChangePasswordComponent.prototype.ngOnInit = /**
     * @return {?}
     */
    function () {
        var _this = this;
        this.observe(this.effects.ofType(AuthActionTypes.ChangePassword)).subscribe(function () {
            _this.submiting = true;
        });
        this.observe(this.effects.ofType(AuthActionTypes.PasswordChanged, AuthActionTypes.PasswordChangeFailed)).subscribe(function () {
            _this.submiting = false;
        });
        this.observe(this.effects.ofType(AuthActionTypes.PasswordChanged)).subscribe(function () {
            _this.oldPassword = '';
            _this.newPassword = '';
            _this.confirmPassword = '';
        });
    };
    /**
     * @param {?} data
     * @return {?}
     */
    ChangePasswordComponent.prototype.onSubmit = /**
     * @param {?} data
     * @return {?}
     */
    function (data) {
        this.facade.changePassword(data);
    };
    ChangePasswordComponent.decorators = [
        { type: Component, args: [{
                    selector: 'core-change-password',
                    template: "<form #formRef=\"ngForm\" (ngSubmit)=\"onSubmit(formRef.value)\">\r\n    <div class=\"row\">\r\n        <div class=\"col-12\">\r\n            <h3>{{ 'core.auth.changePassword.title' | translate }}</h3>\r\n        </div>\r\n    </div>\r\n    <div class=\"row\">\r\n        <div class=\"col-12\">\r\n            <div class=\"form-group\">\r\n                <label>{{ 'core.auth.changePassword.oldPassword' | translate }}</label>\r\n                <input type=\"password\" [(ngModel)]=\"oldPassword\" name=\"oldPassword\" class=\"form-control\" required>\r\n            </div>\r\n        </div>\r\n        <div class=\"col-12\">\r\n            <div class=\"form-group\">\r\n                <label>{{ 'core.auth.changePassword.newPassword' | translate }}</label>\r\n                <input type=\"password\" [(ngModel)]=\"newPassword\" name=\"newPassword\" class=\"form-control\" required>\r\n            </div>\r\n        </div>\r\n        <div class=\"col-12\">\r\n            <div class=\"form-group\">\r\n                <label>{{ 'core.auth.changePassword.confirmPassword' | translate }}</label>\r\n                <input type=\"password\" [(ngModel)]=\"confirmPassword\" name=\"confirmPassword\" class=\"form-control\" required>\r\n            </div>\r\n        </div>\r\n    </div>\r\n    <div class=\"row\">\r\n        <div class=\"col-12\">\r\n            <button type=\"submit\" class=\"btn btn-primary\" [disabled]=\"!formRef.valid || submiting\">\r\n                <span *ngIf=\"!submiting\">{{ 'core.auth.changePassword.submit' | translate }}</span>\r\n                <span *ngIf=\"submiting\"><i class=\"fa fa-circle-o-notch fa-spin\"></i></span>\r\n            </button>\r\n        </div>\r\n    </div>\r\n</form>"
                }] }
    ];
    /** @nocollapse */
    ChangePasswordComponent.ctorParameters = function () { return [
        { type: AuthFacade },
        { type: AuthEffects }
    ]; };
    return ChangePasswordComponent;
}(ObserverComponent));

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
var HasRolePipe = /** @class */ (function () {
    function HasRolePipe(authFacade) {
        this.authFacade = authFacade;
    }
    /**
     * @param {?} role
     * @return {?}
     */
    HasRolePipe.prototype.transform = /**
     * @param {?} role
     * @return {?}
     */
    function (role) {
        return this.authFacade.hasRole(role);
    };
    HasRolePipe.decorators = [
        { type: Pipe, args: [{ name: 'hasRole' },] }
    ];
    /** @nocollapse */
    HasRolePipe.ctorParameters = function () { return [
        { type: AuthFacade }
    ]; };
    return HasRolePipe;
}());

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/** @type {?} */
var tranlation = {
    'core': {
        'auth': {
            'login': {
                'title': 'Login',
                'subtitle': 'Entre com a sua conta',
                'username': 'Usuário',
                'password': 'Senha',
                'forgotPassword': 'Esqueci minha senha',
                'submit': 'Entrar'
            },
            'changePassword': {
                'title': 'Alterar Senha',
                'oldPassword': 'Senha Atual',
                'newPassword': 'Nova Senha',
                'confirmPassword': 'Confirmar Senha',
                'submit': 'Alterar Senha'
            },
            'forgotPassword': {
                'title': 'Esqueci minha senha',
                'userName': 'E-mail',
                'submit': 'Recuperar senha'
            },
            'resetPassword': {
                'title': 'Redefinir Senha',
                'password': 'Nova Senha',
                'submit': 'Salvar'
            }
        }
    }
};

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/** @type {?} */
var tranlation$1 = {};

var _a;
/** @type {?} */
var translations = (_a = {},
    _a[LocalesTypes.ptBr] = tranlation,
    _a[LocalesTypes.en] = tranlation$1,
    _a);

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
var ForgotPasswordComponent = /** @class */ (function (_super) {
    __extends(ForgotPasswordComponent, _super);
    function ForgotPasswordComponent(router, facade, effects) {
        var _this = _super.call(this) || this;
        _this.router = router;
        _this.facade = facade;
        _this.effects = effects;
        _this.userName = '';
        _this.submiting = false;
        return _this;
    }
    /**
     * @return {?}
     */
    ForgotPasswordComponent.prototype.ngOnInit = /**
     * @return {?}
     */
    function () {
        var _this = this;
        this.observe(this.effects.ofType(AuthActionTypes.RequestPasswordReset)).subscribe(function () {
            _this.submiting = true;
        });
        this.observe(this.effects.ofType(AuthActionTypes.PasswordResetRequested, AuthActionTypes.PasswordResetRequestFailed)).subscribe(function () {
            _this.submiting = false;
        });
        this.observe(this.effects.ofType(AuthActionTypes.PasswordResetRequested).pipe(take(1))).subscribe(function () {
            _this.router.navigate(['/login']);
        });
    };
    /**
     * @param {?} userName
     * @return {?}
     */
    ForgotPasswordComponent.prototype.onSubmit = /**
     * @param {?} userName
     * @return {?}
     */
    function (userName) {
        this.facade.requestPasswordReset(userName);
    };
    ForgotPasswordComponent.decorators = [
        { type: Component, args: [{
                    selector: 'core-forgot-password',
                    template: "<form #formRef=\"ngForm\" (ngSubmit)=\"onSubmit(formRef.value.userName)\">\r\n    <div class=\"row mb-4\">\r\n        <div class=\"col-12\">\r\n            <h3>{{ 'core.auth.forgotPassword.title' | translate }}</h3>\r\n        </div>\r\n    </div>\r\n    <div class=\"row mb-3\">\r\n        <div class=\"col-12\">\r\n            <div class=\"form-group\">\r\n                <input type=\"email\" [(ngModel)]=\"userName\" name=\"userName\" class=\"form-control\" [placeholder]=\"'core.auth.forgotPassword.userName' | translate\" required>\r\n            </div>\r\n        </div>\r\n    </div>\r\n    <div class=\"row\">\r\n        <div class=\"col-12\">\r\n            <button type=\"submit\" class=\"btn btn-primary\" [disabled]=\"!formRef.valid || submiting\">\r\n                <span *ngIf=\"!submiting\">{{ 'core.auth.forgotPassword.submit' | translate }}</span>\r\n                <span *ngIf=\"submiting\"><i class=\"fa fa-circle-o-notch fa-spin\"></i></span>\r\n            </button>\r\n        </div>\r\n    </div>\r\n</form>"
                }] }
    ];
    /** @nocollapse */
    ForgotPasswordComponent.ctorParameters = function () { return [
        { type: Router },
        { type: AuthFacade },
        { type: AuthEffects }
    ]; };
    return ForgotPasswordComponent;
}(ObserverComponent));

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
var ResetPasswordComponent = /** @class */ (function (_super) {
    __extends(ResetPasswordComponent, _super);
    function ResetPasswordComponent(router, activedRoute, facade, effects) {
        var _this = _super.call(this) || this;
        _this.router = router;
        _this.activedRoute = activedRoute;
        _this.facade = facade;
        _this.effects = effects;
        _this.userId = '';
        _this.code = '';
        _this.password = '';
        _this.submiting = false;
        return _this;
    }
    /**
     * @return {?}
     */
    ResetPasswordComponent.prototype.ngOnInit = /**
     * @return {?}
     */
    function () {
        var _this = this;
        this.observe(this.activedRoute.queryParams).subscribe(function (params) {
            var userId = params.userId, code = params.code;
            _this.userId = userId;
            _this.code = code;
        });
        this.observe(this.effects.ofType(AuthActionTypes.PasswordReset)).subscribe(function () {
            _this.submiting = true;
        });
        this.observe(this.effects.ofType(AuthActionTypes.PasswordReseted, AuthActionTypes.PasswordResetFailed)).subscribe(function () {
            _this.submiting = false;
        });
        this.observe(this.effects.ofType(AuthActionTypes.PasswordReseted).pipe(take(1))).subscribe(function () {
            _this.router.navigate(['/login']);
        });
    };
    /**
     * @param {?} request
     * @return {?}
     */
    ResetPasswordComponent.prototype.onSubmit = /**
     * @param {?} request
     * @return {?}
     */
    function (request) {
        this.facade.resetPassword(request);
    };
    ResetPasswordComponent.decorators = [
        { type: Component, args: [{
                    selector: 'core-reset-password',
                    template: "<form #formRef=\"ngForm\" (ngSubmit)=\"onSubmit(formRef.value)\">\r\n    <div class=\"row\">\r\n        <div class=\"col-12\">\r\n            <h3>{{ 'core.auth.resetPassword.title' | translate }}</h3>\r\n        </div>\r\n    </div>\r\n    <div class=\"row\">\r\n        <div class=\"col-12\">\r\n            <div class=\"form-group\">\r\n                <label>{{ 'core.auth.resetPassword.password' | translate }}</label>\r\n                <input type=\"password\" [(ngModel)]=\"password\" name=\"password\" class=\"form-control\" required>\r\n                <input type=\"hidden\" [(ngModel)]=\"userId\" name=\"userId\" class=\"form-control\" required>\r\n                <input type=\"hidden\" [(ngModel)]=\"code\" name=\"code\" class=\"form-control\" required>\r\n            </div>\r\n        </div>\r\n    </div>\r\n    <div class=\"row\">\r\n        <div class=\"col-6\">\r\n            <button type=\"submit\" class=\"btn btn-primary\" [disabled]=\"!formRef.valid || submiting\">\r\n                <span *ngIf=\"!submiting\">{{ 'core.auth.resetPassword.submit' | translate }}</span>\r\n                <span *ngIf=\"submiting\"><i class=\"fa fa-circle-o-notch fa-spin\"></i></span>\r\n            </button>\r\n        </div>\r\n    </div>\r\n</form>"
                }] }
    ];
    /** @nocollapse */
    ResetPasswordComponent.ctorParameters = function () { return [
        { type: Router },
        { type: ActivatedRoute },
        { type: AuthFacade },
        { type: AuthEffects }
    ]; };
    return ResetPasswordComponent;
}(ObserverComponent));

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/** @type {?} */
var providers$1 = [
    AuthService,
    AuthGuardService,
    GuestGuardService,
    HasRoleGuardService
];
var ɵ0$2 = translations;
var AuthElisModule = /** @class */ (function () {
    function AuthElisModule(translateService, localesService) {
        localesService.initChild(translateService);
    }
    /**
     * @return {?}
     */
    AuthElisModule.forRoot = /**
     * @return {?}
     */
    function () {
        return {
            ngModule: AuthElisModule,
            providers: providers$1
        };
    };
    AuthElisModule.decorators = [
        { type: NgModule, args: [{
                    declarations: [
                        AuthFormComponent,
                        ChangePasswordComponent,
                        ForgotPasswordComponent,
                        ResetPasswordComponent,
                        HasRolePipe
                    ],
                    exports: [
                        AuthFormComponent,
                        ChangePasswordComponent,
                        ForgotPasswordComponent,
                        ResetPasswordComponent,
                        HasRolePipe
                    ],
                    imports: [
                        CommonModule,
                        FormsModule,
                        RouterModule,
                        HttpClientModule,
                        LocalesModule,
                        TranslateModule.forChild({
                            loader: {
                                provide: TranslateLoader,
                                useClass: LocaleLoader
                            },
                            isolate: true
                        }),
                        AlertModule
                    ],
                    providers: __spread(providers$1, [
                        {
                            provide: 'translations',
                            useValue: ɵ0$2
                        }
                    ])
                },] }
    ];
    /** @nocollapse */
    AuthElisModule.ctorParameters = function () { return [
        { type: TranslateService },
        { type: LocalesService }
    ]; };
    return AuthElisModule;
}());

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/** @type {?} */
var authBlacklistedRoutes = [
    /\/Oauth\/login\/?$/,
    /\/Oauth\/refresh\/?$/,
    /\/Oauth\/ForgotPassword\/?$/,
    /\/Oauth\/ResetPassword\/?$/,
];
/**
 * @param {?} jwtConfig
 * @param {?} authFacade
 * @return {?}
 */
function jwtOptionsFactory(jwtConfig, authFacade) {
    return {
        tokenGetter: function () { return authFacade.selectAccessToken().pipe(take(1)).toPromise(); },
        whitelistedDomains: jwtConfig.whitelistedDomains,
        blacklistedRoutes: jwtConfig.blacklistedRoutes
    };
}
var JwtConfig = /** @class */ (function () {
    function JwtConfig(envService) {
        this.whitelistedDomains = [];
        this.blacklistedRoutes = authBlacklistedRoutes;
        /** @type {?} */
        var whitelistedDomains = (/** @type {?} */ (envService.get('jwtWhitelistedDomains')));
        if (whitelistedDomains !== null) {
            this.whitelistedDomains = whitelistedDomains;
        }
    }
    JwtConfig.decorators = [
        { type: Injectable, args: [{
                    providedIn: 'root'
                },] }
    ];
    /** @nocollapse */
    JwtConfig.ctorParameters = function () { return [
        { type: EnvService }
    ]; };
    /** @nocollapse */ JwtConfig.ngInjectableDef = defineInjectable({ factory: function JwtConfig_Factory() { return new JwtConfig(inject(EnvService)); }, token: JwtConfig, providedIn: "root" });
    return JwtConfig;
}());

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
var RefreshTokenInterceptor = /** @class */ (function () {
    function RefreshTokenInterceptor(authFacade, authService, jwtInterceptor, router) {
        this.authFacade = authFacade;
        this.authService = authService;
        this.jwtInterceptor = jwtInterceptor;
        this.router = router;
        this.authState$ = authFacade.authState$;
    }
    /**
     * @param {?} request
     * @param {?} next
     * @return {?}
     */
    RefreshTokenInterceptor.prototype.intercept = /**
     * @param {?} request
     * @param {?} next
     * @return {?}
     */
    function (request, next) {
        var _this = this;
        if (!this.jwtInterceptor.isWhitelistedDomain(request) || this.jwtInterceptor.isBlacklistedRoute(request)) {
            return next.handle(request);
        }
        return this.authState$.pipe(filter(function (state) {
            if (state.loggedIn === null) {
                _this.authFacade.loadState();
                return false;
            }
            return true;
        }), filter(function (state) {
            if (!state.loggedIn) {
                _this.router.navigate(['/login']);
                return false;
            }
            return true;
        }), filter(function (state) { return state.persisted; }), filter(function (state) {
            if (_this.authService.isTokenExpired(state.user.access_token)) {
                _this.authFacade.refreshToken(state.user);
                return false;
            }
            return true;
        }), take(1), mergeMap(function () { return _this.jwtInterceptor.intercept(request, next); }));
    };
    RefreshTokenInterceptor.decorators = [
        { type: Injectable }
    ];
    /** @nocollapse */
    RefreshTokenInterceptor.ctorParameters = function () { return [
        { type: AuthFacade },
        { type: AuthService },
        { type: JwtInterceptor },
        { type: Router }
    ]; };
    return RefreshTokenInterceptor;
}());

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
var SubsidiaryInterceptor = /** @class */ (function () {
    function SubsidiaryInterceptor(authFacade, jwtInterceptor) {
        this.authFacade = authFacade;
        this.jwtInterceptor = jwtInterceptor;
    }
    /**
     * @param {?} request
     * @param {?} next
     * @return {?}
     */
    SubsidiaryInterceptor.prototype.intercept = /**
     * @param {?} request
     * @param {?} next
     * @return {?}
     */
    function (request, next) {
        if (!this.jwtInterceptor.isWhitelistedDomain(request) || this.jwtInterceptor.isBlacklistedRoute(request)) {
            return next.handle(request);
        }
        return this.authFacade.authState$.pipe(switchMap(function (state) {
            if (state.currentSubsidiary === null) {
                return next.handle(request);
            }
            return next.handle(request.clone({
                setHeaders: {
                    'X-Subsidiary': state.currentSubsidiary.id
                }
            }));
        }));
    };
    SubsidiaryInterceptor.decorators = [
        { type: Injectable }
    ];
    /** @nocollapse */
    SubsidiaryInterceptor.ctorParameters = function () { return [
        { type: AuthFacade },
        { type: JwtInterceptor }
    ]; };
    return SubsidiaryInterceptor;
}());

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
var SistemasService = /** @class */ (function () {
    function SistemasService(http, apiHost) {
        this.http = http;
        this.apiHost = apiHost;
    }
    /**
     * @return {?}
     */
    SistemasService.prototype.fetchSistemas = /**
     * @return {?}
     */
    function () {
        return this.http.get(this.apiHost.url + "/user/GetAllSystems")
            .pipe(map(function (response) { return response.systems; }));
    };
    SistemasService.decorators = [
        { type: Injectable, args: [{
                    providedIn: 'root'
                },] }
    ];
    /** @nocollapse */
    SistemasService.ctorParameters = function () { return [
        { type: HttpClient },
        { type: Host, decorators: [{ type: Inject, args: ['apiHostService',] }] }
    ]; };
    /** @nocollapse */ SistemasService.ngInjectableDef = defineInjectable({ factory: function SistemasService_Factory() { return new SistemasService(inject(HttpClient), inject("apiHostService")); }, token: SistemasService, providedIn: "root" });
    return SistemasService;
}());

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/** @enum {string} */
var SistemasActionTypes = {
    LoadSistemas: '[Sistemas] Load Sistemas Data',
    FetchSistemas: '[Sistemas] Fetch Sistemas Data',
    SistemasFetched: '[Sistemas] Sistemas Data Fetched',
};
var LoadSistemas = /** @class */ (function () {
    function LoadSistemas() {
        this.type = SistemasActionTypes.LoadSistemas;
    }
    return LoadSistemas;
}());
var SistemasFetched = /** @class */ (function () {
    function SistemasFetched(payload) {
        this.payload = payload;
        this.type = SistemasActionTypes.SistemasFetched;
    }
    return SistemasFetched;
}());

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/** @type {?} */
var sistemaAdapter = createEntityAdapter();
/** @type {?} */
var sistemasInitialState = sistemaAdapter.getInitialState({
    loaded: false
});
/**
 * @param {?=} state
 * @param {?=} action
 * @return {?}
 */
function sistemasReducer(state, action) {
    if (state === void 0) { state = sistemasInitialState; }
    switch (action.type) {
        case SistemasActionTypes.SistemasFetched:
            return __assign({}, sistemaAdapter.upsertMany(action.payload, state), { loaded: true });
        default:
            return state;
    }
}
var _a$1 = sistemaAdapter.getSelectors(), selectIds = _a$1.selectIds, selectEntities = _a$1.selectEntities, selectAll = _a$1.selectAll;
/** @type {?} */
var selectSistemasIds = selectIds;
/** @type {?} */
var selectSistemasEntities = selectEntities;
/** @type {?} */
var selectAllSistemas = selectAll;
/** @type {?} */
var selectSistema = function (id) {
    return function (state) {
        return state.entities[id];
    };
};
/** @type {?} */
var isLoaded = function (state) {
    return state.loaded;
};
/** @type {?} */
var selectSistemasState = createFeatureSelector('sistemas');

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
var SistemasEffects = /** @class */ (function () {
    function SistemasEffects(actions$, dataPersistence, service) {
        var _this = this;
        this.actions$ = actions$;
        this.dataPersistence = dataPersistence;
        this.service = service;
        this.loadPage$ = this.dataPersistence.fetch(SistemasActionTypes.LoadSistemas, {
            run: function (action, state) {
                /** @type {?} */
                var loaded = isLoaded(selectSistemasState(state));
                if (loaded) {
                    return;
                }
                return _this.service.fetchSistemas()
                    .pipe(map(function (sistemas) { return new SistemasFetched(sistemas); }), take(1));
            },
            onError: function (action, error) {
                console.error('Error', error);
            }
        });
    }
    /**
     * @param {...?} types
     * @return {?}
     */
    SistemasEffects.prototype.ofType = /**
     * @param {...?} types
     * @return {?}
     */
    function () {
        var types = [];
        for (var _i = 0; _i < arguments.length; _i++) {
            types[_i] = arguments[_i];
        }
        return this.actions$.pipe(filter(function (action) { return types.indexOf(action.type) !== -1; }));
    };
    SistemasEffects.decorators = [
        { type: Injectable, args: [{ providedIn: 'root' },] }
    ];
    /** @nocollapse */
    SistemasEffects.ctorParameters = function () { return [
        { type: Actions },
        { type: DataPersistence },
        { type: SistemasService }
    ]; };
    /** @nocollapse */ SistemasEffects.ngInjectableDef = defineInjectable({ factory: function SistemasEffects_Factory() { return new SistemasEffects(inject(Actions), inject(DataPersistence), inject(SistemasService)); }, token: SistemasEffects, providedIn: "root" });
    __decorate([
        Effect(),
        __metadata("design:type", Object)
    ], SistemasEffects.prototype, "loadPage$", void 0);
    return SistemasEffects;
}());

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
var SistemasFacade = /** @class */ (function () {
    function SistemasFacade(store) {
        this.store = store;
        this.sistemas$ = this.selectSistemas();
    }
    /**
     * @return {?}
     */
    SistemasFacade.prototype.selectSistemas = /**
     * @return {?}
     */
    function () {
        var _this = this;
        return this.store.pipe(select(selectSistemasState), map(selectAllSistemas), tap(function (sistamas) {
            if (sistamas.length === 0) {
                _this.load();
            }
        }), filter(function (sistamas) { return sistamas.length > 0; }));
    };
    /**
     * @return {?}
     */
    SistemasFacade.prototype.load = /**
     * @return {?}
     */
    function () {
        this.store.dispatch(new LoadSistemas);
    };
    SistemasFacade.decorators = [
        { type: Injectable, args: [{
                    providedIn: 'root'
                },] }
    ];
    /** @nocollapse */
    SistemasFacade.ctorParameters = function () { return [
        { type: Store }
    ]; };
    /** @nocollapse */ SistemasFacade.ngInjectableDef = defineInjectable({ factory: function SistemasFacade_Factory() { return new SistemasFacade(inject(Store)); }, token: SistemasFacade, providedIn: "root" });
    return SistemasFacade;
}());

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/** @type {?} */
var providers$2 = [
    SistemasService,
    SistemasFacade,
    SistemasEffects
];
var SistemasModule = /** @class */ (function () {
    function SistemasModule() {
    }
    /**
     * @return {?}
     */
    SistemasModule.forRoot = /**
     * @return {?}
     */
    function () {
        return {
            ngModule: SistemasModule,
            providers: providers$2
        };
    };
    SistemasModule.decorators = [
        { type: NgModule, args: [{
                    declarations: [],
                    imports: [
                        CommonModule,
                        HttpClientModule
                    ],
                    providers: providers$2
                },] }
    ];
    return SistemasModule;
}());

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
var UsersADService = /** @class */ (function () {
    function UsersADService(http, apiHost) {
        this.http = http;
        this.apiHost = apiHost;
    }
    /**
     * @param {?} userNameAD
     * @return {?}
     */
    UsersADService.prototype.getUserAD = /**
     * @param {?} userNameAD
     * @return {?}
     */
    function (userNameAD) {
        /** @type {?} */
        var params = new HttpParams().set('UserNameAD', userNameAD);
        return this.http.get(this.apiHost.url + "/user/getadusername", { params: params }).pipe(map(function (res) { return res.user; }));
    };
    /**
     * @param {?} userNameAD
     * @return {?}
     */
    UsersADService.prototype.getValidUserAD = /**
     * @param {?} userNameAD
     * @return {?}
     */
    function (userNameAD) {
        /** @type {?} */
        var params = new HttpParams().set('UserNameAD', userNameAD);
        return this.http.get(this.apiHost.url + "/user/getadvalidusername", { params: params }).pipe(catchError(function (error) {
            /** @type {?} */
            var response = (error instanceof HttpErrorResponse) ? error.error : {
                success: false,
                message: 'Server Error'
            };
            return of(response);
        }));
    };
    UsersADService.decorators = [
        { type: Injectable, args: [{
                    providedIn: 'root'
                },] }
    ];
    /** @nocollapse */
    UsersADService.ctorParameters = function () { return [
        { type: HttpClient },
        { type: Host, decorators: [{ type: Inject, args: ['apiHostService',] }] }
    ]; };
    /** @nocollapse */ UsersADService.ngInjectableDef = defineInjectable({ factory: function UsersADService_Factory() { return new UsersADService(inject(HttpClient), inject("apiHostService")); }, token: UsersADService, providedIn: "root" });
    return UsersADService;
}());

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/** @enum {string} */
var UsersADActionTypes = {
    UpdateUserADState: '[Users AD] Update Usuario State',
    FetchUserADData: '[Users AD] Fetch Usuario Data',
};
var UpdateUserADState = /** @class */ (function () {
    function UpdateUserADState(payload) {
        this.payload = payload;
        this.type = UsersADActionTypes.UpdateUserADState;
    }
    return UpdateUserADState;
}());
var FetchUserADData = /** @class */ (function () {
    function FetchUserADData(payload) {
        this.payload = payload;
        this.type = UsersADActionTypes.FetchUserADData;
    }
    return FetchUserADData;
}());

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
var ɵ0$3 = function (usuario) { return usuario.samAccountName.toLowerCase(); };
/** @type {?} */
var usuarioAdapter = createEntityAdapter({
    selectId: ɵ0$3
});
/** @type {?} */
var usersADInitialState = usuarioAdapter.getInitialState();
/**
 * @param {?=} state
 * @param {?=} action
 * @return {?}
 */
function usersADReducer(state, action) {
    if (state === void 0) { state = usersADInitialState; }
    switch (action.type) {
        case UsersADActionTypes.UpdateUserADState:
            return usuarioAdapter.upsertOne(action.payload, state);
        default:
            return state;
    }
}
var _a$2 = usuarioAdapter.getSelectors(), selectIds$1 = _a$2.selectIds, selectEntities$1 = _a$2.selectEntities, selectAll$1 = _a$2.selectAll;
/** @type {?} */
var selectUsersIds = selectIds$1;
/** @type {?} */
var selectUsersEntities = selectEntities$1;
/** @type {?} */
var selectAllUsers = selectAll$1;
/** @type {?} */
var selectUser = function (samAccountName) {
    return function (state) {
        return state.entities[samAccountName.toLowerCase()] || null;
    };
};
/** @type {?} */
var selectUsersADState = createFeatureSelector('usersAD');

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
var UsersADFacade = /** @class */ (function () {
    function UsersADFacade(store) {
        this.store = store;
    }
    /**
     * @param {?} userNameAD
     * @return {?}
     */
    UsersADFacade.prototype.selectUser = /**
     * @param {?} userNameAD
     * @return {?}
     */
    function (userNameAD) {
        var _this = this;
        return this.store.pipe(select(selectUsersADState), map(selectUser(userNameAD)), distinctUntilChanged(), tap(function (user) {
            if (user === null) {
                _this.fetchUser(userNameAD);
            }
        }), filter(function (user) { return user !== null; }));
    };
    /**
     * @param {?} userNameAD
     * @return {?}
     */
    UsersADFacade.prototype.fetchUser = /**
     * @param {?} userNameAD
     * @return {?}
     */
    function (userNameAD) {
        this.store.dispatch(new FetchUserADData(userNameAD));
    };
    UsersADFacade.decorators = [
        { type: Injectable, args: [{
                    providedIn: 'root'
                },] }
    ];
    /** @nocollapse */
    UsersADFacade.ctorParameters = function () { return [
        { type: Store }
    ]; };
    /** @nocollapse */ UsersADFacade.ngInjectableDef = defineInjectable({ factory: function UsersADFacade_Factory() { return new UsersADFacade(inject(Store)); }, token: UsersADFacade, providedIn: "root" });
    return UsersADFacade;
}());

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
var UsersAdEffects = /** @class */ (function () {
    function UsersAdEffects(actions$, dataPersistence, service) {
        var _this = this;
        this.actions$ = actions$;
        this.dataPersistence = dataPersistence;
        this.service = service;
        this.fetchUsers$ = this.dataPersistence.fetch(UsersADActionTypes.FetchUserADData, {
            id: function (action, state) {
                return action.payload;
            },
            run: function (action, state) {
                return _this.service.getUserAD(action.payload).pipe(map(function (user) { return new UpdateUserADState(user); }), take(1));
            },
            onError: function (action, error) {
                console.error('Error', error);
            }
        });
    }
    /**
     * @param {...?} types
     * @return {?}
     */
    UsersAdEffects.prototype.ofType = /**
     * @param {...?} types
     * @return {?}
     */
    function () {
        var types = [];
        for (var _i = 0; _i < arguments.length; _i++) {
            types[_i] = arguments[_i];
        }
        return this.actions$.pipe(filter(function (action) { return types.indexOf(action.type) !== -1; }));
    };
    UsersAdEffects.decorators = [
        { type: Injectable, args: [{ providedIn: 'root' },] }
    ];
    /** @nocollapse */
    UsersAdEffects.ctorParameters = function () { return [
        { type: Actions },
        { type: DataPersistence },
        { type: UsersADService }
    ]; };
    /** @nocollapse */ UsersAdEffects.ngInjectableDef = defineInjectable({ factory: function UsersAdEffects_Factory() { return new UsersAdEffects(inject(Actions), inject(DataPersistence), inject(UsersADService)); }, token: UsersAdEffects, providedIn: "root" });
    __decorate([
        Effect(),
        __metadata("design:type", Object)
    ], UsersAdEffects.prototype, "fetchUsers$", void 0);
    return UsersAdEffects;
}());

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/** @type {?} */
var providers$3 = [
    UsersADService,
    UsersADFacade,
    UsersAdEffects
];
var UsersADModule = /** @class */ (function () {
    function UsersADModule() {
    }
    /**
     * @return {?}
     */
    UsersADModule.forRoot = /**
     * @return {?}
     */
    function () {
        return {
            ngModule: UsersADModule,
            providers: providers$3
        };
    };
    UsersADModule.decorators = [
        { type: NgModule, args: [{
                    declarations: [],
                    imports: [
                        CommonModule
                    ],
                    providers: providers$3
                },] }
    ];
    return UsersADModule;
}());

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
var RolesService = /** @class */ (function () {
    function RolesService(http, apiHost) {
        this.http = http;
        this.apiHost = apiHost;
    }
    /**
     * @param {?} number
     * @return {?}
     */
    RolesService.prototype.fetchPageData = /**
     * @param {?} number
     * @return {?}
     */
    function (number) {
        /** @type {?} */
        var params = new HttpParams().set('page', number.toString());
        return this.http.get(this.apiHost.url + "/user/GetAllRolesByPagination", { params: params });
    };
    /**
     * @param {?} systemName
     * @return {?}
     */
    RolesService.prototype.fetchRoleGroupsBySistema = /**
     * @param {?} systemName
     * @return {?}
     */
    function (systemName) {
        /** @type {?} */
        var params = new HttpParams().set('system', systemName);
        return this.http.get(this.apiHost.url + "/user/GetAllRolesBySystem", { params: params })
            .pipe(map(function (response) { return response.groups; }));
    };
    /**
     * @param {?} request
     * @return {?}
     */
    RolesService.prototype.updateUserRoles = /**
     * @param {?} request
     * @return {?}
     */
    function (request) {
        return this.http.post(this.apiHost.url + "/user/UpdatePermission", request);
    };
    RolesService.decorators = [
        { type: Injectable, args: [{
                    providedIn: 'root'
                },] }
    ];
    /** @nocollapse */
    RolesService.ctorParameters = function () { return [
        { type: HttpClient },
        { type: Host, decorators: [{ type: Inject, args: ['apiHostService',] }] }
    ]; };
    /** @nocollapse */ RolesService.ngInjectableDef = defineInjectable({ factory: function RolesService_Factory() { return new RolesService(inject(HttpClient), inject("apiHostService")); }, token: RolesService, providedIn: "root" });
    return RolesService;
}());

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/** @enum {string} */
var UpdateUserRoleActionsTypes = {
    inserted: 'inserted',
    deleted: 'deleted',
    none: 'none',
};
var AddUserRoleRequest = /** @class */ (function () {
    function AddUserRoleRequest(email, role) {
        this.email = email;
        this.role = role;
        this.insertUpdate = true;
    }
    return AddUserRoleRequest;
}());
var RemoveUserRoleRequest = /** @class */ (function () {
    function RemoveUserRoleRequest(email, role) {
        this.email = email;
        this.role = role;
        this.insertUpdate = false;
    }
    return RemoveUserRoleRequest;
}());

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
var RolesFacade = /** @class */ (function () {
    function RolesFacade(store) {
        this.store = store;
        this.roles$ = this.selectRoles();
        this.groups$ = this.selectRoleGroups();
    }
    /**
     * @return {?}
     */
    RolesFacade.prototype.selectRoles = /**
     * @return {?}
     */
    function () {
        return this.store.pipe(select(selectRolesState), map(selectAllRoles));
    };
    /**
     * @return {?}
     */
    RolesFacade.prototype.selectRoleGroups = /**
     * @return {?}
     */
    function () {
        return this.store.pipe(select(selectRolesState), select(selectRoleGroupsState), map(selectAllRoleGroups));
    };
    /**
     * @param {?} sistema
     * @return {?}
     */
    RolesFacade.prototype.selectRolesBySistema = /**
     * @param {?} sistema
     * @return {?}
     */
    function (sistema) {
        return this.selectRoleGroups().pipe(map(function (groups) {
            return groups.filter(function (group) { return group.systemId === sistema.id; });
        }));
    };
    /**
     * @return {?}
     */
    RolesFacade.prototype.loadPage = /**
     * @return {?}
     */
    function () {
        this.store.dispatch(new LoadPage);
    };
    /**
     * @param {?} systemName
     * @return {?}
     */
    RolesFacade.prototype.loadRoleGroupsBySistema = /**
     * @param {?} systemName
     * @return {?}
     */
    function (systemName) {
        this.store.dispatch(new FetchRoleGroupsBySistema(systemName));
    };
    /**
     * @param {?} usuario
     * @param {?} rolesNames
     * @return {?}
     */
    RolesFacade.prototype.insertUserRoles = /**
     * @param {?} usuario
     * @param {?} rolesNames
     * @return {?}
     */
    function (usuario, rolesNames) {
        /** @type {?} */
        var requests = rolesNames.map(function (roleName) { return new AddUserRoleRequest(usuario.userName, roleName); });
        this.store.dispatch(new UpdateUserRoles(requests));
    };
    /**
     * @param {?} usuario
     * @param {?} rolesNames
     * @return {?}
     */
    RolesFacade.prototype.removeUserRoles = /**
     * @param {?} usuario
     * @param {?} rolesNames
     * @return {?}
     */
    function (usuario, rolesNames) {
        /** @type {?} */
        var requests = rolesNames.map(function (roleName) { return new RemoveUserRoleRequest(usuario.userName, roleName); });
        this.store.dispatch(new UpdateUserRoles(requests));
    };
    RolesFacade.decorators = [
        { type: Injectable, args: [{
                    providedIn: 'root'
                },] }
    ];
    /** @nocollapse */
    RolesFacade.ctorParameters = function () { return [
        { type: Store }
    ]; };
    /** @nocollapse */ RolesFacade.ngInjectableDef = defineInjectable({ factory: function RolesFacade_Factory() { return new RolesFacade(inject(Store)); }, token: RolesFacade, providedIn: "root" });
    return RolesFacade;
}());

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/** @enum {string} */
var UsuariosActionTypes = {
    LoadPage: '[Usuarios] Load Page',
    FetchPageData: '[Usuarios] Fetch Page Data',
    PageDataFetched: '[Usuarios] Page Data Fetched',
    PageDataFetchFailed: '[Usuarios] Page Data Fetch Failed',
    ResetPagination: '[Usuarios] Reset Pagination',
    SelectUsuario: '[Usuarios] Select Usuario',
    UpdateUsuarioState: '[Usuarios] Update Usuario State',
    FetchUsuarioData: '[Usuarios] Fetch Usuario Data',
    CreateUsuario: '[Usuarios] Create Usuario',
    UsuarioCreated: '[Usuarios] Usuario Created',
    UsuarioCreateFailed: '[Usuarios] Usuario Create Failed',
    ToggleAccessUsuario: '[Usuarios] Toggle Access Usuario',
    UsuarioRoleRemoved: '[Usuarios] Usuario Role removed',
    UsuarioRoleInserted: '[Usuarios] Usuario Role inserted',
    UsuarioSubsidiaryRemoved: '[Usuarios] Usuario Subsidiary removed',
    UsuarioSubsidiaryInserted: '[Usuarios] Usuario Subsidiary inserted',
    UpdateUsuarioHostFirewall: '[Usuarios] Update Usuario Host Firewall',
    UsuarioHostFirewallUpdated: '[Usuarios] Usuario Host Firewall Updated',
};
var LoadPage$1 = /** @class */ (function () {
    function LoadPage() {
        this.type = UsuariosActionTypes.LoadPage;
    }
    return LoadPage;
}());
var PageDataFetched$1 = /** @class */ (function () {
    function PageDataFetched(payload) {
        this.payload = payload;
        this.type = UsuariosActionTypes.PageDataFetched;
    }
    return PageDataFetched;
}());
var PageDataFetchFailed$1 = /** @class */ (function () {
    function PageDataFetchFailed(payload) {
        this.payload = payload;
        this.type = UsuariosActionTypes.PageDataFetchFailed;
    }
    return PageDataFetchFailed;
}());
var ResetPagination$1 = /** @class */ (function () {
    function ResetPagination() {
        this.type = UsuariosActionTypes.ResetPagination;
    }
    return ResetPagination;
}());
var SelectUsuario = /** @class */ (function () {
    function SelectUsuario(payload) {
        this.payload = payload;
        this.type = UsuariosActionTypes.SelectUsuario;
    }
    return SelectUsuario;
}());
var UpdateUsuarioState = /** @class */ (function () {
    function UpdateUsuarioState(payload) {
        this.payload = payload;
        this.type = UsuariosActionTypes.UpdateUsuarioState;
    }
    return UpdateUsuarioState;
}());
var FetchUsuarioData = /** @class */ (function () {
    function FetchUsuarioData(payload) {
        this.payload = payload;
        this.type = UsuariosActionTypes.FetchUsuarioData;
    }
    return FetchUsuarioData;
}());
var CreateUsuario = /** @class */ (function () {
    function CreateUsuario(payload) {
        this.payload = payload;
        this.type = UsuariosActionTypes.CreateUsuario;
    }
    return CreateUsuario;
}());
var UsuarioCreated = /** @class */ (function () {
    function UsuarioCreated(payload) {
        this.payload = payload;
        this.type = UsuariosActionTypes.UsuarioCreated;
    }
    return UsuarioCreated;
}());
var UsuarioCreateFailed = /** @class */ (function () {
    function UsuarioCreateFailed(payload) {
        this.payload = payload;
        this.type = UsuariosActionTypes.UsuarioCreateFailed;
    }
    return UsuarioCreateFailed;
}());
var ToggleUsuarioAcess = /** @class */ (function () {
    function ToggleUsuarioAcess(payload) {
        this.payload = payload;
        this.type = UsuariosActionTypes.ToggleAccessUsuario;
    }
    return ToggleUsuarioAcess;
}());
var UsuarioRoleInserted = /** @class */ (function () {
    function UsuarioRoleInserted(payload) {
        this.payload = payload;
        this.type = UsuariosActionTypes.UsuarioRoleInserted;
    }
    return UsuarioRoleInserted;
}());
var UsuarioRoleRemoved = /** @class */ (function () {
    function UsuarioRoleRemoved(payload) {
        this.payload = payload;
        this.type = UsuariosActionTypes.UsuarioRoleRemoved;
    }
    return UsuarioRoleRemoved;
}());
var UsuarioSubsidiaryInserted = /** @class */ (function () {
    function UsuarioSubsidiaryInserted(payload) {
        this.payload = payload;
        this.type = UsuariosActionTypes.UsuarioSubsidiaryInserted;
    }
    return UsuarioSubsidiaryInserted;
}());
var UsuarioSubsidiaryRemoved = /** @class */ (function () {
    function UsuarioSubsidiaryRemoved(payload) {
        this.payload = payload;
        this.type = UsuariosActionTypes.UsuarioSubsidiaryRemoved;
    }
    return UsuarioSubsidiaryRemoved;
}());
var UpdateUsuarioHostFirewall = /** @class */ (function () {
    function UpdateUsuarioHostFirewall(payload) {
        this.payload = payload;
        this.type = UsuariosActionTypes.UpdateUsuarioHostFirewall;
    }
    return UpdateUsuarioHostFirewall;
}());
var UsuarioHostFirewallUpdated = /** @class */ (function () {
    function UsuarioHostFirewallUpdated(payload) {
        this.payload = payload;
        this.type = UsuariosActionTypes.UsuarioHostFirewallUpdated;
    }
    return UsuarioHostFirewallUpdated;
}());

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
var UsuarioRoleInsertData = /** @class */ (function () {
    function UsuarioRoleInsertData(userName, role) {
        this.userName = userName;
        this.role = role;
    }
    return UsuarioRoleInsertData;
}());
var UsuarioRoleRemoveData = /** @class */ (function () {
    function UsuarioRoleRemoveData(userName, role) {
        this.userName = userName;
        this.role = role;
    }
    return UsuarioRoleRemoveData;
}());
var UsuarioSubsidiaryInsertData = /** @class */ (function () {
    function UsuarioSubsidiaryInsertData(userName, subsidiary) {
        this.userName = userName;
        this.subsidiary = subsidiary;
    }
    return UsuarioSubsidiaryInsertData;
}());
var UsuarioSubsidiaryRemoveData = /** @class */ (function () {
    function UsuarioSubsidiaryRemoveData(userName, subsidiary) {
        this.userName = userName;
        this.subsidiary = subsidiary;
    }
    return UsuarioSubsidiaryRemoveData;
}());

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
var RolesEffects = /** @class */ (function () {
    function RolesEffects(actions$, dataPersistence, service) {
        var _this = this;
        this.actions$ = actions$;
        this.dataPersistence = dataPersistence;
        this.service = service;
        this.loadPage$ = this.dataPersistence.fetch(RolesActionTypes.LoadPage, {
            id: function (action, state) {
                return getNextPage(selectRolesState(state));
            },
            run: function (action, state) {
                /** @type {?} */
                var page = getNextPage(selectRolesState(state));
                if (page === null) {
                    return;
                }
                return _this.service.fetchPageData(page)
                    .pipe(map(function (res) { return new PageDataFetched(res); }), take(1), catchError(function (error) { return of(new PageDataFetchFailed(page)); }));
            },
            onError: function (action, error) {
                console.error('Error', error);
            }
        });
        this.fetchRoleGroupsBySistema$ = this.dataPersistence.fetch(RolesActionTypes.FetchRoleGroupsBySistema, {
            id: function (action, state) {
                return action.payload;
            },
            run: function (action, state) {
                return _this.service.fetchRoleGroupsBySistema(action.payload)
                    .pipe(map(function (groups) { return new RoleGroupsFetched(groups); }), take(1), catchError(function (error) { return of(new FetchRoleGroupsBySistemaFail(action.payload)); }));
            },
            onError: function (action, error) {
                console.error('Error', error);
            }
        });
        this.updateUserRoles$ = this.dataPersistence.pessimisticUpdate(RolesActionTypes.UpdateUserRoles, {
            run: function (action, state) {
                return _this.service.updateUserRoles(action.payload)
                    .pipe(take(1), map(function (responses) { return responses.filter(function (response) { return response.action !== UpdateUserRoleActionsTypes.none; }); }), switchMap(function (itens) { return itens.map(function (response) {
                    switch (response.action) {
                        case UpdateUserRoleActionsTypes.inserted:
                            return new UsuarioRoleInserted(new UsuarioRoleInsertData(response.email, selectRole(response.role)(selectRolesState(state))));
                        case UpdateUserRoleActionsTypes.deleted:
                            return new UsuarioRoleRemoved(new UsuarioRoleRemoveData(response.email, selectRole(response.role)(selectRolesState(state))));
                    }
                }); }));
            },
            onError: function (action, error) {
                console.error('Error', error);
            }
        });
    }
    /**
     * @param {...?} types
     * @return {?}
     */
    RolesEffects.prototype.ofType = /**
     * @param {...?} types
     * @return {?}
     */
    function () {
        var types = [];
        for (var _i = 0; _i < arguments.length; _i++) {
            types[_i] = arguments[_i];
        }
        return this.actions$.pipe(filter(function (action) { return types.indexOf(action.type) !== -1; }));
    };
    RolesEffects.decorators = [
        { type: Injectable, args: [{ providedIn: 'root' },] }
    ];
    /** @nocollapse */
    RolesEffects.ctorParameters = function () { return [
        { type: Actions },
        { type: DataPersistence },
        { type: RolesService }
    ]; };
    /** @nocollapse */ RolesEffects.ngInjectableDef = defineInjectable({ factory: function RolesEffects_Factory() { return new RolesEffects(inject(Actions), inject(DataPersistence), inject(RolesService)); }, token: RolesEffects, providedIn: "root" });
    __decorate([
        Effect(),
        __metadata("design:type", Object)
    ], RolesEffects.prototype, "loadPage$", void 0);
    __decorate([
        Effect(),
        __metadata("design:type", Object)
    ], RolesEffects.prototype, "fetchRoleGroupsBySistema$", void 0);
    __decorate([
        Effect(),
        __metadata("design:type", Object)
    ], RolesEffects.prototype, "updateUserRoles$", void 0);
    return RolesEffects;
}());

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
var SelectRolesComponent = /** @class */ (function (_super) {
    __extends(SelectRolesComponent, _super);
    function SelectRolesComponent(rolesFacade, sistemasFacade) {
        var _this = _super.call(this) || this;
        _this.rolesFacade = rolesFacade;
        _this.sistemasFacade = sistemasFacade;
        _this.insert = new EventEmitter();
        _this.remove = new EventEmitter();
        _this.selectedSistema$ = new BehaviorSubject(null);
        _this.usuarioRoles$ = new BehaviorSubject([]);
        _this.rolesList = [];
        _this.usuarioRoleGroups = [];
        _this.selectedRoles = [];
        _this.selectedUsuarioRoles = [];
        return _this;
    }
    /**
     * @param {?} changes
     * @return {?}
     */
    SelectRolesComponent.prototype.ngOnChanges = /**
     * @param {?} changes
     * @return {?}
     */
    function (changes) {
        this.usuarioRoles$.next(changes.roles.currentValue);
    };
    /**
     * @return {?}
     */
    SelectRolesComponent.prototype.ngOnInit = /**
     * @return {?}
     */
    function () {
        var _this = this;
        this.observe(this.sistemasFacade.sistemas$).subscribe(function (sistemas) {
            _this.sistemas = sistemas;
        });
        this.observe(this.rolesFacade.roles$).subscribe(function (roles) {
            _this.rolesList = roles;
        });
        this.sistemasFacade.sistemas$.pipe(take(1)).subscribe(function (sistemas) {
            _this.selectSistema(sistemas[0]);
        });
        this.observe(this.selectedSistema$.pipe(filter(function (sistema) { return sistema !== null; }), distinctUntilChanged())).subscribe(function (sistema) {
            _this.selectedRoles = [];
            _this.selectedUsuarioRoles = [];
            _this.rolesFacade.loadRoleGroupsBySistema(sistema.name);
        });
        this.roleGroups$ = this.selectedSistema$.pipe(filter(function (sistema) { return sistema !== null; }), switchMap(function (sistema) { return _this.rolesFacade.selectRolesBySistema(sistema); }));
        this.observe(combineLatest(this.roleGroups$, this.usuarioRoles$).pipe(map(function (_a) {
            var _b = __read(_a, 2), groups = _b[0], roles = _b[1];
            /** @type {?} */
            var usuarioRolesName = roles.map(function (role) { return role.name; });
            return groups.map(function (group) {
                return __assign({}, group, { roles: group.roles.filter(function (role) { return usuarioRolesName.indexOf(role.name) !== -1; }) });
            }).filter(function (group) {
                return group.roles.length > 0;
            });
        }))).subscribe(function (usuarioRoleGroups) {
            _this.usuarioRoleGroups = usuarioRoleGroups;
        });
    };
    /**
     * @param {?} rolesNames
     * @return {?}
     */
    SelectRolesComponent.prototype.insertRoles = /**
     * @param {?} rolesNames
     * @return {?}
     */
    function (rolesNames) {
        /** @type {?} */
        var roles = this.rolesList.filter(function (role) { return rolesNames.indexOf(role.name) !== -1; });
        this.insert.emit(roles);
        this.selectedRoles = [];
    };
    /**
     * @param {?} rolesNames
     * @return {?}
     */
    SelectRolesComponent.prototype.removeRoles = /**
     * @param {?} rolesNames
     * @return {?}
     */
    function (rolesNames) {
        /** @type {?} */
        var roles = this.rolesList.filter(function (role) { return rolesNames.indexOf(role.name) !== -1; });
        this.remove.emit(roles);
        this.selectedUsuarioRoles = [];
    };
    /**
     * @param {?} sistema
     * @return {?}
     */
    SelectRolesComponent.prototype.selectSistema = /**
     * @param {?} sistema
     * @return {?}
     */
    function (sistema) {
        this.selectedSistema$.next(sistema);
    };
    SelectRolesComponent.decorators = [
        { type: Component, args: [{
                    selector: 'core-select-roles',
                    template: "<div class=\"card\" *ngIf=\"(selectedSistema$ | async) !== null\">\r\n        <div class=\"card-header border-bottom-0\">\r\n            <i class=\"fa fa-key\"></i> {{ 'roles.select.title' | translate }}\r\n        </div>\r\n        <div class=\"card-body bg-light p-0\">\r\n            <div class=\"tab-container\">\r\n                <ul class=\"nav nav-tabs\">\r\n                    <li class=\"nav-item\" *ngFor=\"let sistema of sistemas\" [ngClass]=\"{ active: sistema.id == (selectedSistema$ | async).id }\" >\r\n                        <a\r\n                            class=\"nav-link\"\r\n                            href=\"javascript:;\"\r\n                            [ngClass]=\"{ active: sistema.id == (selectedSistema$ | async).id }\"\r\n                            (click)=\"selectSistema(sistema)\"\r\n                        >\r\n                            {{ sistema.description }}\r\n                        </a>\r\n                    </li>\r\n                </ul>\r\n                <div class=\"tab-content border-bottom-0 border-left-0 border-right-0 px-3 py-4\">\r\n                    <div class=\"form-row\">\r\n                        <div class=\"col-12 col-md-5\">\r\n                            <select [(ngModel)]=\"selectedRoles\" class=\"form-control roles-select\" multiple>\r\n                                <optgroup\r\n                                    *ngFor=\"let group of roleGroups$ | async\"\r\n                                    [label]=\"group.description\"\r\n                                >\r\n                                    <option *ngFor=\"let role of group.roles\" [value]=\"role.name\" [disabled]=\"role | hasRoleInList:roles\" >{{ role.description }}</option>\r\n                                </optgroup>\r\n                            </select>\r\n                        </div>\r\n                        <div class=\"col-12 col-md-2 d-flex flex-column justify-content-center align-items-center my-2\">\r\n                            <div class=\"mb-3\">\r\n                                <button\r\n                                    type=\"button\"\r\n                                    class=\"btn btn-primary\"\r\n                                    [disabled]=\"selectedRoles.length === 0\"\r\n                                    (click)=\"insertRoles(selectedRoles)\"\r\n                                >\r\n                                    >>\r\n                                </button>\r\n                            </div>\r\n                            <div>\r\n                                <button\r\n                                    type=\"button\"\r\n                                    class=\"btn btn-primary\"\r\n                                    [disabled]=\"selectedUsuarioRoles.length === 0\"\r\n                                    (click)=\"removeRoles(selectedUsuarioRoles)\"\r\n                                >\r\n                                    <<\r\n                                </button>\r\n                            </div>\r\n                        </div>\r\n                        <div class=\"col-12 col-md-5\">\r\n                            <select [(ngModel)]=\"selectedUsuarioRoles\" class=\"form-control roles-select\" multiple>\r\n                                    <optgroup\r\n                                    *ngFor=\"let group of usuarioRoleGroups\"\r\n                                    [label]=\"group.description\"\r\n                                >\r\n                                    <option *ngFor=\"let role of group.roles\" [value]=\"role.name\" >{{ role.description }}</option>\r\n                                </optgroup>\r\n                            </select>\r\n                        </div>\r\n                    </div>\r\n                </div>\r\n            </div>\r\n        </div>\r\n    </div>",
                    styles: [".roles-select{min-height:50vh}"]
                }] }
    ];
    /** @nocollapse */
    SelectRolesComponent.ctorParameters = function () { return [
        { type: RolesFacade },
        { type: SistemasFacade }
    ]; };
    SelectRolesComponent.propDecorators = {
        roles: [{ type: Input }],
        insert: [{ type: Output }],
        remove: [{ type: Output }]
    };
    return SelectRolesComponent;
}(ObserverComponent));

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
var HasRoleInListPipe = /** @class */ (function () {
    function HasRoleInListPipe() {
    }
    /**
     * @param {?} role
     * @param {?} roles
     * @return {?}
     */
    HasRoleInListPipe.prototype.transform = /**
     * @param {?} role
     * @param {?} roles
     * @return {?}
     */
    function (role, roles) {
        return roles.filter(function (userRole) { return userRole.name === role.name; }).length > 0;
    };
    HasRoleInListPipe.decorators = [
        { type: Pipe, args: [{ name: 'hasRoleInList' },] }
    ];
    return HasRoleInListPipe;
}());

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/** @type {?} */
var tranlation$2 = {
    'roles': {
        'select': {
            'title': 'Permissões',
        }
    }
};

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/** @type {?} */
var tranlation$3 = {};

var _a$3;
/** @type {?} */
var translations$1 = (_a$3 = {},
    _a$3[LocalesTypes.ptBr] = tranlation$2,
    _a$3[LocalesTypes.en] = tranlation$3,
    _a$3);

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/** @type {?} */
var providers$4 = [
    RolesService,
    RolesFacade,
    RolesEffects
];
var ɵ0$4 = translations$1;
var RolesModule = /** @class */ (function () {
    function RolesModule(translateService, localesService) {
        localesService.initChild(translateService);
    }
    /**
     * @return {?}
     */
    RolesModule.forRoot = /**
     * @return {?}
     */
    function () {
        return {
            ngModule: RolesModule,
            providers: providers$4
        };
    };
    RolesModule.decorators = [
        { type: NgModule, args: [{
                    declarations: [
                        SelectRolesComponent,
                        HasRoleInListPipe
                    ],
                    exports: [
                        SelectRolesComponent,
                        HasRoleInListPipe
                    ],
                    imports: [
                        CommonModule,
                        FormsModule,
                        LocalesModule,
                        TranslateModule.forChild({
                            loader: {
                                provide: TranslateLoader,
                                useClass: LocaleLoader
                            },
                            isolate: true
                        }),
                    ],
                    providers: __spread(providers$4, [
                        {
                            provide: 'translations',
                            useValue: ɵ0$4
                        }
                    ])
                },] }
    ];
    /** @nocollapse */
    RolesModule.ctorParameters = function () { return [
        { type: TranslateService },
        { type: LocalesService }
    ]; };
    return RolesModule;
}());

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
var SubsidiariesService = /** @class */ (function () {
    function SubsidiariesService(http, apiHost) {
        this.http = http;
        this.apiHost = apiHost;
    }
    /**
     * @return {?}
     */
    SubsidiariesService.prototype.fetchAll = /**
     * @return {?}
     */
    function () {
        return this.http.get(this.apiHost.url + "/Subsidiary/Segment/GetAll");
    };
    /**
     * @param {?} request
     * @return {?}
     */
    SubsidiariesService.prototype.updateUserSubsidiaries = /**
     * @param {?} request
     * @return {?}
     */
    function (request) {
        return this.http.post(this.apiHost.url + "/Subsidiary/Segment/UpdateLot", request);
    };
    SubsidiariesService.decorators = [
        { type: Injectable, args: [{
                    providedIn: 'root'
                },] }
    ];
    /** @nocollapse */
    SubsidiariesService.ctorParameters = function () { return [
        { type: HttpClient },
        { type: Host, decorators: [{ type: Inject, args: ['apiHostService',] }] }
    ]; };
    /** @nocollapse */ SubsidiariesService.ngInjectableDef = defineInjectable({ factory: function SubsidiariesService_Factory() { return new SubsidiariesService(inject(HttpClient), inject("apiHostService")); }, token: SubsidiariesService, providedIn: "root" });
    return SubsidiariesService;
}());

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/** @enum {string} */
var SubsidiariesActionTypes = {
    FetchAllData: '[Subsidiaries] Fetch All Data',
    DataFetched: '[Subsidiaries] Data Fetched',
    DataFetchFailed: '[Subsidiaries] Data Fetch Failed',
    UpdateUserSubsidiaries: '[Subsidiaries] Update User Subsidiaries',
};
var FetchAllData = /** @class */ (function () {
    function FetchAllData() {
        this.type = SubsidiariesActionTypes.FetchAllData;
    }
    return FetchAllData;
}());
var DataFetched = /** @class */ (function () {
    function DataFetched(payload) {
        this.payload = payload;
        this.type = SubsidiariesActionTypes.DataFetched;
    }
    return DataFetched;
}());
var DataFetchFailed = /** @class */ (function () {
    function DataFetchFailed() {
        this.type = SubsidiariesActionTypes.DataFetchFailed;
    }
    return DataFetchFailed;
}());
var UpdateUserSubsidiaries = /** @class */ (function () {
    function UpdateUserSubsidiaries(payload) {
        this.payload = payload;
        this.type = SubsidiariesActionTypes.UpdateUserSubsidiaries;
    }
    return UpdateUserSubsidiaries;
}());

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/** @type {?} */
var subsidiaryAdapter = createEntityAdapter({
    selectId: selectSubsidiaryId
});
/**
 * @param {?} a
 * @return {?}
 */
function selectSubsidiaryId(a) {
    //In this case this would be optional since primary key is id
    return a.segment.id;
}
/** @type {?} */
var subsidiariesInitialState = subsidiaryAdapter.getInitialState();
/**
 * @param {?=} state
 * @param {?=} action
 * @return {?}
 */
function subsidiariesReducer(state, action) {
    if (state === void 0) { state = subsidiariesInitialState; }
    switch (action.type) {
        case SubsidiariesActionTypes.DataFetched:
            return subsidiaryAdapter.upsertMany(action.payload.data, state);
        default:
            return state;
    }
}
/** @type {?} */
var subsidiariesSelectors = subsidiaryAdapter.getSelectors();
/** @type {?} */
var selectSubsidiariesIds = subsidiariesSelectors.selectIds;
/** @type {?} */
var selectSubsidiariesEntities = subsidiariesSelectors.selectEntities;
/** @type {?} */
var selectAllSubsidiaries = subsidiariesSelectors.selectAll;
/** @type {?} */
var selectSubsidiary = function (id) {
    return function (state) {
        return state.entities[id] || null;
    };
};
/** @type {?} */
var hasSubsidiary = function (id, subsidiaries) {
    return subsidiaries.some(function (subsidiary) { return subsidiary.id === id; });
};
/** @type {?} */
var filterSubsidiary = function () { };
/** @type {?} */
var selectSubsidiariesState = createFeatureSelector('subsidiaries');

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/** @enum {string} */
var UpdateUserSubsidiaryActionsTypes = {
    inserted: 'inserted',
    deleted: 'deleted',
    none: 'none',
};
var AddUserSubsidiaryRequest = /** @class */ (function () {
    function AddUserSubsidiaryRequest(username, segmentId) {
        this.username = username;
        this.segmentId = segmentId;
        this.insertUpdate = true;
    }
    return AddUserSubsidiaryRequest;
}());
var RemoveUserSubsidiaryRequest = /** @class */ (function () {
    function RemoveUserSubsidiaryRequest(username, segmentId) {
        this.username = username;
        this.segmentId = segmentId;
        this.insertUpdate = false;
    }
    return RemoveUserSubsidiaryRequest;
}());

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
var SubsidiariesFacade = /** @class */ (function () {
    function SubsidiariesFacade(store) {
        this.store = store;
        this.subsidiaries$ = this.selectSubsidiaries();
    }
    /**
     * @return {?}
     */
    SubsidiariesFacade.prototype.selectSubsidiaries = /**
     * @return {?}
     */
    function () {
        var _this = this;
        return this.store.pipe(select(selectSubsidiariesState), map(selectAllSubsidiaries), tap(function (subsidiaries) {
            if (subsidiaries.length === 0) {
                _this.fetchAll();
            }
        }), filter(function (subsidiaries) { return subsidiaries.length > 0; }), map(function (subsidiaries) { return subsidiaries.sort(function (a, b) { return a.companyId.toString().localeCompare(b.companyId.toString(), 'en', { numeric: true }) || a.subsidiary.toString().localeCompare(b.subsidiary.toString(), 'en', { numeric: true }); }); }));
    };
    /**
     * @return {?}
     */
    SubsidiariesFacade.prototype.fetchAll = /**
     * @return {?}
     */
    function () {
        this.store.dispatch(new FetchAllData);
    };
    /**
     * @param {?} usuario
     * @param {?} subsidiariesIds
     * @return {?}
     */
    SubsidiariesFacade.prototype.insertUserSubsidiaries = /**
     * @param {?} usuario
     * @param {?} subsidiariesIds
     * @return {?}
     */
    function (usuario, subsidiariesIds) {
        /** @type {?} */
        var requests = subsidiariesIds.map(function (id) {
            return new AddUserSubsidiaryRequest(usuario.userName, id);
        });
        this.store.dispatch(new UpdateUserSubsidiaries(requests));
    };
    /**
     * @param {?} usuario
     * @param {?} subsidiariesIds
     * @return {?}
     */
    SubsidiariesFacade.prototype.removeUserSubsidiaries = /**
     * @param {?} usuario
     * @param {?} subsidiariesIds
     * @return {?}
     */
    function (usuario, subsidiariesIds) {
        /** @type {?} */
        var requests = subsidiariesIds.map(function (id) { return new RemoveUserSubsidiaryRequest(usuario.userName, id); });
        this.store.dispatch(new UpdateUserSubsidiaries(requests));
    };
    SubsidiariesFacade.decorators = [
        { type: Injectable, args: [{
                    providedIn: 'root'
                },] }
    ];
    /** @nocollapse */
    SubsidiariesFacade.ctorParameters = function () { return [
        { type: Store }
    ]; };
    /** @nocollapse */ SubsidiariesFacade.ngInjectableDef = defineInjectable({ factory: function SubsidiariesFacade_Factory() { return new SubsidiariesFacade(inject(Store)); }, token: SubsidiariesFacade, providedIn: "root" });
    return SubsidiariesFacade;
}());

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
var SubsidiariesEffects = /** @class */ (function () {
    function SubsidiariesEffects(actions$, dataPersistence, service) {
        var _this = this;
        this.actions$ = actions$;
        this.dataPersistence = dataPersistence;
        this.service = service;
        this.fetchAll$ = this.dataPersistence.fetch(SubsidiariesActionTypes.FetchAllData, {
            id: function () { return SubsidiariesActionTypes.FetchAllData; },
            run: function (action, state) {
                return _this.service.fetchAll()
                    .pipe(map(function (res) { return new DataFetched(res); }), take(1), catchError(function (error) { return of(new DataFetchFailed); }));
            },
            onError: function (action, error) {
                console.error('Error', error);
            }
        });
        this.updateUserSubsidiaries$ = this.dataPersistence.pessimisticUpdate(SubsidiariesActionTypes.UpdateUserSubsidiaries, {
            run: function (action, state) {
                return _this.service.updateUserSubsidiaries(action.payload)
                    .pipe(take(1), map(function (responses) { return responses.filter(function (response) { return response.action !== UpdateUserSubsidiaryActionsTypes.none; }); }), switchMap(function (itens) { return itens.map(function (response) {
                    switch (response.action) {
                        case UpdateUserSubsidiaryActionsTypes.inserted:
                            return new UsuarioSubsidiaryInserted(new UsuarioSubsidiaryInsertData(response.email, selectSubsidiary(response.segmentId)(selectSubsidiariesState(state))));
                        case UpdateUserSubsidiaryActionsTypes.deleted:
                            return new UsuarioSubsidiaryRemoved(new UsuarioSubsidiaryRemoveData(response.email, selectSubsidiary(response.segmentId)(selectSubsidiariesState(state))));
                    }
                }); }));
            },
            onError: function (action, error) {
                console.error('Error', error);
            }
        });
    }
    /**
     * @param {...?} types
     * @return {?}
     */
    SubsidiariesEffects.prototype.ofType = /**
     * @param {...?} types
     * @return {?}
     */
    function () {
        var types = [];
        for (var _i = 0; _i < arguments.length; _i++) {
            types[_i] = arguments[_i];
        }
        return this.actions$.pipe(filter(function (action) { return types.indexOf(action.type) !== -1; }));
    };
    SubsidiariesEffects.decorators = [
        { type: Injectable, args: [{ providedIn: 'root' },] }
    ];
    /** @nocollapse */
    SubsidiariesEffects.ctorParameters = function () { return [
        { type: Actions },
        { type: DataPersistence },
        { type: SubsidiariesService }
    ]; };
    /** @nocollapse */ SubsidiariesEffects.ngInjectableDef = defineInjectable({ factory: function SubsidiariesEffects_Factory() { return new SubsidiariesEffects(inject(Actions), inject(DataPersistence), inject(SubsidiariesService)); }, token: SubsidiariesEffects, providedIn: "root" });
    __decorate([
        Effect(),
        __metadata("design:type", Object)
    ], SubsidiariesEffects.prototype, "fetchAll$", void 0);
    __decorate([
        Effect(),
        __metadata("design:type", Object)
    ], SubsidiariesEffects.prototype, "updateUserSubsidiaries$", void 0);
    return SubsidiariesEffects;
}());

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
var SelectSubsidiariesComponent = /** @class */ (function () {
    function SelectSubsidiariesComponent(subsidiariesFacade) {
        this.subsidiariesFacade = subsidiariesFacade;
        this.insert = new EventEmitter();
        this.remove = new EventEmitter();
        this.selectedSubsidiaries = [];
        this.selectedUsuarioSubsidiaries = [];
    }
    /**
     * @return {?}
     */
    SelectSubsidiariesComponent.prototype.ngOnInit = /**
     * @return {?}
     */
    function () {
        var _this = this;
        this.subsidiariesFacade.selectSubsidiaries().subscribe(function (subsidiaries) {
            _this.subsidiaryList = subsidiaries;
        });
    };
    /**
     * @param {?} segmentIds
     * @return {?}
     */
    SelectSubsidiariesComponent.prototype.insertSubsidiaries = /**
     * @param {?} segmentIds
     * @return {?}
     */
    function (segmentIds) {
        /** @type {?} */
        var subsidiaries = this.subsidiaryList.filter(function (subsidiary) { return segmentIds.indexOf(subsidiary.segment.id) !== -1; });
        this.insert.emit(subsidiaries);
        this.selectedSubsidiaries = [];
    };
    /**
     * @param {?} segmentIds
     * @return {?}
     */
    SelectSubsidiariesComponent.prototype.removeSubsidiaries = /**
     * @param {?} segmentIds
     * @return {?}
     */
    function (segmentIds) {
        /** @type {?} */
        var subsidiaries = this.subsidiaryList.filter(function (subsidiary) { return segmentIds.indexOf(subsidiary.segment.id) !== -1; });
        this.remove.emit(subsidiaries);
        this.selectedUsuarioSubsidiaries = [];
    };
    /**
     * @param {?} subsidiary
     * @return {?}
     */
    SelectSubsidiariesComponent.prototype.maskedValue = /**
     * @param {?} subsidiary
     * @return {?}
     */
    function (subsidiary) {
        return "(" + subsidiary.companyId + "/" + subsidiary.subsidiary + ") " + subsidiary.fantasyName;
    };
    SelectSubsidiariesComponent.decorators = [
        { type: Component, args: [{
                    selector: 'core-select-subsidiaries',
                    template: "<div class=\"card\">\r\n    <div class=\"card-header border-bottom-0\">\r\n        <i class=\"fa fa-building\"></i> {{ 'subsidiaries.select.title' | translate }}\r\n    </div>\r\n    <div class=\"card-body\">\r\n        <th class=\"py-1 border-top-0\" [attr.colspan]=\"2\">\r\n            <input type=\"search\" class=\"form-control form-control-sm\"\r\n                [placeholder]=\"'subsidiaries.select.search' | translate\" [(ngModel)]=\"searchFilterString\">\r\n        </th>\r\n        <div class=\"form-row\">\r\n            <div class=\"col-12 col-md-5\">\r\n                <select [(ngModel)]=\"selectedSubsidiaries\" class=\"form-control subsidiaries-select\" multiple>\r\n                    <option *ngFor=\"let subsidiary of subsidiaryList | filterSubsidiary:searchFilterString\"\r\n                        [value]=\"subsidiary.segment.id\" [disabled]=\"subsidiary | hasSubsidiary:subsidiaries\">\r\n                        ({{ subsidiary.companyId }}/{{\r\n                        subsidiary.subsidiary }}) - {{ subsidiary.fantasyName }} {{ subsidiary.segment !== null\r\n                        ? \" - (\"+ subsidiary.segment.segment + \" / \" +subsidiary.segment.name + \")\" : \"\"}}</option>\r\n                </select>\r\n            </div>\r\n            <div class=\"col-12 col-md-2 d-flex flex-column justify-content-center align-items-center my-2\">\r\n                <div class=\"mb-3\">\r\n                    <button type=\"button\" class=\"btn btn-primary\" [disabled]=\"selectedSubsidiaries.length === 0\"\r\n                        (click)=\"insertSubsidiaries(selectedSubsidiaries)\">\r\n                        >>\r\n                    </button>\r\n                </div>\r\n                <div>\r\n                    <button type=\"button\" class=\"btn btn-primary\" [disabled]=\"selectedUsuarioSubsidiaries.length === 0\"\r\n                        (click)=\"removeSubsidiaries(selectedUsuarioSubsidiaries)\">\r\n                        << </button>\r\n                </div>\r\n            </div>\r\n            <div class=\"col-12 col-md-5\">\r\n                <select [(ngModel)]=\"selectedUsuarioSubsidiaries\" class=\"form-control subsidiaries-select\" multiple>\r\n                    <option *ngFor=\"let subsidiary of subsidiaries\" [value]=\"subsidiary.segment.id\">({{\r\n                        subsidiary.companyId\r\n                        }}/{{ subsidiary.subsidiary }}) - {{ subsidiary.fantasyName }} {{ subsidiary.segment !== null\r\n                        ? \" - (\"+ subsidiary.segment.segment + \" / \" +subsidiary.segment.name + \")\" : \"\"}}\r\n                    </option>\r\n                </select>\r\n            </div>\r\n        </div>\r\n    </div>\r\n</div>",
                    styles: [".subsidiaries-select{min-height:35vh}"]
                }] }
    ];
    /** @nocollapse */
    SelectSubsidiariesComponent.ctorParameters = function () { return [
        { type: SubsidiariesFacade }
    ]; };
    SelectSubsidiariesComponent.propDecorators = {
        subsidiaries: [{ type: Input }],
        insert: [{ type: Output }],
        remove: [{ type: Output }]
    };
    return SelectSubsidiariesComponent;
}());

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
var HasSubsidiaryPipe = /** @class */ (function () {
    function HasSubsidiaryPipe() {
    }
    /**
     * @param {?} subsidiary
     * @param {?} subsidiaries
     * @return {?}
     */
    HasSubsidiaryPipe.prototype.transform = /**
     * @param {?} subsidiary
     * @param {?} subsidiaries
     * @return {?}
     */
    function (subsidiary, subsidiaries) {
        return subsidiaries.filter(function (userSubsidiary) { return userSubsidiary.segment && userSubsidiary.segment.id === subsidiary.segment.id; }).length > 0;
    };
    HasSubsidiaryPipe.decorators = [
        { type: Pipe, args: [{ name: 'hasSubsidiary' },] }
    ];
    return HasSubsidiaryPipe;
}());
var FilterSubsidiaryPipe = /** @class */ (function () {
    function FilterSubsidiaryPipe() {
    }
    /**
     * @param {?} subsidiaries
     * @param {?=} searchText
     * @return {?}
     */
    FilterSubsidiaryPipe.prototype.transform = /**
     * @param {?} subsidiaries
     * @param {?=} searchText
     * @return {?}
     */
    function (subsidiaries, searchText) {
        if (searchText === void 0) { searchText = ''; }
        if (!subsidiaries)
            return subsidiaries;
        if (!searchText)
            return subsidiaries;
        searchText = searchText.toLowerCase();
        return subsidiaries.filter(function (item) { return (item.companyId.toString() + item.subsidiary.toString() + item.fantasyName.toLowerCase() + item.segment.segment + item.segment.name.toLowerCase()).indexOf(searchText) !== -1; });
    };
    FilterSubsidiaryPipe.decorators = [
        { type: Pipe, args: [{ name: 'filterSubsidiary' },] }
    ];
    return FilterSubsidiaryPipe;
}());

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/** @type {?} */
var tranlation$4 = {
    'subsidiaries': {
        'select': {
            'title': 'Filiais / Segmentos',
            'search': 'Filtrar filial/segmento'
        }
    }
};

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/** @type {?} */
var tranlation$5 = {};

var _a$4;
/** @type {?} */
var translations$2 = (_a$4 = {},
    _a$4[LocalesTypes.ptBr] = tranlation$4,
    _a$4[LocalesTypes.en] = tranlation$5,
    _a$4);

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/** @type {?} */
var providers$5 = [
    SubsidiariesService,
    SubsidiariesFacade,
    SubsidiariesEffects
];
var ɵ0$5 = translations$2;
var SubsidiariesModule = /** @class */ (function () {
    function SubsidiariesModule(translateService, localesService) {
        localesService.initChild(translateService);
    }
    /**
     * @return {?}
     */
    SubsidiariesModule.forRoot = /**
     * @return {?}
     */
    function () {
        return {
            ngModule: SubsidiariesModule,
            providers: providers$5
        };
    };
    SubsidiariesModule.decorators = [
        { type: NgModule, args: [{
                    declarations: [
                        SelectSubsidiariesComponent,
                        HasSubsidiaryPipe,
                        FilterSubsidiaryPipe
                    ],
                    exports: [
                        SelectSubsidiariesComponent,
                        HasSubsidiaryPipe,
                        FilterSubsidiaryPipe
                    ],
                    imports: [
                        CommonModule,
                        FormsModule,
                        LocalesModule,
                        TranslateModule.forChild({
                            loader: {
                                provide: TranslateLoader,
                                useClass: LocaleLoader
                            },
                            isolate: true
                        }),
                    ],
                    providers: __spread(providers$5, [
                        {
                            provide: 'translations',
                            useValue: ɵ0$5
                        }
                    ])
                },] }
    ];
    /** @nocollapse */
    SubsidiariesModule.ctorParameters = function () { return [
        { type: TranslateService },
        { type: LocalesService }
    ]; };
    return SubsidiariesModule;
}());

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
var UsuariosService = /** @class */ (function () {
    function UsuariosService(http, apiHost) {
        this.http = http;
        this.apiHost = apiHost;
    }
    /**
     * @param {?} number
     * @return {?}
     */
    UsuariosService.prototype.fetchPageData = /**
     * @param {?} number
     * @return {?}
     */
    function (number) {
        /** @type {?} */
        var params = new HttpParams().set('page', number.toString());
        return this.http.get(this.apiHost.url + "/user/GetAllUsersByPagination", { params: params });
    };
    /**
     * @param {?} data
     * @return {?}
     */
    UsuariosService.prototype.createUsuario = /**
     * @param {?} data
     * @return {?}
     */
    function (data) {
        return this.http.post(this.apiHost.url + "/user/create", data).pipe(map(function (res) { return res.data; }), catchError(function (errorResponse) {
            throw errorResponse.error.message;
        }));
    };
    /**
     * @param {?} usuario
     * @return {?}
     */
    UsuariosService.prototype.toggleAcessUsuario = /**
     * @param {?} usuario
     * @return {?}
     */
    function (usuario) {
        /** @type {?} */
        var LockoutEnabled = !usuario.lockoutEnabled;
        return this.http.post(this.apiHost.url + "/user/UpdateAccessUserByEmail", {
            email: usuario.userName,
            LockoutEnabled: LockoutEnabled
        }).pipe(map(function (res) {
            if (res.success) {
                return __assign({}, usuario, { lockoutEnabled: LockoutEnabled });
            }
            return usuario;
        }));
    };
    /**
     * @param {?} userName
     * @return {?}
     */
    UsuariosService.prototype.getUsuario = /**
     * @param {?} userName
     * @return {?}
     */
    function (userName) {
        /** @type {?} */
        var params = new HttpParams().set('UserName', userName);
        return this.http.get(this.apiHost.url + "/user/getusername", { params: params }).pipe(map(function (res) { return res.data; }));
    };
    /**
     * @param {?} request
     * @return {?}
     */
    UsuariosService.prototype.updateUsuarioHostFirewall = /**
     * @param {?} request
     * @return {?}
     */
    function (request) {
        return this.http.post(this.apiHost.url + "/user/UpdateHostFirewallUserByEmail", request);
    };
    UsuariosService.decorators = [
        { type: Injectable, args: [{
                    providedIn: 'root'
                },] }
    ];
    /** @nocollapse */
    UsuariosService.ctorParameters = function () { return [
        { type: HttpClient },
        { type: Host, decorators: [{ type: Inject, args: ['apiHostService',] }] }
    ]; };
    /** @nocollapse */ UsuariosService.ngInjectableDef = defineInjectable({ factory: function UsuariosService_Factory() { return new UsuariosService(inject(HttpClient), inject("apiHostService")); }, token: UsuariosService, providedIn: "root" });
    return UsuariosService;
}());

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
var ɵ0$6 = function (usuario) { return usuario.userName; };
/** @type {?} */
var usuarioAdapter$1 = createEntityAdapter({
    selectId: ɵ0$6
});
/** @type {?} */
var usuariosInitialState = usuarioAdapter$1.getInitialState({
    currentUsuario: null,
    filters: {},
    metadata: new InitialPaginationMetadata,
});
/** @type {?} */
var insertUsarioRole = function (usuario, role) {
    return __assign({}, usuario, { roles: __spread(usuario.roles, [role]) });
};
/** @type {?} */
var removeUsuarioRole = function (usuario, role) {
    return __assign({}, usuario, { roles: usuario.roles.filter(function (userRole) { return userRole.name !== role.name; }) });
};
/** @type {?} */
var insertUsarioSubsidiary = function (usuario, subsidiary) {
    return __assign({}, usuario, { subsidiaries: __spread(usuario.subsidiaries, [subsidiary]) });
};
/** @type {?} */
var removeUsuarioSubsidiary = function (usuario, subsidiary) {
    return __assign({}, usuario, { subsidiaries: usuario.subsidiaries.filter(function (userSubsidiary) { return userSubsidiary.segment.id !== subsidiary.segment.id; }) });
};
/** @type {?} */
var updateHostFirewall = function (usuario, ips) {
    return __assign({}, usuario, { hostFirewall: ips.join(',') });
};
/** @type {?} */
var selectUsuario = function (userName) {
    return function (state) {
        return state.entities[userName] || null;
    };
};
/**
 * @param {?=} state
 * @param {?=} action
 * @return {?}
 */
function usuariosReducer(state, action) {
    if (state === void 0) { state = usuariosInitialState; }
    switch (action.type) {
        case UsuariosActionTypes.PageDataFetched:
            return __assign({}, usuarioAdapter$1.upsertMany(action.payload.data, state), { metadata: action.payload.metadata });
        case UsuariosActionTypes.ResetPagination:
            return __assign({}, state, resetPagination(state));
        case UsuariosActionTypes.SelectUsuario:
            return __assign({}, state, { currentUsuario: action.payload });
        case UsuariosActionTypes.UpdateUsuarioState:
            return usuarioAdapter$1.upsertOne(action.payload, state);
        case UsuariosActionTypes.UsuarioRoleInserted:
            return usuarioAdapter$1.upsertOne(insertUsarioRole(selectUsuario(action.payload.userName)(state), action.payload.role), state);
        case UsuariosActionTypes.UsuarioRoleRemoved:
            return usuarioAdapter$1.upsertOne(removeUsuarioRole(selectUsuario(action.payload.userName)(state), action.payload.role), state);
        case UsuariosActionTypes.UsuarioSubsidiaryInserted:
            return usuarioAdapter$1.upsertOne(insertUsarioSubsidiary(selectUsuario(action.payload.userName)(state), action.payload.subsidiary), state);
        case UsuariosActionTypes.UsuarioSubsidiaryRemoved:
            return usuarioAdapter$1.upsertOne(removeUsuarioSubsidiary(selectUsuario(action.payload.userName)(state), action.payload.subsidiary), state);
        case UsuariosActionTypes.UsuarioHostFirewallUpdated:
            return usuarioAdapter$1.upsertOne(updateHostFirewall(selectUsuario(action.payload.email)(state), action.payload.hostfirewall), state);
        default:
            return state;
    }
}
var _a$5 = usuarioAdapter$1.getSelectors(), selectIds$2 = _a$5.selectIds, selectEntities$2 = _a$5.selectEntities, selectAll$2 = _a$5.selectAll;
/** @type {?} */
var selectUsuariosIds = selectIds$2;
/** @type {?} */
var selectUsuariosEntities = selectEntities$2;
/** @type {?} */
var selectAllUsuarios = selectAll$2;
/** @type {?} */
var getCurrentUsuario = function (state) {
    return state.entities[state.currentUsuario] || null;
};
/** @type {?} */
var selectUsuariosState = createFeatureSelector('usuarios');

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
var UsuariosFacade = /** @class */ (function () {
    function UsuariosFacade(store) {
        this.store = store;
        this.usuarios$ = this.selectUsuarios();
        this.currentUsuario$ = store.pipe(select(selectUsuariosState), select(getCurrentUsuario));
        this.pagination$ = store.pipe(select(selectUsuariosState), map(function (state) { return state.metadata; }));
    }
    /**
     * @return {?}
     */
    UsuariosFacade.prototype.selectUsuarios = /**
     * @return {?}
     */
    function () {
        return this.store.pipe(select(selectUsuariosState), map(selectAllUsuarios), share());
    };
    /**
     * @param {?} userName
     * @return {?}
     */
    UsuariosFacade.prototype.selectUser = /**
     * @param {?} userName
     * @return {?}
     */
    function (userName) {
        var _this = this;
        return this.store.pipe(select(selectUsuariosState), map(selectUsuario(userName)), tap(function (usuario) {
            if (usuario === null) {
                _this.fetchUsuarioData(userName);
            }
        }), filter(function (usuario) { return usuario !== null; }));
    };
    /**
     * @return {?}
     */
    UsuariosFacade.prototype.loadPage = /**
     * @return {?}
     */
    function () {
        this.store.dispatch(new LoadPage$1);
    };
    /**
     * @return {?}
     */
    UsuariosFacade.prototype.resetPagination = /**
     * @return {?}
     */
    function () {
        this.store.dispatch(new ResetPagination$1);
    };
    /**
     * @param {?} userName
     * @return {?}
     */
    UsuariosFacade.prototype.selectCurrentUsuario = /**
     * @param {?} userName
     * @return {?}
     */
    function (userName) {
        this.store.dispatch(new SelectUsuario(userName));
    };
    /**
     * @param {?} userName
     * @return {?}
     */
    UsuariosFacade.prototype.fetchUsuarioData = /**
     * @param {?} userName
     * @return {?}
     */
    function (userName) {
        this.store.dispatch(new FetchUsuarioData(userName));
    };
    /**
     * @param {?} data
     * @return {?}
     */
    UsuariosFacade.prototype.createUsuario = /**
     * @param {?} data
     * @return {?}
     */
    function (data) {
        this.store.dispatch(new CreateUsuario(data));
    };
    /**
     * @param {?} usuario
     * @return {?}
     */
    UsuariosFacade.prototype.toggleAccessUsuario = /**
     * @param {?} usuario
     * @return {?}
     */
    function (usuario) {
        this.store.dispatch(new ToggleUsuarioAcess(usuario));
    };
    /**
     * @param {?} usuario
     * @param {?} ips
     * @return {?}
     */
    UsuariosFacade.prototype.updateUsuarioHostFirewall = /**
     * @param {?} usuario
     * @param {?} ips
     * @return {?}
     */
    function (usuario, ips) {
        /** @type {?} */
        var request = {
            email: usuario.email,
            hostfirewall: ips
        };
        this.store.dispatch(new UpdateUsuarioHostFirewall(request));
    };
    UsuariosFacade.decorators = [
        { type: Injectable, args: [{
                    providedIn: 'root'
                },] }
    ];
    /** @nocollapse */
    UsuariosFacade.ctorParameters = function () { return [
        { type: Store }
    ]; };
    /** @nocollapse */ UsuariosFacade.ngInjectableDef = defineInjectable({ factory: function UsuariosFacade_Factory() { return new UsuariosFacade(inject(Store)); }, token: UsuariosFacade, providedIn: "root" });
    return UsuariosFacade;
}());

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
var UsuariosEffects = /** @class */ (function () {
    function UsuariosEffects(actions$, dataPersistence, service) {
        var _this = this;
        this.actions$ = actions$;
        this.dataPersistence = dataPersistence;
        this.service = service;
        this.loadPage$ = this.dataPersistence.fetch(UsuariosActionTypes.LoadPage, {
            id: function (action, state) {
                return getNextPage(selectUsuariosState(state));
            },
            run: function (action, state) {
                /** @type {?} */
                var page = getNextPage(selectUsuariosState(state));
                if (page === null) {
                    return;
                }
                return _this.service.fetchPageData(page)
                    .pipe(map(function (res) { return new PageDataFetched$1(res); }), take(1), catchError(function (error) { return of(new PageDataFetchFailed$1(page)); }));
            },
            onError: function (action, error) {
                console.error('Error', error);
            }
        });
        this.createUsuario$ = this.dataPersistence.pessimisticUpdate(UsuariosActionTypes.CreateUsuario, {
            run: function (action) {
                return _this.service.createUsuario(action.payload)
                    .pipe(map(function (usuario) { return new UsuarioCreated(usuario); }), take(1), catchError(function (error) { return of(new UsuarioCreateFailed(error)); }));
            },
            onError: function (action, error) {
                console.error('Error', error);
            }
        });
        this.usuarioCreated$ = this.dataPersistence.pessimisticUpdate(UsuariosActionTypes.UsuarioCreated, {
            run: function (action) {
                return of(new UpdateUsuarioState(action.payload));
            },
            onError: function (action, error) {
                console.error('Error', error);
            }
        });
        this.selectUsuario$ = this.dataPersistence.fetch(UsuariosActionTypes.SelectUsuario, {
            run: function (action, state) {
                /** @type {?} */
                var usuario = getCurrentUsuario(state.usuarios);
                return of(new FetchUsuarioData(action.payload));
            },
            onError: function (action, error) {
                console.error('Error', error);
            }
        });
        this.fetchUsuario$ = this.dataPersistence.fetch(UsuariosActionTypes.FetchUsuarioData, {
            id: function (action, state) {
                return action.payload;
            },
            run: function (action, state) {
                return _this.service.getUsuario(action.payload).pipe(map(function (usuario) { return new UpdateUsuarioState(usuario); }), take(1));
            },
            onError: function (action, error) {
                console.error('Error', error);
            }
        });
        this.toggleAcessUsuario$ = this.dataPersistence.pessimisticUpdate(UsuariosActionTypes.ToggleAccessUsuario, {
            run: function (action) {
                return _this.service.toggleAcessUsuario(action.payload)
                    .pipe(map(function (usuario) { return new UpdateUsuarioState(usuario); }), take(1));
            },
            onError: function (action, error) {
                console.error('Error', error);
            }
        });
        this.updateUsuarioHostFirewall$ = this.dataPersistence.pessimisticUpdate(UsuariosActionTypes.UpdateUsuarioHostFirewall, {
            run: function (action) {
                return _this.service.updateUsuarioHostFirewall(action.payload)
                    .pipe(filter(function (response) { return response.success; }), map(function () { return new UsuarioHostFirewallUpdated(action.payload); }), take(1));
            },
            onError: function (action, error) {
                console.error('Error', error);
            }
        });
    }
    /**
     * @param {...?} types
     * @return {?}
     */
    UsuariosEffects.prototype.ofType = /**
     * @param {...?} types
     * @return {?}
     */
    function () {
        var types = [];
        for (var _i = 0; _i < arguments.length; _i++) {
            types[_i] = arguments[_i];
        }
        return this.actions$.pipe(filter(function (action) { return types.indexOf(action.type) !== -1; }));
    };
    UsuariosEffects.decorators = [
        { type: Injectable, args: [{ providedIn: 'root' },] }
    ];
    /** @nocollapse */
    UsuariosEffects.ctorParameters = function () { return [
        { type: Actions },
        { type: DataPersistence },
        { type: UsuariosService }
    ]; };
    /** @nocollapse */ UsuariosEffects.ngInjectableDef = defineInjectable({ factory: function UsuariosEffects_Factory() { return new UsuariosEffects(inject(Actions), inject(DataPersistence), inject(UsuariosService)); }, token: UsuariosEffects, providedIn: "root" });
    __decorate([
        Effect(),
        __metadata("design:type", Object)
    ], UsuariosEffects.prototype, "loadPage$", void 0);
    __decorate([
        Effect(),
        __metadata("design:type", Object)
    ], UsuariosEffects.prototype, "createUsuario$", void 0);
    __decorate([
        Effect(),
        __metadata("design:type", Object)
    ], UsuariosEffects.prototype, "usuarioCreated$", void 0);
    __decorate([
        Effect(),
        __metadata("design:type", Object)
    ], UsuariosEffects.prototype, "selectUsuario$", void 0);
    __decorate([
        Effect(),
        __metadata("design:type", Object)
    ], UsuariosEffects.prototype, "fetchUsuario$", void 0);
    __decorate([
        Effect(),
        __metadata("design:type", Object)
    ], UsuariosEffects.prototype, "toggleAcessUsuario$", void 0);
    __decorate([
        Effect(),
        __metadata("design:type", Object)
    ], UsuariosEffects.prototype, "updateUsuarioHostFirewall$", void 0);
    return UsuariosEffects;
}());

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
var SelectUsuarioPipe = /** @class */ (function () {
    function SelectUsuarioPipe(usuariosFacade) {
        this.usuariosFacade = usuariosFacade;
    }
    /**
     * @param {?} userName
     * @return {?}
     */
    SelectUsuarioPipe.prototype.transform = /**
     * @param {?} userName
     * @return {?}
     */
    function (userName) {
        if (userName === null) {
            return null;
        }
        return this.usuariosFacade.selectUser(userName);
    };
    SelectUsuarioPipe.decorators = [
        { type: Pipe, args: [{ name: 'selectUsuario' },] }
    ];
    /** @nocollapse */
    SelectUsuarioPipe.ctorParameters = function () { return [
        { type: UsuariosFacade }
    ]; };
    return SelectUsuarioPipe;
}());

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/** @type {?} */
var providers$6 = [
    UsuariosService,
    UsuariosFacade,
    UsuariosEffects
];
var UsuariosModule = /** @class */ (function () {
    function UsuariosModule() {
    }
    /**
     * @return {?}
     */
    UsuariosModule.forRoot = /**
     * @return {?}
     */
    function () {
        return {
            ngModule: UsuariosModule,
            providers: providers$6
        };
    };
    UsuariosModule.decorators = [
        { type: NgModule, args: [{
                    declarations: [
                        SelectUsuarioPipe
                    ],
                    exports: [
                        SelectUsuarioPipe
                    ],
                    imports: [
                        CommonModule
                    ],
                    providers: providers$6
                },] }
    ];
    return UsuariosModule;
}());

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
var LocaleInterceptor = /** @class */ (function () {
    function LocaleInterceptor(translateService) {
        this.translateService = translateService;
    }
    /**
     * @param {?} request
     * @param {?} next
     * @return {?}
     */
    LocaleInterceptor.prototype.intercept = /**
     * @param {?} request
     * @param {?} next
     * @return {?}
     */
    function (request, next) {
        return next.handle(request.clone({
            setHeaders: {
                'X-Language': this.translateService.currentLang
            }
        }));
    };
    LocaleInterceptor.decorators = [
        { type: Injectable }
    ];
    /** @nocollapse */
    LocaleInterceptor.ctorParameters = function () { return [
        { type: TranslateService }
    ]; };
    return LocaleInterceptor;
}());

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
var ɵ0$7 = hostEnvFactory, ɵ1$1 = hostEnvFactory;
/** @type {?} */
var providers$7 = [
    EnvServiceProvider,
    JwtConfig,
    RefreshTokenInterceptor,
    JwtInterceptor,
    LocaleInterceptor,
    SubsidiaryInterceptor,
    {
        provide: 'apiHost',
        useValue: 'apiHost'
    },
    {
        provide: 'apiOauthHost',
        useValue: 'apiOauthHost'
    },
    {
        provide: 'apiHostService',
        useFactory: ɵ0$7,
        deps: [EnvService, [new Inject('apiHost')]]
    },
    {
        provide: 'apiOauthHostService',
        useFactory: ɵ1$1,
        deps: [EnvService, [new Inject('apiOauthHost')]]
    },
];
var ɵ2$1 = jwtOptionsFactory;
var ElisCoreModule = /** @class */ (function () {
    function ElisCoreModule() {
    }
    /**
     * @return {?}
     */
    ElisCoreModule.forRoot = /**
     * @return {?}
     */
    function () {
        return {
            ngModule: ElisCoreModule,
            providers: providers$7
        };
    };
    ElisCoreModule.decorators = [
        { type: NgModule, args: [{
                    declarations: [],
                    imports: [
                        NxModule,
                        StoreModule,
                        EffectsModule,
                        AlertModule.forRoot(),
                        LocalesModule.forRoot(),
                        AuthElisModule.forRoot(),
                        SistemasModule.forRoot(),
                        UsersADModule.forRoot(),
                        RolesModule.forRoot(),
                        SubsidiariesModule.forRoot(),
                        UsuariosModule.forRoot(),
                        JwtModule.forRoot({
                            jwtOptionsProvider: {
                                provide: JWT_OPTIONS,
                                useFactory: ɵ2$1,
                                deps: [JwtConfig, AuthFacade]
                            }
                        })
                    ],
                    exports: [],
                    providers: __spread(providers$7, [
                        {
                            provide: HTTP_INTERCEPTORS,
                            useClass: RefreshTokenInterceptor,
                            multi: true
                        },
                        {
                            provide: HTTP_INTERCEPTORS,
                            useExisting: JwtInterceptor,
                            multi: true
                        },
                        {
                            provide: HTTP_INTERCEPTORS,
                            useExisting: LocaleInterceptor,
                            multi: true
                        }
                    ])
                },] }
    ];
    return ElisCoreModule;
}());

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/**
 * @abstract
 */
var  /**
 * @abstract
 */
ScrollPagination = /** @class */ (function (_super) {
    __extends(ScrollPagination, _super);
    function ScrollPagination() {
        var _this = _super !== null && _super.apply(this, arguments) || this;
        _this.scrollIndex$ = new BehaviorSubject(0);
        return _this;
    }
    /**
     * @param {?} index
     * @return {?}
     */
    ScrollPagination.prototype.changeIndex = /**
     * @param {?} index
     * @return {?}
     */
    function (index) {
        this.scrollIndex$.next(index);
    };
    /**
     * @template T
     * @param {?} pagination$
     * @return {?}
     */
    ScrollPagination.prototype.selectToLoadPage = /**
     * @template T
     * @param {?} pagination$
     * @return {?}
     */
    function (pagination$) {
        return merge(pagination$.pipe(isInitialPagination()), this.scrollIndex$.pipe(distinctUntilChanged(), switchMap(function (index) { return pagination$.pipe(filterPaginationScrollPosition(index)); }))).pipe(throttleTime(200));
    };
    /**
     * @return {?}
     */
    ScrollPagination.prototype.ngOnDestroy = /**
     * @return {?}
     */
    function () {
        _super.prototype.ngOnDestroy.call(this);
        this.scrollIndex$.unsubscribe();
    };
    return ScrollPagination;
}(ObserverComponent));

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */

export { ObserverComponent, ScrollPagination, EnvService, EnvServiceProvider, hostEnvFactory, Host, AlertModule, AlertComponent, SistemasModule, SistemasService, SistemasFacade, SistemasEffects, SistemasActionTypes, UsersADModule, UsersADService, UsersADFacade, UsersAdEffects, UsersADActionTypes, RolesModule, RolesService, RolesFacade, RolesEffects, RolesActionTypes, SelectRolesComponent, HasRoleInListPipe, translations$1 as RolesTranslations, SubsidiariesModule, SubsidiariesService, SubsidiariesFacade, SubsidiariesEffects, SubsidiariesActionTypes, SelectSubsidiariesComponent, HasSubsidiaryPipe, FilterSubsidiaryPipe, translations$2 as SubsidiariesTranslations, UsuariosModule, UsuariosService, UsuariosFacade, UsuariosEffects, UsuariosActionTypes, SelectUsuarioPipe, AuthElisModule, AuthService, AuthGuardService, GuestGuardService, HasRoleGuardService, AuthFacade, AuthEffects, AuthActionTypes, JwtConfig, jwtOptionsFactory, translations as AuthModuleTranslations, AuthFormComponent, ChangePasswordComponent, HasRolePipe, LocalesModule, LocalesService, LocaleLoader, InitialPaginationMetadata, PaginationActionTypes, PaginationLoaded, ResetPagination, paginationReducer, getFiltersHash, getLastPageLoaded, getNextPage, resetPagination, nextPage, pageLoaded, takePagination, isInitialPagination, filterPaginationScrollPosition, selectPagination, paginationResponseFromPageResponse, ElisCoreModule, AlertTypes, SuccessAlert, ErrorAlert, InfoAlert, WarningAlert, sistemasReducer, selectSistemasIds, selectSistemasEntities, selectAllSistemas, selectSistema, isLoaded, selectSistemasState, usersADReducer, selectUsersIds, selectUsersEntities, selectAllUsers, selectUser, selectUsersADState, UpdateUserRoleActionsTypes, AddUserRoleRequest, RemoveUserRoleRequest, rolesReducer, selectRolesIds, selectRolesEntities, selectAllRoles, selectRoleGroupsIds, selectRoleGroupsEntities, selectAllRoleGroups, selectRoleGroupsState, selectRole, selectRoleGroupsBySistema, hasRole, selectRolesState, UpdateUserSubsidiaryActionsTypes, AddUserSubsidiaryRequest, RemoveUserSubsidiaryRequest, selectSubsidiaryId, subsidiariesReducer, selectSubsidiariesIds, selectSubsidiariesEntities, selectAllSubsidiaries, selectSubsidiary, hasSubsidiary, filterSubsidiary, selectSubsidiariesState, UsuarioRoleInsertData, UsuarioRoleRemoveData, UsuarioSubsidiaryInsertData, UsuarioSubsidiaryRemoveData, usuariosReducer, selectUsuario, selectUsuariosIds, selectUsuariosEntities, selectAllUsuarios, getCurrentUsuario, selectUsuariosState, authReducer, initialState, selectAuthUser, selectUserSubsidiary, selectUserSubsidiarySegment, selectPreferedSubsidiary, selectPreferedSubsidiarySegment, selectAuthState, LocalesTypes, DefaultLocale, ForgotPasswordComponent as ɵc, ResetPasswordComponent as ɵd, RefreshTokenInterceptor as ɵe, SubsidiaryInterceptor as ɵg, EnvServiceFactory as ɵa, LocaleInterceptor as ɵf, TranslateCacheFactory as ɵb };

//# sourceMappingURL=elisconnect-core.js.map