import { Action } from '@ngrx/store';
import { User, Credential, ChangePasswordRequest, ForgotPasswordRequest, ResetPasswordRequest, ChangeSubsidiarySegmentRequest } from '../auth.model';
import { AuthState } from './auth.reducer';
import { DefaultResponse } from '../../response/response.model';
export declare enum AuthActionTypes {
    Login = "[Auth] Login",
    LoggedIn = "[Auth] LoggedIn",
    LoginFailed = "[Auth] Login Failed",
    Logout = "[Auth] Logout",
    ClearAuthState = "[Auth] Clear Auth State",
    Loggedout = "[Auth] Loggedout",
    LoadState = "[Auth] Load State",
    StateLoaded = "[Auth] State Loaded",
    PersistState = "[Auth] Persist State",
    StatePersisted = "[Auth] State Persisted",
    RefreshToken = "[Auth] Refresh Token",
    ChangeSubsidiary = "[Auth] Change Current Subsidiary",
    ChangeSubsidiarySegment = "[Auth] Change Current SubsidiarySegment",
    ChangePassword = "[Auth] Change Password",
    PasswordChanged = "[Auth] Password Changed",
    PasswordChangeFailed = "[Auth] Password Change Failed",
    RequestPasswordReset = "[Auth] Request Password Reset",
    PasswordResetRequested = "[Auth] Password Reset Requested",
    PasswordResetRequestFailed = "[Auth] Password Reset Request Failed",
    PasswordReset = "[Auth] Password Reset",
    PasswordReseted = "[Auth] Password Reseted",
    PasswordResetFailed = "[Auth] Password Reset Failed"
}
export declare class Login implements Action {
    payload: Credential;
    readonly type = AuthActionTypes.Login;
    constructor(payload: Credential);
}
export declare class LoggedIn implements Action {
    payload: User;
    readonly type = AuthActionTypes.LoggedIn;
    constructor(payload: User);
}
export declare class LoginFailed implements Action {
    payload: string;
    readonly type = AuthActionTypes.LoginFailed;
    constructor(payload: string);
}
export declare class Logout implements Action {
    readonly type = AuthActionTypes.Logout;
}
export declare class ClearAuthState implements Action {
    readonly type = AuthActionTypes.ClearAuthState;
}
export declare class Loggedout implements Action {
    readonly type = AuthActionTypes.Loggedout;
}
export declare class LoadAuthState implements Action {
    readonly type = AuthActionTypes.LoadState;
}
export declare class AuthStateLoaded implements Action {
    payload: AuthState;
    readonly type = AuthActionTypes.StateLoaded;
    constructor(payload: AuthState);
}
export declare class PersistState implements Action {
    payload: AuthState;
    readonly type = AuthActionTypes.PersistState;
    constructor(payload: AuthState);
}
export declare class StatePersisted implements Action {
    readonly type = AuthActionTypes.StatePersisted;
}
export declare class RefreshToken implements Action {
    payload: User;
    readonly type = AuthActionTypes.RefreshToken;
    constructor(payload: User);
}
export declare class ChangeSubsidiary implements Action {
    payload: string;
    readonly type = AuthActionTypes.ChangeSubsidiary;
    constructor(payload: string);
}
export declare class ChangeSubsidiarySegment implements Action {
    payload: ChangeSubsidiarySegmentRequest;
    readonly type = AuthActionTypes.ChangeSubsidiarySegment;
    constructor(payload: ChangeSubsidiarySegmentRequest);
}
export declare class ChangePassword implements Action {
    payload: ChangePasswordRequest;
    readonly type = AuthActionTypes.ChangePassword;
    constructor(payload: ChangePasswordRequest);
}
export declare class PasswordChanged implements Action {
    payload: DefaultResponse;
    readonly type = AuthActionTypes.PasswordChanged;
    constructor(payload: DefaultResponse);
}
export declare class PasswordChangeFailed implements Action {
    payload: string;
    readonly type = AuthActionTypes.PasswordChangeFailed;
    constructor(payload: string);
}
export declare class RequestPasswordReset implements Action {
    payload: ForgotPasswordRequest;
    readonly type = AuthActionTypes.RequestPasswordReset;
    constructor(payload: ForgotPasswordRequest);
}
export declare class PasswordResetRequested implements Action {
    payload: DefaultResponse;
    readonly type = AuthActionTypes.PasswordResetRequested;
    constructor(payload: DefaultResponse);
}
export declare class PasswordResetRequestFailed implements Action {
    payload: string;
    readonly type = AuthActionTypes.PasswordResetRequestFailed;
    constructor(payload: string);
}
export declare class PasswordReset implements Action {
    payload: ResetPasswordRequest;
    readonly type = AuthActionTypes.PasswordReset;
    constructor(payload: ResetPasswordRequest);
}
export declare class PasswordReseted implements Action {
    payload: DefaultResponse;
    readonly type = AuthActionTypes.PasswordReseted;
    constructor(payload: DefaultResponse);
}
export declare class PasswordResetFailed implements Action {
    payload: string;
    readonly type = AuthActionTypes.PasswordResetFailed;
    constructor(payload: string);
}
export declare type AuthActions = Login | LoggedIn | LoginFailed | Logout | ClearAuthState | Loggedout | LoadAuthState | AuthStateLoaded | PersistState | StatePersisted | RefreshToken | ChangeSubsidiary | ChangeSubsidiarySegment | ChangePassword | PasswordChanged | PasswordChangeFailed | RequestPasswordReset | PasswordResetRequested | PasswordResetRequestFailed | PasswordReset | PasswordReseted | PasswordResetFailed;
